@@ -65,14 +65,13 @@ QualifiedMassSpectrum::QualifiedMassSpectrum(const QualifiedMassSpectrum &other)
     m_dt(other.m_dt),
     m_precursorSpectrumIndex(other.m_precursorSpectrumIndex),
     m_precursorNativeId(other.m_precursorNativeId),
-    m_precursorMz(other.m_precursorMz),
-    m_precursorCharge(other.m_precursorCharge),
-    m_precursorIntensity(other.m_precursorIntensity),
+    m_precursorIonData(other.m_precursorIonData),
     m_paramsMap(other.m_paramsMap)
 {
   // qDebug();
 }
 
+
 //! Destruct this QualifiedMassSpectrum.
 QualifiedMassSpectrum::~QualifiedMassSpectrum()
 {
@@ -91,12 +90,18 @@ QualifiedMassSpectrum::operator=(const QualifiedMassSpectrum &other)
   m_dt                     = other.m_dt;
   m_precursorSpectrumIndex = other.m_precursorSpectrumIndex;
   m_precursorNativeId      = other.m_precursorNativeId;
-  m_precursorMz            = other.m_precursorMz;
-  m_precursorCharge        = other.m_precursorCharge;
-  m_precursorIntensity     = other.m_precursorIntensity;
+  m_precursorIonData       = other.m_precursorIonData;
+  m_paramsMap              = other.m_paramsMap;
 
-  m_paramsMap = other.m_paramsMap;
+  return *this;
+}
 
+
+const QualifiedMassSpectrum &
+QualifiedMassSpectrum::cloneMassSpectrumSPtr()
+{
+  this->msp_massSpectrum =
+    std::make_shared<MassSpectrum>(*this->msp_massSpectrum.get());
   return *this;
 }
 
@@ -115,22 +120,6 @@ QualifiedMassSpectrum::makeQualifiedMassSpectrumCstSPtr() const
 }
 
 
-//! Set the MassSpectrumId.
-void
-QualifiedMassSpectrum::setMassSpectrumId(const MassSpectrumId &iD)
-{
-  m_massSpectrumId = iD;
-}
-
-
-//! Get the MassSpectrumId.
-const MassSpectrumId &
-QualifiedMassSpectrum::getMassSpectrumId() const
-{
-  return m_massSpectrumId;
-}
-
-
 //! Set the MassSpectrumSPtr.
 void
 QualifiedMassSpectrum::setMassSpectrumSPtr(MassSpectrumSPtr massSpectrum)
@@ -155,6 +144,22 @@ QualifiedMassSpectrum::getMassSpectrumCstSPtr() const
 }
 
 
+//! Set the MassSpectrumId.
+void
+QualifiedMassSpectrum::setMassSpectrumId(const MassSpectrumId &iD)
+{
+  m_massSpectrumId = iD;
+}
+
+
+//! Get the MassSpectrumId.
+const MassSpectrumId &
+QualifiedMassSpectrum::getMassSpectrumId() const
+{
+  return m_massSpectrumId;
+}
+
+
 void
 QualifiedMassSpectrum::setEmptyMassSpectrum(bool is_empty_mass_spectrum)
 {
@@ -169,38 +174,6 @@ QualifiedMassSpectrum::isEmptyMassSpectrum() const
 }
 
 
-//! Set the precursor charge.
-void
-QualifiedMassSpectrum::setPrecursorCharge(unsigned int precursor_charge)
-{
-  m_precursorCharge = precursor_charge;
-}
-
-
-//! Get the precursor charge.
-unsigned int
-QualifiedMassSpectrum::getPrecursorCharge() const
-{
-  return m_precursorCharge;
-}
-
-
-//! Set the precursor m/z ratio.
-void
-QualifiedMassSpectrum::setPrecursorMz(pappso_double precursor_mz)
-{
-  m_precursorMz = precursor_mz;
-}
-
-
-//! Get the precursor m/z ratio.
-pappso_double
-QualifiedMassSpectrum::getPrecursorMz() const
-{
-  return m_precursorMz;
-}
-
-
 //! Set the mass spectrum level.
 void
 QualifiedMassSpectrum::setMsLevel(unsigned int level)
@@ -260,6 +233,168 @@ QualifiedMassSpectrum::getDtInMilliSeconds() const
 }
 
 
+//! Get the precursor m/z ratio.
+pappso_double
+QualifiedMassSpectrum::getPrecursorMz(bool *ok_p) const
+{
+  if(!m_precursorIonData.size())
+    {
+      if(ok_p != nullptr)
+        *ok_p = false;
+
+      return std::numeric_limits<double>::max();
+    }
+
+  if(ok_p != nullptr)
+    *ok_p = true;
+
+  // qDebug() << "Returning precursor mz value: " <<
+  // m_precursorIonData.front().mz;
+  return m_precursorIonData.front().mz;
+}
+
+
+QString
+QualifiedMassSpectrum::getPrecursorDataMzValuesAsString(
+  const std::vector<PrecursorIonData> &precursor_ion_data_vector,
+  const QString &separator) const
+{
+  QString text;
+
+  // We do not want to use the separator if there is only one precursor in the
+  // vector.
+
+  if(precursor_ion_data_vector.size() == 1)
+    return QString("%1").arg(precursor_ion_data_vector.front().mz, 0, 'f', 6);
+
+  // If there are more than one precursor, then we should list them joined with
+  // the separator.
+
+  using iterator = std::vector<pappso::PrecursorIonData>::const_iterator;
+
+  iterator begin_iterator   = precursor_ion_data_vector.begin();
+  iterator pre_end_iterator = std::prev(precursor_ion_data_vector.end());
+
+  for(; begin_iterator != precursor_ion_data_vector.end(); ++begin_iterator)
+    {
+      if(begin_iterator == pre_end_iterator)
+        // No separator at the end of the string
+        text += QString("%1").arg(begin_iterator->mz, 0, 'f', 6);
+      else
+        text +=
+          QString("%1%2").arg(begin_iterator->mz, 0, 'f', 6).arg(separator);
+    }
+
+  return text;
+}
+
+
+QString
+QualifiedMassSpectrum::getPrecursorDataMzValuesAsString(
+  const QString &separator) const
+{
+  return getPrecursorDataMzValuesAsString(m_precursorIonData, separator);
+}
+
+
+QString
+QualifiedMassSpectrum::getMzSortedPrecursorDataMzValuesAsString(
+  const QString &separator) const
+{
+  // Sort the PrecursorIonData instances by increasing mz values.
+  // Then craft the string using the mz values.
+
+  std::vector<PrecursorIonData> sorted_vector =
+    getPrecursorIonDataSortedWithMz();
+
+  return getPrecursorDataMzValuesAsString(sorted_vector, separator);
+}
+
+
+//! Get the precursor charge.
+unsigned int
+QualifiedMassSpectrum::getPrecursorCharge(bool *ok_p) const
+{
+  if(!m_precursorIonData.size())
+    {
+      return std::numeric_limits<unsigned int>::max();
+
+      if(ok_p != nullptr)
+        *ok_p = false;
+    }
+
+  if(ok_p != nullptr)
+    *ok_p = true;
+
+  return m_precursorIonData.front().charge;
+}
+
+
+QString
+QualifiedMassSpectrum::getPrecursorDataChargeValuesAsString(
+  const std::vector<PrecursorIonData> &precursor_ion_data_vector,
+  const QString &separator) const
+{
+  QString text;
+
+  // We do not want to use the separator if there is only one precursor in the
+  // vector.
+
+  if(precursor_ion_data_vector.size() == 1)
+    return QString("%1").arg(precursor_ion_data_vector.front().charge);
+
+  // If there are more than one precursor, then we should list them joined with
+  // the separator.
+  for(auto item : precursor_ion_data_vector)
+    {
+      text += QString("%1%2").arg(item.charge).arg(separator);
+    }
+
+  return text;
+}
+
+
+QString
+QualifiedMassSpectrum::getPrecursorDataChargeValuesAsString(
+  const QString &separator) const
+{
+  return getPrecursorDataChargeValuesAsString(m_precursorIonData, separator);
+}
+
+
+QString
+QualifiedMassSpectrum::getMzSortedPrecursorDataChargeValuesAsString(
+  const QString &separator) const
+{
+  // Sort the PrecursorIonData instances by increasing mz values.
+  // Then craft the string using the mz values.
+
+  std::vector<PrecursorIonData> sorted_vector =
+    getPrecursorIonDataSortedWithMz();
+
+  return getPrecursorDataChargeValuesAsString(sorted_vector, separator);
+}
+
+
+//! Get the intensity of the precursor ion.
+pappso_double
+QualifiedMassSpectrum::getPrecursorIntensity(bool *ok_p) const
+{
+  if(!m_precursorIonData.size())
+    {
+      return std::numeric_limits<double>::max();
+
+      if(ok_p != nullptr)
+        *ok_p = false;
+    }
+
+  if(ok_p != nullptr)
+    *ok_p = true;
+
+  return m_precursorIonData.front().intensity;
+}
+
+
 //! Set the scan number of the precursor ion.
 void
 QualifiedMassSpectrum::setPrecursorSpectrumIndex(
@@ -268,6 +403,7 @@ QualifiedMassSpectrum::setPrecursorSpectrumIndex(
   m_precursorSpectrumIndex = precursor_spectrum_index;
 }
 
+
 //! Get the scan number of the precursor ion.
 std::size_t
 QualifiedMassSpectrum::getPrecursorSpectrumIndex() const
@@ -275,6 +411,7 @@ QualifiedMassSpectrum::getPrecursorSpectrumIndex() const
   return m_precursorSpectrumIndex;
 }
 
+
 //! Set the scan native id of the precursor ion.
 void
 QualifiedMassSpectrum::setPrecursorNativeId(const QString &native_id)
@@ -288,19 +425,66 @@ QualifiedMassSpectrum::getPrecursorNativeId() const
   return m_precursorNativeId;
 }
 
-//! Set the intensity of the precursor ion.
+
 void
-QualifiedMassSpectrum::setPrecursorIntensity(pappso_double intensity)
+QualifiedMassSpectrum::appendPrecursorIonData(
+  const PrecursorIonData &precursor_ion_data)
 {
-  m_precursorIntensity = intensity;
+  m_precursorIonData.push_back(precursor_ion_data);
 }
 
 
-//! Get the intensity of the precursor ion.
-pappso_double
-QualifiedMassSpectrum::getPrecursorIntensity() const
+const std::vector<PrecursorIonData> &
+QualifiedMassSpectrum::getPrecursorIonData() const
 {
-  return m_precursorIntensity;
+  return m_precursorIonData;
+}
+
+
+std::vector<PrecursorIonData>
+QualifiedMassSpectrum::getPrecursorIonDataSortedWithMz() const
+{
+  std::vector<PrecursorIonData> new_vector;
+  new_vector.assign(m_precursorIonData.begin(), m_precursorIonData.end());
+
+  std::sort(new_vector.begin(),
+            new_vector.end(),
+            [](const PrecursorIonData &a, const PrecursorIonData &b) -> bool {
+              return a.mz < b.mz;
+            });
+
+  return new_vector;
+}
+
+
+void
+QualifiedMassSpectrum::setParameterValue(
+  QualifiedMassSpectrumParameter parameter, const QVariant &value)
+{
+
+  auto ret = m_paramsMap.insert(
+    std::pair<QualifiedMassSpectrumParameter, QVariant>(parameter, value));
+
+  if(ret.second == false)
+    {
+      ret.first->second = value;
+    }
+}
+
+
+const QVariant
+QualifiedMassSpectrum::getParameterValue(
+  QualifiedMassSpectrumParameter parameter) const
+{
+  auto it = m_paramsMap.find(parameter);
+  if(it == m_paramsMap.end())
+    {
+      return QVariant();
+    }
+  else
+    {
+      return it->second;
+    }
 }
 
 
@@ -333,11 +517,20 @@ QualifiedMassSpectrum::toString() const
 
   // qDebug() << text;
 
+  QString precursor_mz_values_string;
+
+  if(m_precursorIonData.size())
+    precursor_mz_values_string += "Precursor mz values: ";
+
+  precursor_mz_values_string += getMzSortedPrecursorDataMzValuesAsString();
+
+  precursor_mz_values_string += "\n";
+
   text +=
     QString(
       "; m_massSpectrumId : %1 \n"
       "m_msLevel: %2 ; m_rt (min): %3 ; m_dt (ms): %4 ; prec. spec. "
-      "index: %5 ; prec. mz: %6 ; prec. z: %7 ; prec. int.: %8")
+      "index: %5 ; %6")
       .arg(m_massSpectrumId.toString())
       .arg(m_msLevel)
       .arg(getRtInMinutes(), 0, 'f', 2)
@@ -345,53 +538,10 @@ QualifiedMassSpectrum::toString() const
       .arg(m_precursorSpectrumIndex != std::numeric_limits<std::size_t>::max()
              ? m_precursorSpectrumIndex
              : -1)
-      .arg(m_precursorMz != std::numeric_limits<double>::max() ? m_precursorMz
-                                                               : -1)
-      .arg(m_precursorCharge != std::numeric_limits<unsigned int>::max()
-             ? m_precursorCharge
-             : -1)
-      .arg(m_precursorIntensity != std::numeric_limits<double>::max()
-             ? m_precursorIntensity
-             : -1);
+      .arg(precursor_mz_values_string);
 
   return text;
 }
 
 
-void
-QualifiedMassSpectrum::setParameterValue(
-  QualifiedMassSpectrumParameter parameter, const QVariant &value)
-{
-
-  auto ret = m_paramsMap.insert(
-    std::pair<QualifiedMassSpectrumParameter, QVariant>(parameter, value));
-
-  if(ret.second == false)
-    {
-      ret.first->second = value;
-    }
-}
-const QVariant
-QualifiedMassSpectrum::getParameterValue(
-  QualifiedMassSpectrumParameter parameter) const
-{
-  auto it = m_paramsMap.find(parameter);
-  if(it == m_paramsMap.end())
-    {
-      return QVariant();
-    }
-  else
-    {
-      return it->second;
-    }
-}
-
-const QualifiedMassSpectrum &
-QualifiedMassSpectrum::cloneMassSpectrumSPtr()
-{
-  MassSpectrum copy(*this->msp_massSpectrum.get());
-  this->msp_massSpectrum = copy.makeMassSpectrumSPtr();
-  return *this;
-}
-
 } // namespace pappso
