@@ -58,6 +58,23 @@ enum class QualifiedMassSpectrumParameter
   last
 };
 
+struct PrecursorIonData
+{
+  double mz        = 0;
+  int charge       = 0;
+  double intensity = 0;
+
+  PrecursorIonData(double mz_value        = 0,
+                   int charge_value       = 0,
+                   double intensity_value = 0)
+  {
+    mz        = mz_value;
+    charge    = charge_value;
+    intensity = intensity_value;
+  };
+};
+
+
 //! Class representing a fully specified mass spectrum.
 /*!
  * The member data that qualify the MassSpectrum \c msp_massSpectrum member
@@ -75,39 +92,26 @@ class PMSPP_LIB_DECL QualifiedMassSpectrum
 
   QualifiedMassSpectrum &operator=(const QualifiedMassSpectrum &other);
 
+  /** @brief clone the mass spectrum contained in Qualified Mass Spectrum
+   */
+  const QualifiedMassSpectrum &cloneMassSpectrumSPtr();
 
   QualifiedMassSpectrumSPtr makeQualifiedMassSpectrumSPtr() const;
   QualifiedMassSpectrumCstSPtr makeQualifiedMassSpectrumCstSPtr() const;
 
-  void setMassSpectrumId(const MassSpectrumId &iD);
-  const MassSpectrumId &getMassSpectrumId() const;
-
   void setMassSpectrumSPtr(MassSpectrumSPtr massSpectrum);
   MassSpectrumSPtr getMassSpectrumSPtr() const;
   MassSpectrumCstSPtr getMassSpectrumCstSPtr() const;
 
-  /** @brief clone the mass spectrum contained in Qualified Mass Spectrum
-   */
-  const QualifiedMassSpectrum &cloneMassSpectrumSPtr();
+  void setMassSpectrumId(const MassSpectrumId &iD);
+  const MassSpectrumId &getMassSpectrumId() const;
 
   void setEmptyMassSpectrum(bool is_empty_mass_spectrum);
   bool isEmptyMassSpectrum() const;
 
-  void setPrecursorCharge(uint precursor_charge);
-  uint getPrecursorCharge() const;
-
-  void setPrecursorMz(pappso_double precursor_mz);
-  pappso_double getPrecursorMz() const;
-
   void setMsLevel(uint ms_level);
   uint getMsLevel() const;
 
-  void setPrecursorSpectrumIndex(std::size_t precursor_scan_num);
-  std::size_t getPrecursorSpectrumIndex() const;
-
-  void setPrecursorNativeId(const QString &native_id);
-  const QString &getPrecursorNativeId() const;
-
   void setRtInSeconds(pappso_double rt);
   pappso_double getRtInSeconds() const;
   pappso_double getRtInMinutes() const;
@@ -115,8 +119,35 @@ class PMSPP_LIB_DECL QualifiedMassSpectrum
   void setDtInMilliSeconds(pappso_double rt);
   pappso_double getDtInMilliSeconds() const;
 
-  void setPrecursorIntensity(pappso_double intensity);
-  pappso_double getPrecursorIntensity() const;
+  pappso_double getPrecursorMz(bool *ok = nullptr) const;
+  QString getPrecursorDataMzValuesAsString(
+    const std::vector<PrecursorIonData> &precursor_ion_data_vector,
+    const QString &separator = "\n") const;
+  QString
+  getPrecursorDataMzValuesAsString(const QString &separator = "\n") const;
+  QString getMzSortedPrecursorDataMzValuesAsString(
+    const QString &separator = "\n") const;
+
+  uint getPrecursorCharge(bool *ok = nullptr) const;
+  QString getPrecursorDataChargeValuesAsString(
+    const std::vector<PrecursorIonData> &precursor_ion_data_vector,
+    const QString &separator = "\n") const;
+  QString
+  getPrecursorDataChargeValuesAsString(const QString &separator = "\n") const;
+  QString getMzSortedPrecursorDataChargeValuesAsString(
+    const QString &separator = "\n") const;
+
+  pappso_double getPrecursorIntensity(bool *ok = nullptr) const;
+
+  void setPrecursorSpectrumIndex(std::size_t precursor_scan_num);
+  std::size_t getPrecursorSpectrumIndex() const;
+
+  void setPrecursorNativeId(const QString &native_id);
+  const QString &getPrecursorNativeId() const;
+
+  void appendPrecursorIonData(const PrecursorIonData &precursor_ion_data);
+  const std::vector<PrecursorIonData> &getPrecursorIonData() const;
+  std::vector<PrecursorIonData> getPrecursorIonDataSortedWithMz() const;
 
   void setParameterValue(QualifiedMassSpectrumParameter parameter,
                          const QVariant &value);
@@ -153,16 +184,10 @@ class PMSPP_LIB_DECL QualifiedMassSpectrum
   //! Native XML id of the spectrum relative to the mz data native file
   QString m_precursorNativeId;
 
-  //! m/z ratio of the precursor that was fragmented to yield this mass
-  //! spectrum.
-  pappso_double m_precursorMz = std::numeric_limits<double>::max();
+  //! vector of precursor ion data of the precursors that were fragmented to
+  //! yield this mass spectrum.
 
-  //! Charge of the precursor that was fragmented to yield this mass spectrum.
-  unsigned int m_precursorCharge = std::numeric_limits<unsigned int>::max();
-
-  //! Intensity of the precursor that was fragmented to yield this mass
-  //! spectrum.
-  pappso_double m_precursorIntensity = std::numeric_limits<double>::max();
+  std::vector<PrecursorIonData> m_precursorIonData;
 
   //! map containing any parameter value for this spectrum
   std::map<QualifiedMassSpectrumParameter, QVariant> m_paramsMap;
