@@ -222,6 +222,13 @@ MsFileAccessor::msRunReaderSp(MsRunIdCstSPtr ms_run_id)
 
 MsRunReaderSPtr
 MsFileAccessor::buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
+{
+  return buildMsRunReaderSPtr(ms_run_id, pappso::FileReaderType::tims);
+}
+
+MsRunReaderSPtr
+MsFileAccessor::buildMsRunReaderSPtr(
+  MsRunIdCstSPtr ms_run_id, pappso::FileReaderType prefered_file_reader_type)
 {
 
   QFile file(ms_run_id.get()->getFileName());
@@ -246,6 +253,16 @@ MsFileAccessor::buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
     }
   else if(file_format == MzFormat::brukerTims)
     {
+      if(prefered_file_reader_type == pappso::FileReaderType::tims)
+        {
+          return std::make_shared<TimsMsRunReader>(ms_run_id);
+        }
+      else if(prefered_file_reader_type == pappso::FileReaderType::tims_ms2)
+        {
+          qDebug();
+          return std::make_shared<TimsMsRunReaderMs2>(ms_run_id);
+        }
+
       qDebug() << "by default, build a TimsMsRunReader.";
       return std::make_shared<TimsMsRunReader>(ms_run_id);
     }
