@@ -43,7 +43,7 @@ class PMSPP_LIB_DECL MsFileAccessor
   /** @brief get the raw format of mz data
    */
   MzFormat getFileFormat() const;
-  
+
   /** @brief get the file reader type
    */
   FileReaderType getFileReaderType() const;
@@ -69,9 +69,26 @@ class PMSPP_LIB_DECL MsFileAccessor
    *
    * no need to check the file format or filename : all is already part of the
    * msrunid
+   *
+   * @param ms_run_id msrun identifier
+   * @return msrun reader shared pointer
    */
   static MsRunReaderSPtr buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id);
 
+  /** @brief get an MsRunReader directly from a valid MsRun ID
+   *
+   * no need to check the file format or filename : all is already part of the
+   * msrunid
+   *
+   * @param ms_run_id msrun identifier
+   * @param prefered_file_reader_type the prefered file reader type to use
+   * (depending on the mz format)
+   * @return msrun reader shared pointer
+   */
+  static MsRunReaderSPtr
+  buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id,
+                       pappso::FileReaderType prefered_file_reader_type);
+
   /** @brief if possible, builds directly a dedicated Tims TOF tdf file reader
    */
   TimsMsRunReaderMs2SPtr buildTimsMsRunReaderMs2SPtr();
