@@ -31,68 +31,18 @@
 
 using namespace pappso;
 
-/*
-void
-writeTrace(const QString &filename, const pappso::Trace &trace)
-{
-  QFile file(filename);
-  qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "() "
-           << QFileInfo(filename).absoluteFilePath();
-  // file.open(QIODevice::WriteOnly);
-  OdsDocWriter writer(&file);
-
-  for(auto &data_point : trace)
-    {
-      writer.writeCell(data_point.x);
-      writer.writeCell(data_point.y);
-      writer.writeLine();
-    }
-  writer.close();
-}
-*/
-
-class RetentionTimeReader : public SpectrumCollectionHandlerInterface
-{
-
-  public:
-  RetentionTimeReader(std::vector<RtPoint> &rt_points)
-    : m_rtPoints(rt_points){};
-  virtual ~RetentionTimeReader(){};
-  virtual void
-  setQualifiedMassSpectrum(const QualifiedMassSpectrum &spectrum) override
-  {
-    if(spectrum.getMsLevel() == 1)
-      {
-        m_rtPoints.push_back({spectrum.getRtInSeconds(),
-                              spectrum.getMassSpectrumId().getSpectrumIndex()});
-      }
-  };
-  virtual bool
-  needPeakList() const override
-  {
-    return false;
-  };
-
-  private:
-  std::vector<RtPoint> &m_rtPoints;
-};
-
-
 template <class T>
 MsRunRetentionTime<T>::MsRunRetentionTime(MsRunReaderSPtr msrun_reader_sp)
   : m_ms2MedianFilter(10), m_ms2MeanFilter(15), m_ms1MeanFilter(1)
 {
-  msp_msrunReader = msrun_reader_sp;
-  mcsp_msrunId    = msp_msrunReader.get()->getMsRunId();
-  RetentionTimeReader handler(m_ms1RetentionTimeVector);
-  msrun_reader_sp.get()->readSpectrumCollection(handler);
+  msp_msrunReader          = msrun_reader_sp;
+  mcsp_msrunId             = msp_msrunReader.get()->getMsRunId();
+  m_ms1RetentionTimeVector = msp_msrunReader.get()->getRetentionTimeLine();
 
 
   std::sort(m_ms1RetentionTimeVector.begin(),
             m_ms1RetentionTimeVector.end(),
-            [](const RtPoint &a, const RtPoint &b) {
-              return (a.retentionTime < b.retentionTime);
-            });
+            [](const double &a, const double &b) { return (a < b); });
 }
 
 template <class T>
@@ -119,6 +69,20 @@ MsRunRetentionTime<T>::~MsRunRetentionTime()
 {
 }
 
+template <class T>
+const MsRunId &
+MsRunRetentionTime<T>::getMsRunId() const
+{
+  return *(mcsp_msrunId.get());
+}
+
+template <typename T>
+const pappso::FilterMorphoMedian &
+pappso::MsRunRetentionTime<T>::getMs2MedianFilter() const
+{
+  return m_ms2MedianFilter;
+}
+
 template <class T>
 void
 MsRunRetentionTime<T>::setMs2MedianFilter(
@@ -127,6 +91,14 @@ MsRunRetentionTime<T>::setMs2MedianFilter(
   m_ms2MedianFilter = ms2MedianFilter;
 }
 
+template <typename T>
+const pappso::FilterMorphoMean &
+pappso::MsRunRetentionTime<T>::getMs2MeanFilter() const
+{
+  return m_ms2MeanFilter;
+}
+
+
 template <class T>
 void
 MsRunRetentionTime<T>::setMs2MeanFilter(const FilterMorphoMean &ms2MeanFilter)
@@ -134,6 +106,13 @@ MsRunRetentionTime<T>::setMs2MeanFilter(const FilterMorphoMean &ms2MeanFilter)
   m_ms2MeanFilter = ms2MeanFilter;
 }
 
+template <typename T>
+const pappso::FilterMorphoMean &
+pappso::MsRunRetentionTime<T>::getMs1MeanFilter() const
+{
+  return m_ms1MeanFilter;
+}
+
 template <class T>
 void
 MsRunRetentionTime<T>::setMs1MeanFilter(const FilterMorphoMean &ms1MeanFilter)
@@ -163,7 +142,7 @@ MsRunRetentionTime<T>::getNumberOfCorrectedValues() const
   return m_valuesCorrected;
 }
 template <class T>
-const std::vector<RtPoint> &
+const std::vector<double> &
 MsRunRetentionTime<T>::getMs1RetentionTimeVector() const
 {
   return m_ms1RetentionTimeVector;
@@ -203,16 +182,29 @@ MsRunRetentionTime<T>::addPeptideAsSeamark(const T &peptide_id,
 
 template <class T>
 void
-MsRunRetentionTime<T>::computePeptideRetentionTimes()
+MsRunRetentionTime<T>::addPeptideAsSeamark(const T &peptide_id,
+                                           double retentionTime,
+                                           double precursorIntensity)
+{
+  PeptideMs2Point ms2point;
+  ms2point.entityHash         = peptide_id;
+  ms2point.precursorIntensity = precursorIntensity;
+  ms2point.retentionTime      = retentionTime;
+  m_allMs2Points.push_back(ms2point);
+}
+
+
+template <class T>
+void
+MsRunRetentionTime<T>::computeSeamarks()
 {
 
   qDebug();
-  if(msp_msrunReader == nullptr)
+  if(m_allMs2Points.size() == 0)
     {
-      throw ExceptionNotPossible(
-        QObject::tr("ERROR : msp_msrunReader == nullptr"));
+      // already computed
+      return;
     }
-  msp_msrunReader.get()->releaseDevice();
   m_seamarks.clear();
   if(m_retentionTimeReferenceMethod ==
      ComputeRetentionTimeReference::maximum_intensity)
@@ -320,7 +312,7 @@ MsRunRetentionTime<T>::getFrontRetentionTimeReference() const
     {
       return m_alignedRetentionTimeVector.front();
     }
-  return m_ms1RetentionTimeVector.front().retentionTime;
+  return m_ms1RetentionTimeVector.front();
 }
 template <class T>
 double
@@ -330,7 +322,7 @@ MsRunRetentionTime<T>::getBackRetentionTimeReference() const
     {
       return m_alignedRetentionTimeVector.back();
     }
-  return m_ms1RetentionTimeVector.back().retentionTime;
+  return m_ms1RetentionTimeVector.back();
 }
 
 
@@ -357,8 +349,8 @@ MsRunRetentionTime<T>::translateOriginal2AlignedRetentionTime(
   auto it_plus =
     std::find_if(m_ms1RetentionTimeVector.begin(),
                  m_ms1RetentionTimeVector.end(),
-                 [original_retention_time](const RtPoint &rt_point) {
-                   return original_retention_time < rt_point.retentionTime;
+                 [original_retention_time](const double &rt_point) {
+                   return original_retention_time < rt_point;
                  });
   double rt1_a, rt2_a, rt1_b, rt2_b;
   if(it_plus == m_ms1RetentionTimeVector.end())
@@ -371,8 +363,8 @@ MsRunRetentionTime<T>::translateOriginal2AlignedRetentionTime(
     }
   auto it_minus = it_plus - 1;
 
-  rt1_a = it_minus->retentionTime;
-  rt2_a = it_plus->retentionTime;
+  rt1_a = *it_minus;
+  rt2_a = *it_plus;
 
   double ratio = (original_retention_time - rt1_a) / (rt2_a - rt1_a);
 
@@ -386,6 +378,57 @@ MsRunRetentionTime<T>::translateOriginal2AlignedRetentionTime(
   return (((rt2_b - rt1_b) * ratio) + rt1_b);
 }
 
+template <class T>
+double
+MsRunRetentionTime<T>::translateAligned2OriginalRetentionTime(
+  double aligned_retention_time) const
+{
+  if(m_alignedRetentionTimeVector.size() < 3)
+    {
+      throw ExceptionNotPossible(
+        QObject::tr("ERROR : too few aligned points to compute aligned "
+                    "retention time (%1)")
+          .arg(m_ms1RetentionTimeVector.size()));
+    }
+  if(m_alignedRetentionTimeVector.size() != m_ms1RetentionTimeVector.size())
+    {
+      throw ExceptionNotPossible(
+        QObject::tr("ERROR : m_alignedRetentionTimeVector.size() %1 != %2 "
+                    "m_ms1RetentionTimeVector.size()")
+          .arg(m_alignedRetentionTimeVector.size())
+          .arg(m_ms1RetentionTimeVector.size()));
+    }
+  auto it_plus = std::find_if(m_alignedRetentionTimeVector.begin(),
+                              m_alignedRetentionTimeVector.end(),
+                              [aligned_retention_time](const double &rt_point) {
+                                return aligned_retention_time < rt_point;
+                              });
+  double rt1_a, rt2_a, rt1_b, rt2_b;
+  if(it_plus == m_alignedRetentionTimeVector.end())
+    {
+      it_plus--;
+    }
+  if(it_plus == m_alignedRetentionTimeVector.begin())
+    {
+      it_plus++;
+    }
+  auto it_minus = it_plus - 1;
+
+  rt1_a = *it_minus;
+  rt2_a = *it_plus;
+
+  double ratio = (aligned_retention_time - rt1_a) / (rt2_a - rt1_a);
+
+  auto itref = m_ms1RetentionTimeVector.begin() +
+               std::distance(m_alignedRetentionTimeVector.begin(), it_minus);
+
+  rt1_b = *itref;
+  itref++;
+  rt2_b = *itref;
+
+  return (((rt2_b - rt1_b) * ratio) + rt1_b);
+}
+
 template <class T>
 const std::vector<MsRunRetentionTimeSeamarkPoint<T>>
 MsRunRetentionTime<T>::getSeamarksReferences() const
@@ -411,6 +454,7 @@ Trace
 MsRunRetentionTime<T>::align(
   const MsRunRetentionTime<T> &msrun_retention_time_reference)
 {
+  computeSeamarks();
   std::vector<MsRunRetentionTimeSeamarkPoint<T>> other_seamarks;
   if(msrun_retention_time_reference.isAligned())
     {
@@ -452,20 +496,20 @@ MsRunRetentionTime<T>::align(
 
   // add a first point to ensure coherence:
   DataPoint first_point;
-  first_point.x = m_ms1RetentionTimeVector.front().retentionTime - (double)1;
+  first_point.x = m_ms1RetentionTimeVector.front() - (double)1;
   if(first_point.x < 0)
     {
       first_point.x = 0;
     }
   first_point.y =
-    m_ms1RetentionTimeVector.front().retentionTime -
+    m_ms1RetentionTimeVector.front() -
     msrun_retention_time_reference.getFrontRetentionTimeReference();
 
   common_points.push_back(first_point);
   // add a last point to ensure coherence:
   DataPoint last_point;
-  last_point.x = m_ms1RetentionTimeVector.back().retentionTime + 1;
-  last_point.y = m_ms1RetentionTimeVector.back().retentionTime -
+  last_point.x = m_ms1RetentionTimeVector.back() + 1;
+  last_point.y = m_ms1RetentionTimeVector.back() -
                  msrun_retention_time_reference.getBackRetentionTimeReference();
   common_points.push_back(last_point);
   common_points.sortX();
@@ -497,8 +541,7 @@ MsRunRetentionTime<T>::align(
   // Here, the correction parameter is the slope of old rt points curve
   // (divided by 4 to get a finer correction).
   double correction_parameter =
-    (m_ms1RetentionTimeVector.back().retentionTime -
-     m_ms1RetentionTimeVector.front().retentionTime) /
+    (m_ms1RetentionTimeVector.back() - m_ms1RetentionTimeVector.front()) /
     (ms1_aligned_points.size());
   // set_correction_parameter(correction_parameter / 4);
   correction_parameter = correction_parameter / (double)4;
@@ -532,10 +575,10 @@ MsRunRetentionTime<T>::linearRegressionMs2toMs1(Trace &ms1_aligned_points,
     }
   qDebug() << "() itms2->x=" << itms2->x << " itms2->y=" << itms2->y;
 
-  for(RtPoint &original_rt_point : m_ms1RetentionTimeVector)
+  for(double &original_rt_point : m_ms1RetentionTimeVector)
     {
       DataPoint ms1_point;
-      ms1_point.x = original_rt_point.retentionTime;
+      ms1_point.x = original_rt_point;
 
       while(ms1_point.x > itms2next->x)
         {
@@ -585,9 +628,76 @@ MsRunRetentionTime<T>::correctNewTimeValues(Trace &ms1_aligned_points,
 }
 
 
-template <typename T>
+template <class T>
 pappso::MsRunReaderSPtr
 pappso::MsRunRetentionTime<T>::getMsRunReaderSPtr() const
 {
   return msp_msrunReader;
 }
+
+template <class T>
+void
+pappso::MsRunRetentionTime<T>::setAlignedRetentionTimeVector(
+  const std::vector<double> &aligned_times)
+{
+
+  if(aligned_times.size() == m_ms1RetentionTimeVector.size())
+    {
+      m_alignedRetentionTimeVector = aligned_times;
+    }
+  else
+    {
+      if(aligned_times.size() == m_ms1RetentionTimeVector.size() * 2)
+        {
+          m_alignedRetentionTimeVector = m_ms1RetentionTimeVector;
+          for(std::size_t i = 0; i < m_ms1RetentionTimeVector.size(); i++)
+            {
+              if(aligned_times[2 * i] != m_ms1RetentionTimeVector[i])
+                {
+                  throw pappso::PappsoException(
+                    QObject::tr(
+                      "ERROR : aligned_times (size=%1) vector does not have "
+                      "required size (size=%2)")
+                      .arg(aligned_times.size())
+                      .arg(m_ms1RetentionTimeVector.size()));
+                }
+              m_alignedRetentionTimeVector[i] = aligned_times[(2 * i) + 1];
+            }
+        }
+      else
+        {
+          throw ExceptionNotPossible(
+            QObject::tr("ERROR : aligned_times (size=%1) vector does not have "
+                        "required size (size=%2)")
+              .arg(aligned_times.size())
+              .arg(m_ms1RetentionTimeVector.size()));
+        }
+    }
+}
+
+
+template <class T>
+Trace
+MsRunRetentionTime<T>::getCommonSeamarksDeltaRt(
+  const MsRunRetentionTime<T> &msrun_retention_time_reference) const
+{
+  // computeSeamarks();
+  std::vector<MsRunRetentionTimeSeamarkPoint<T>> other_seamarks;
+  if(msrun_retention_time_reference.isAligned())
+    {
+      other_seamarks = msrun_retention_time_reference.getSeamarksReferences();
+    }
+  else
+    {
+      other_seamarks = msrun_retention_time_reference.getSeamarks();
+    }
+  qDebug();
+
+  qDebug() << m_seamarks[0].entityHash << " " << m_seamarks[0].retentionTime
+           << " " << other_seamarks[0].entityHash
+           << other_seamarks[0].retentionTime << " ";
+  // both seamarks has to be ordered
+  Trace common_points;
+  getCommonDeltaRt(common_points, other_seamarks);
+  return common_points;
+}
