@@ -958,4 +958,30 @@ PwizMsRunReader::acquireDevice()
   return true;
 }
 
+
+XicCoordSPtr
+PwizMsRunReader::newXicCoordSPtrFromSpectrumIndex(
+  std::size_t spectrum_index, pappso::PrecisionPtr precision) const
+{
+
+  QualifiedMassSpectrum mass_spectrum =
+    qualifiedMassSpectrum(spectrum_index, false);
+
+  return newXicCoordSPtrFromQualifiedMassSpectrum(mass_spectrum, precision);
+}
+
+XicCoordSPtr
+PwizMsRunReader::newXicCoordSPtrFromQualifiedMassSpectrum(
+  const pappso::QualifiedMassSpectrum &mass_spectrum,
+  pappso::PrecisionPtr precision) const
+{
+  XicCoordSPtr xic_coord = std::make_shared<XicCoord>();
+
+  xic_coord.get()->rtTarget = mass_spectrum.getRtInSeconds();
+
+  xic_coord.get()->mzRange = MzRange(mass_spectrum.getPrecursorMz(), precision);
+
+  return xic_coord;
+}
+
 } // namespace pappso
