@@ -62,6 +62,13 @@ class PwizMsRunReader : public MsRunReader
   virtual void
   readSpectrumCollection(SpectrumCollectionHandlerInterface &handler) override;
 
+  virtual pappso::XicCoordSPtr newXicCoordSPtrFromSpectrumIndex(
+    std::size_t spectrum_index, pappso::PrecisionPtr precision) const override;
+
+  virtual pappso::XicCoordSPtr newXicCoordSPtrFromQualifiedMassSpectrum(
+    const pappso::QualifiedMassSpectrum &mass_spectrum,
+    pappso::PrecisionPtr precision) const override;
+
 
   virtual void
   readSpectrumCollectionByMsLevel(SpectrumCollectionHandlerInterface &handler,
