@@ -39,24 +39,26 @@ TimsMsRunReader::TimsMsRunReader(MsRunIdCstSPtr &msrun_id_csp)
 
 TimsMsRunReader::~TimsMsRunReader()
 {
-  if(mpa_timsData != nullptr)
-    {
-      delete mpa_timsData;
-    }
+  msp_timsData = nullptr;
 }
 
 void
-pappso::TimsMsRunReader::initialize()
+TimsMsRunReader::initialize()
 {
-  mpa_timsData = new TimsData(mcsp_msRunId.get()->getFileName());
+  msp_timsData = std::make_shared<TimsData>(mcsp_msRunId.get()->getFileName());
+  if(msp_timsData == nullptr)
+    {
+      throw PappsoException(QObject::tr("ERROR in TimsMsRunReader::initialize "
+                                        "msp_timsData is null for MsRunId %1")
+                              .arg(mcsp_msRunId.get()->toString()));
+    }
 }
 
 
 bool
 TimsMsRunReader::accept(const QString &file_name) const
 {
-  qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
-           << file_name;
+  qDebug() << file_name;
   return true;
 }
 
@@ -73,7 +75,7 @@ TimsMsRunReader::massSpectrumSPtr([[maybe_unused]] std::size_t spectrum_index)
 pappso::MassSpectrumCstSPtr
 TimsMsRunReader::massSpectrumCstSPtr(std::size_t spectrum_index)
 {
-  return mpa_timsData->getMassSpectrumCstSPtrByRawIndex(spectrum_index);
+  return msp_timsData->getMassSpectrumCstSPtrByRawIndex(spectrum_index);
 }
 
 
@@ -82,18 +84,10 @@ TimsMsRunReader::qualifiedMassSpectrum(std::size_t spectrum_index,
                                        bool want_binary_data) const
 {
 
-  QualifiedMassSpectrum mass_spectrum =
-    mpa_timsData->getQualifiedMassSpectrumByRawIndex(spectrum_index,
-                                                     want_binary_data);
+  QualifiedMassSpectrum mass_spectrum;
 
-  MassSpectrumId spectrum_id(mass_spectrum.getMassSpectrumId());
-  spectrum_id.setMsRunId(getMsRunId());
-  mass_spectrum.setMassSpectrumId(spectrum_id);
-  // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
-  //<< mass_spectrum.toString();
-
-  // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__ << " "
-  //<< mass_spectrum.getMassSpectrumSPtr().get()->toString();
+  msp_timsData->getQualifiedMassSpectrumByRawIndex(
+    getMsRunId(), mass_spectrum, spectrum_index, want_binary_data);
   return mass_spectrum;
 }
 
@@ -113,55 +107,9 @@ TimsMsRunReader::readSpectrumCollectionByMsLevel(
 
   qDebug();
 
-  const bool want_binary_data = handler.needPeakList();
 
-  // We'll need it to perform the looping in the spectrum list.
-  std::size_t spectrum_list_size = spectrumListSize();
-
-  qDebug() << "The spectrum list has size:" << spectrum_list_size;
-
-  // Inform the handler of the spectrum list so that it can handle feedback to
-  // the user.
-  handler.spectrumListHasSize(spectrum_list_size);
-
-  // Iterate in the full list of spectra.
-  // mpa_timsData->iterateOnAllScans(mcsp_msRunId, handler);
-
-  for(std::size_t iter = 0; iter < spectrum_list_size; iter++)
-    {
-      unsigned int current_ms_level =
-        mpa_timsData->getMsLevelBySpectrumIndex(iter);
-
-      // If the user of this reader instance wants to stop reading the spectra,
-      // then break this loop.
-      if(handler.shouldStop())
-        {
-          qDebug() << "The operation was cancelled. Breaking the loop.";
-          break;
-        }
-
-      if(ms_level > 0)
-        {
-          if(ms_level != current_ms_level)
-            {
-              continue;
-            }
-        }
-      bool get_data = want_binary_data;
-      if(get_data)
-        {
-          get_data = handler.needMsLevelPeakList(ms_level);
-        }
-      qDebug();
-
-      QualifiedMassSpectrum qualified_mass_spectrum =
-        qualifiedMassSpectrum(iter, get_data);
-      qDebug();
-      handler.setQualifiedMassSpectrum(qualified_mass_spectrum);
-      qDebug();
-    }
-  // End of
-  // for(std::size_t iter = 0; iter < spectrum_list_size; iter++)
+  msp_timsData.get()->rawReaderSpectrumCollectionByMsLevel(
+    getMsRunId(), handler, ms_level);
 
   // Now let the loading handler know that the loading of the data has ended.
   // The handler might need this "signal" to perform additional tasks or to
@@ -175,7 +123,7 @@ TimsMsRunReader::readSpectrumCollectionByMsLevel(
 std::size_t
 TimsMsRunReader::spectrumListSize() const
 {
-  return mpa_timsData->getTotalNumberOfScans();
+  return msp_timsData->getTotalNumberOfScans();
 }
 
 
@@ -189,17 +137,60 @@ TimsMsRunReader::hasScanNumbers() const
 bool
 TimsMsRunReader::releaseDevice()
 {
-  delete mpa_timsData;
-  mpa_timsData = nullptr;
+  msp_timsData = nullptr;
   return true;
 }
 
 bool
 TimsMsRunReader::acquireDevice()
 {
-  if(mpa_timsData == nullptr)
+  if(msp_timsData == nullptr)
     {
       initialize();
     }
   return true;
 }
+
+
+XicCoordSPtr
+TimsMsRunReader::newXicCoordSPtrFromSpectrumIndex(std::size_t spectrum_index
+                                                  [[maybe_unused]],
+                                                  pappso::PrecisionPtr precision
+                                                  [[maybe_unused]]) const
+{
+  throw ExceptionNotImplemented(QObject::tr("Not implemented %1 %2 %3")
+                                  .arg(__FILE__)
+                                  .arg(__FUNCTION__)
+                                  .arg(__LINE__));
+}
+
+XicCoordSPtr
+TimsMsRunReader::newXicCoordSPtrFromQualifiedMassSpectrum(
+  const pappso::QualifiedMassSpectrum &mass_spectrum [[maybe_unused]],
+  pappso::PrecisionPtr precision [[maybe_unused]]) const
+{
+  throw ExceptionNotImplemented(QObject::tr("Not implemented %1 %2 %3")
+                                  .arg(__FILE__)
+                                  .arg(__FUNCTION__)
+                                  .arg(__LINE__));
+}
+
+TimsDataSp
+TimsMsRunReader::getTimsDataSPtr()
+{
+  acquireDevice();
+  return msp_timsData;
+}
+
+
+Trace
+TimsMsRunReader::getTicChromatogram()
+{
+  // Use the Sqlite database to fetch the total ion current chromatogram (TIC
+  // chromatogram).
+
+  acquireDevice();
+
+  return msp_timsData->getTicChromatogram();
+}
+
