@@ -29,6 +29,8 @@
 
 #include "timsmsrunreaderms2.h"
 #include "../../exception/exceptionnotimplemented.h"
+#include "../../exception/exceptionnotfound.h"
+#include "../../msrun/xiccoord/xiccoordtims.h"
 #include <QDebug>
 #include <QtConcurrent/QtConcurrent>
 
@@ -59,6 +61,7 @@ pappso::TimsMsRunReaderMs2::initialize()
                     "msp_timsData is null for MsRunId %1")
           .arg(mcsp_msRunId.get()->toString()));
     }
+    
 }
 
 void
@@ -141,17 +144,28 @@ TimsMsRunReaderMs2::qualifiedMassSpectrum(std::size_t spectrum_index,
 {
 
   std::size_t precursor_index = (spectrum_index / 2) + 1;
+  TimsData::SpectrumDescr spectrum_descr;
+  try
+    {
+      spectrum_descr =
+        msp_timsData.get()->getSpectrumDescrWithPrecursorId(precursor_index);
+    }
+  catch(ExceptionNotFound &error)
+    {
+      throw ExceptionNotFound(
+        QObject::tr("spectrum_index %1 NOT FOUND in file %2 : %3")
+          .arg(spectrum_index)
+          .arg(getMsRunId().get()->getFileName())
+          .arg(error.qwhat()));
+    }
 
   if(spectrum_index % 2 == 0)
     {
-      qDebug();
+      qDebug() << "MS1 spectrum precursor_index=" << precursor_index;
       // this is an MS1 spectrum
-      QualifiedMassSpectrum mass_spectrum_ms1 =
-        msp_timsData->getQualifiedMs1MassSpectrumByPrecursorId(
-          spectrum_index, precursor_index, want_binary_data);
-      MassSpectrumId spectrum_id(mass_spectrum_ms1.getMassSpectrumId());
-      spectrum_id.setMsRunId(getMsRunId());
-      mass_spectrum_ms1.setMassSpectrumId(spectrum_id);
+      QualifiedMassSpectrum mass_spectrum_ms1;
+      msp_timsData->getQualifiedMs1MassSpectrumByPrecursorId(
+        getMsRunId(), mass_spectrum_ms1, spectrum_descr, want_binary_data);
       qDebug(); // << mass_spectrum_ms1.toString();
 
       // qDebug() << mass_spectrum_ms1.getMassSpectrumSPtr().get()->toString();
@@ -159,13 +173,23 @@ TimsMsRunReaderMs2::qualifiedMassSpectrum(std::size_t spectrum_index,
     }
   else
     {
-      qDebug();
+      qDebug() << "MS2 spectrum precursor_index=" << precursor_index;
       QualifiedMassSpectrum mass_spectrum_ms2;
+      if(spectrum_descr.ms2_index != spectrum_index)
+        {
+          qDebug();
+          throw PappsoException(
+            QObject::tr("ERROR in %1 %2 %3 spectrum_descr.ms2_index(%4) != "
+                        "spectrum_index(%5)")
+              .arg(__FILE__)
+              .arg(__FUNCTION__)
+              .arg(__LINE__)
+              .arg(spectrum_descr.ms2_index)
+              .arg(spectrum_index));
+        }
+
       msp_timsData->getQualifiedMs2MassSpectrumByPrecursorId(
-        mass_spectrum_ms2, spectrum_index, precursor_index, want_binary_data);
-      MassSpectrumId spectrum_id(mass_spectrum_ms2.getMassSpectrumId());
-      spectrum_id.setMsRunId(getMsRunId());
-      mass_spectrum_ms2.setMassSpectrumId(spectrum_id);
+        getMsRunId(), mass_spectrum_ms2, spectrum_descr, want_binary_data);
       qDebug(); // << mass_spectrum_ms2.toString();
 
       // qDebug() << mass_spectrum_ms2.getMassSpectrumSPtr().get()->toString();
@@ -183,12 +207,9 @@ TimsMsRunReaderMs2::readSpectrumCollection(
 
 void
 TimsMsRunReaderMs2::readSpectrumCollectionByMsLevel(
-  SpectrumCollectionHandlerInterface &handler, unsigned int ms_level [[maybe_unused]])
+  SpectrumCollectionHandlerInterface &handler, unsigned int ms_level)
 {
-
-  const bool want_binary_data = handler.needPeakList();
-  // const bool want_binary_data = false;
-
+  qDebug() << " ms_level=" << ms_level;
   // We'll need it to perform the looping in the spectrum list.
   std::size_t spectrum_list_size = spectrumListSize();
 
@@ -198,103 +219,8 @@ TimsMsRunReaderMs2::readSpectrumCollectionByMsLevel(
   // the user.
   handler.spectrumListHasSize(spectrum_list_size);
 
-  // Iterate in the full list of spectra.
-  bool readAhead = handler.isReadAhead();
-
-  if(readAhead)
-    {
-
-      std::size_t process_list_size = 300;
-
-      struct tmp_item
-      {
-        QualifiedMassSpectrum qualified_mass_spectrum;
-        std::size_t iter;
-        bool want_binary_data;
-      };
-
-      for(std::size_t i = 0; i < spectrum_list_size; i += process_list_size)
-        {
-          qDebug();
-          // If the user of this reader instance wants to stop reading the
-          // spectra, then break this loop.
-          if(handler.shouldStop())
-            {
-              qDebug() << "The operation was cancelled. Breaking the loop.";
-              break;
-            }
-          std::vector<tmp_item> item_list;
-          for(std::size_t iter = 0;
-              (iter < process_list_size) && ((iter + i) < spectrum_list_size);
-              iter++)
-            {
-
-              bool get_data = want_binary_data;
-              if((iter + i) % 2 == 0)
-                { // MS1
-                  get_data = handler.needMsLevelPeakList(1);
-                }
-              else
-                {
-                  get_data = handler.needMsLevelPeakList(2);
-                }
-
-              item_list.push_back(
-                {QualifiedMassSpectrum(), iter + i, get_data});
-            }
-          qDebug() << item_list.size();
-          // Use QtConcurrentBlocking::mapped to apply the scale function to all
-          // the images in the list.
-          QtConcurrent::blockingMap(
-            item_list.begin(), item_list.end(), [this](tmp_item &one_item) {
-              qDebug() << one_item.iter;
-              one_item.qualified_mass_spectrum =
-                qualifiedMassSpectrum(one_item.iter, one_item.want_binary_data);
-
-              // qDebug() << one_item.qualified_mass_spectrum.size() << " " <<
-              // one_item.qualified_mass_spectrum.getMassSpectrumSPtr().get()->toString();
-            });
-
-          qDebug() << item_list.size();
-          for(auto &item : item_list)
-            {
-              // qDebug() << item.qualified_mass_spectrum.getMassSpectrumSPtr()
-              //              .get()
-              //              ->toString();
-              handler.setQualifiedMassSpectrum(item.qualified_mass_spectrum);
-              qDebug();
-            }
-        }
-    }
-  else
-    {
-      for(std::size_t iter = 0; iter < spectrum_list_size; iter++)
-        {
-          qDebug();
-          // If the user of this reader instance wants to stop reading the
-          // spectra, then break this loop.
-          if(handler.shouldStop())
-            {
-              qDebug() << "The operation was cancelled. Breaking the loop.";
-              break;
-            }
-          bool get_data = want_binary_data;
-          if(iter % 2 == 0)
-            { // MS1
-              if(!handler.needMsLevelPeakList(1))
-                {
-                  get_data = false;
-                }
-            }
-          QualifiedMassSpectrum qualified_mass_spectrum =
-            qualifiedMassSpectrum(iter, get_data);
-          handler.setQualifiedMassSpectrum(qualified_mass_spectrum);
-          qDebug();
-        }
-    }
-  // End of
-  // for(std::size_t iter = 0; iter < spectrum_list_size; iter++)
-
+  msp_timsData.get()->ms2ReaderSpectrumCollectionByMsLevel(
+    getMsRunId(), handler, ms_level);
   // Now let the loading handler know that the loading of the data has ended.
   // The handler might need this "signal" to perform additional tasks or to
   // cleanup cruft.
@@ -353,3 +279,49 @@ pappso::TimsMsRunReaderMs2::getTimsDataSPtr()
   acquireDevice();
   return msp_timsData;
 }
+
+
+XicCoordSPtr
+TimsMsRunReaderMs2::newXicCoordSPtrFromSpectrumIndex(
+  std::size_t spectrum_index, pappso::PrecisionPtr precision) const
+{
+  XicCoordTimsSPtr xic_coord  = std::make_shared<XicCoordTims>();
+  std::size_t precursor_index = (spectrum_index / 2) + 1;
+  auto xic = this->msp_timsData.get()->getXicCoordTimsFromPrecursorId(
+    precursor_index, precision);
+
+  xic_coord.get()->mzRange      = xic.mzRange;
+  xic_coord.get()->rtTarget     = xic.rtTarget;
+  xic_coord.get()->scanNumBegin = xic.scanNumBegin;
+  xic_coord.get()->scanNumEnd   = xic.scanNumEnd;
+
+
+  return xic_coord;
+}
+
+pappso::XicCoordSPtr
+TimsMsRunReaderMs2::newXicCoordSPtrFromQualifiedMassSpectrum(
+  const pappso::QualifiedMassSpectrum &mass_spectrum,
+  pappso::PrecisionPtr precision) const
+{
+  return newXicCoordSPtrFromSpectrumIndex(
+    mass_spectrum.getMassSpectrumId().getSpectrumIndex(), precision);
+}
+
+std::vector<double>
+pappso::TimsMsRunReaderMs2::getRetentionTimeLine()
+{
+  return msp_timsData.get()->getRetentionTimeLine();
+}
+
+Trace
+TimsMsRunReaderMs2::getTicChromatogram()
+{
+  // Use the Sqlite database to fetch the total ion current chromatogram (TIC
+  // chromatogram).
+
+  acquireDevice();
+
+  return msp_timsData->getTicChromatogram();
+}
+
