@@ -60,6 +60,14 @@ class PMSPP_LIB_DECL TimsMsRunReaderMs2 : public MsRunReader
   readSpectrumCollection(SpectrumCollectionHandlerInterface &handler) override;
 
 
+  virtual pappso::XicCoordSPtr newXicCoordSPtrFromSpectrumIndex(
+    std::size_t spectrum_index, pappso::PrecisionPtr precision) const override;
+
+  virtual pappso::XicCoordSPtr newXicCoordSPtrFromQualifiedMassSpectrum(
+    const pappso::QualifiedMassSpectrum &mass_spectrum,
+    pappso::PrecisionPtr precision) const override;
+
+
   virtual void
   readSpectrumCollectionByMsLevel(SpectrumCollectionHandlerInterface &handler,
                                   unsigned int ms_level) override;
@@ -90,6 +98,15 @@ class PMSPP_LIB_DECL TimsMsRunReaderMs2 : public MsRunReader
    */
   virtual TimsDataSp getTimsDataSPtr();
 
+
+  /** @brief retention timeline
+   * get retention times along the MSrun in seconds
+   * @return vector of retention times (seconds)
+   */
+  virtual std::vector<double> getRetentionTimeLine() override;
+
+  virtual Trace getTicChromatogram() override;
+
   protected:
   virtual void initialize() override;
   virtual bool accept(const QString &file_name) const override;
