@@ -17,6 +17,7 @@
 #include "../pappsoexception.h"
 #include "../exception/exceptionnotfound.h"
 #include "../exception/exceptionnotpossible.h"
+#include "../exception/exceptionnotimplemented.h"
 
 
 namespace pappso
@@ -309,5 +310,27 @@ XyMsRunReader::acquireDevice()
   return true;
 }
 
+XicCoordSPtr
+XyMsRunReader::newXicCoordSPtrFromSpectrumIndex(std::size_t spectrum_index
+                                                [[maybe_unused]],
+                                                pappso::PrecisionPtr precision
+                                                [[maybe_unused]]) const
+{
+  throw ExceptionNotImplemented(QObject::tr("Not implemented %1 %2 %3")
+                                  .arg(__FILE__)
+                                  .arg(__FUNCTION__)
+                                  .arg(__LINE__));
+}
+
+XicCoordSPtr
+XyMsRunReader::newXicCoordSPtrFromQualifiedMassSpectrum(
+  const pappso::QualifiedMassSpectrum &mass_spectrum [[maybe_unused]],
+  pappso::PrecisionPtr precision [[maybe_unused]]) const
+{
+  throw ExceptionNotImplemented(QObject::tr("Not implemented %1 %2 %3")
+                                  .arg(__FILE__)
+                                  .arg(__FUNCTION__)
+                                  .arg(__LINE__));
+}
 
 } // namespace pappso
