@@ -73,7 +73,7 @@ MzRange::MzRange(pappso_double mz,
 MzRange::MzRange(const MzRange &other)
   : m_mz(other.m_mz), m_delta(other.m_delta)
 {
-  // std::cout << "MzRange::MzRange (const MzRange & other)" << endl;
+  // std::cout << "MzRange::MzRange (const MzRange & other)" << std::endl;
 }
 
 
@@ -92,6 +92,24 @@ MzRange::operator=(const MzRange &other)
 }
 
 
+MzRange &
+MzRange::operator+=(const MzRange &other)
+{
+  m_mz += other.m_mz;
+  m_delta += other.m_delta;
+
+  return *this;
+}
+
+MzRange &
+MzRange::operator*=(double number)
+{
+  m_mz *= number;
+  m_delta *= number;
+
+  return *this;
+}
+
 pappso_double
 MzRange::getMz() const
 {
