@@ -77,7 +77,7 @@ PrecisionFactory::fromString(const QString &str)
   // If there only once component, that is, <string> is omitted and charge is
   // not provided, then "dalton" is considered.
 
-  QStringList list = str.split(QRegExp("\\s+"), QString::SkipEmptyParts);
+  QStringList list = str.split(QRegExp("\\s+"), Qt::SkipEmptyParts);
 
   if(list.size() > 0)
     {
