@@ -30,14 +30,15 @@ class PMSPP_LIB_DECL MassSpectrumMinusCombiner : public MassSpectrumCombiner
   MassSpectrumMinusCombiner(int decimal_places);
   MassSpectrumMinusCombiner(MassSpectrumMinusCombinerCstSPtr other);
   MassSpectrumMinusCombiner(const MassSpectrumMinusCombiner &other);
-  MassSpectrumMinusCombiner(const MassSpectrumCombiner &&other);
 
   virtual ~MassSpectrumMinusCombiner();
 
-  protected:
-  private:
-  virtual MapTrace &combineNoFilteringStep(MapTrace &map_trace,
-                                           const Trace &trace) const;
+  MassSpectrumMinusCombiner &operator=(const MassSpectrumMinusCombiner &other);
+
+  virtual MapTrace &combine(MapTrace &map_trace,
+                            const Trace &trace) const override;
+  virtual MapTrace &combine(MapTrace &map_trace_out,
+                            const MapTrace &map_trace_in) const override;
 };
 
 
