@@ -100,22 +100,10 @@ MzIntegrationParams::MzIntegrationParams(const MzIntegrationParams &other)
     mp_precision(other.mp_precision),
     m_applyMzShift(other.m_applyMzShift),
     m_mzShift(other.m_mzShift),
-    m_removeZeroValDataPoints(other.m_removeZeroValDataPoints),
-    m_applySavGolFilter(other.m_applySavGolFilter)
+    m_removeZeroValDataPoints(other.m_removeZeroValDataPoints)
 {
   if(mp_precision == nullptr)
     mp_precision = pappso::PrecisionFactory::getPpmInstance(20);
-
-  m_savGolParams.initialize(other.m_savGolParams);
-}
-
-
-MzIntegrationParams::MzIntegrationParams(
-  const pappso::SavGolParams &savGolParams)
-{
-  m_binningType = BinningType::NONE;
-  mp_precision  = pappso::PrecisionFactory::getPpmInstance(20);
-  setSavGolParams(savGolParams);
 }
 
 
@@ -144,10 +132,6 @@ MzIntegrationParams::operator=(const MzIntegrationParams &other)
   m_mzShift                 = other.m_mzShift;
   m_removeZeroValDataPoints = other.m_removeZeroValDataPoints;
 
-  setSavGolParams(other.m_savGolParams);
-
-  m_applySavGolFilter = other.m_applySavGolFilter;
-
   return *this;
 }
 
@@ -276,50 +260,6 @@ MzIntegrationParams::getMzShift() const
 }
 
 
-void
-MzIntegrationParams::setApplySavGolFilter(bool applySavGolFilter)
-{
-  m_applySavGolFilter = applySavGolFilter;
-}
-
-
-bool
-MzIntegrationParams::isApplySavGolFilter() const
-{
-  return m_applySavGolFilter;
-}
-
-
-void
-MzIntegrationParams::setSavGolParams(
-  int nL, int nR, int m, int lD, bool convolveWithNr)
-{
-  m_savGolParams.nL             = nL;
-  m_savGolParams.nR             = nR;
-  m_savGolParams.m              = m;
-  m_savGolParams.lD             = lD;
-  m_savGolParams.convolveWithNr = convolveWithNr;
-}
-
-
-void
-MzIntegrationParams::setSavGolParams(const pappso::SavGolParams &params)
-{
-  m_savGolParams.nL             = params.nL;
-  m_savGolParams.nR             = params.nR;
-  m_savGolParams.m              = params.m;
-  m_savGolParams.lD             = params.lD;
-  m_savGolParams.convolveWithNr = params.convolveWithNr;
-}
-
-
-pappso::SavGolParams
-MzIntegrationParams::getSavGolParams() const
-{
-  return m_savGolParams;
-}
-
-
 //! Reset the instance to default values.
 void
 MzIntegrationParams::reset()
@@ -334,14 +274,6 @@ MzIntegrationParams::reset()
   m_applyMzShift            = false;
   m_mzShift                 = 0;
   m_removeZeroValDataPoints = false;
-
-  m_savGolParams.nL             = 15;
-  m_savGolParams.nR             = 15;
-  m_savGolParams.m              = 4;
-  m_savGolParams.lD             = 0;
-  m_savGolParams.convolveWithNr = false;
-
-  m_applySavGolFilter = false;
 }
 
 
@@ -790,25 +722,6 @@ MzIntegrationParams::toString(int offset, const QString &spacer) const
   text += QString("Remove 0-val data points: %1\n")
             .arg(m_removeZeroValDataPoints ? "true" : "false");
 
-  // Finally the Savitzy-Golay parameters (if requested)
-
-  if(m_applySavGolFilter)
-    {
-      text += lead;
-      text += spacer;
-      text.append("Savitzky-Golay parameters\n");
-      text += lead;
-      text += spacer;
-      text += spacer;
-      text +=
-        QString("nL = %1 ; nR = %2 ; m = %3 ; lD = %4 ; convolveWithNr = %5\n")
-          .arg(m_savGolParams.nL)
-          .arg(m_savGolParams.nR)
-          .arg(m_savGolParams.m)
-          .arg(m_savGolParams.lD)
-          .arg(m_savGolParams.convolveWithNr ? "true" : "false");
-    }
-
   return text;
 }
 
