@@ -31,13 +31,13 @@ TraceMinusCombiner::TraceMinusCombiner(int decimal_places)
 
 
 TraceMinusCombiner::TraceMinusCombiner(const TraceMinusCombiner &other)
-  : TraceCombiner(other.m_decimalPlaces)
+  : TraceCombiner(other)
 {
 }
 
 
 TraceMinusCombiner::TraceMinusCombiner(TraceMinusCombinerCstSPtr other)
-  : TraceCombiner(other->m_decimalPlaces)
+  : TraceCombiner(other)
 {
 }
 
@@ -116,40 +116,7 @@ TraceMinusCombiner::combine(MapTrace &map_trace_out,
   if(!map_trace_in.size())
     return map_trace_out;
 
-  for(auto &map_pair : map_trace_in)
-    {
-
-      // If the data point is 0-intensity, then do nothing!
-      if(!map_pair.second)
-        continue;
-
-      double x = Utils::roundToDecimals(map_pair.first, m_decimalPlaces);
-
-      std::map<double, double>::iterator map_iterator;
-
-      std::pair<std::map<pappso_double, pappso_double>::iterator, bool> result;
-
-      result = map_trace_out.insert(
-        std::pair<pappso_double, pappso_double>(x, -map_pair.second));
-
-      if(result.second)
-        {
-          // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << " ()";
-          // The new element was inserted, we have nothing to do.
-        }
-      else
-        {
-          // The key already existed! The item was not inserted. We need to
-          // update the value.
-
-          result.first->second -= map_pair.second;
-        }
-    }
-
-  // qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << " ()"
-  //<< "Prior to returning map_trace_out, its size is:" << map_trace_out.size();
-
-  return map_trace_out;
+  return combine(map_trace_out, map_trace_in.toTrace());
 }
 
 
