@@ -27,7 +27,7 @@
 
 #pragma once
 
-#include "filterinterface.h"
+#include "filternameinterface.h"
 #include <cstddef>
 #include "../../exportinmportconfig.h"
 
@@ -228,4 +228,61 @@ class PMSPP_LIB_DECL FilterScaleFactorY : public FilterInterface
   double getScaleFactorY() const;
 };
 
+
+/** @brief removes a value to all Y values
+ */
+class PMSPP_LIB_DECL FilterRemoveY : public FilterInterface
+{
+  private:
+  double m_valueToRemove = 0;
+
+  public:
+  FilterRemoveY(double valueToRemove);
+  FilterRemoveY(const FilterRemoveY &other);
+  virtual ~FilterRemoveY(){};
+
+  FilterRemoveY &operator=(const FilterRemoveY &other);
+
+  Trace &filter(Trace &data_points) const override;
+
+  double getValue() const;
+};
+
+
+/** @brief removes a value found by quantile to all Y values
+ *
+ * sort all values by Y intensity and take the iest value located at the defined
+ * quantile the use it to remove this value to all Y intensities
+ */
+class PMSPP_LIB_DECL FilterQuantileBasedRemoveY : public FilterNameInterface
+{
+  public:
+  FilterQuantileBasedRemoveY(double quantile_threshold);
+
+  /**
+   * @param strBuildParams string to build the filter
+   * "passQuantileBasedRemoveY|0.6"
+   */
+  FilterQuantileBasedRemoveY(const QString &strBuildParams);
+
+  FilterQuantileBasedRemoveY(const FilterQuantileBasedRemoveY &other);
+  virtual ~FilterQuantileBasedRemoveY(){};
+
+  FilterQuantileBasedRemoveY &
+  operator=(const FilterQuantileBasedRemoveY &other);
+
+  Trace &filter(Trace &data_points) const override;
+
+  double getQuantileThreshold() const;
+
+  virtual QString name() const override;
+  QString toString() const override;
+
+  protected:
+  void buildFilterFromString(const QString &strBuildParams) override;
+
+  private:
+  double m_quantile = 0;
+};
+
 } // namespace pappso
