@@ -31,19 +31,20 @@
 #include <QSettings>
 #include <QThread>
 #include <QThreadPool>
-#include "../../pappsoexception.h"
+#include "../../exception/exceptioninterrupted.h"
 #include "../../msfile/msfileaccessor.h"
 #include "../../msrun/private/timsmsrunreaderms2.h"
-#include "../../processing/filters/filterpseudocentroid.h"
 #include "../../processing/filters/filtertriangle.h"
 #include "../../processing/filters/filterchargedeconvolution.h"
 #include "../../msrun/output/mzxmloutput.h"
-#include "xtandeminputsaxhandler.h"
-#include "xtandemoutputsaxhandler.h"
-#include "xtandempresetsaxhandler.h"
+#include "wraptandemresults.h"
+#include "xtandempresetreader.h"
+#include "wraptandeminput.h"
 
 namespace pappso
 {
+
+
 TandemWrapperRun::TandemWrapperRun(const QString &tandem_binary,
                                    const QString &tmp_dir)
 {
@@ -200,26 +201,39 @@ TandemWrapperRun::checkXtandemVersion(const QString &tandem_bin_path)
   return version_return;
 }
 
-
-bool
-TandemWrapperRun::shouldIstop()
-{
-  return false;
-}
-
-
 void
 TandemWrapperRun::readyReadStandardOutput()
 {
-  *mp_outputStream << m_xtProcess->readAllStandardOutput();
-  mp_outputStream->flush();
+  QString message(m_xtProcess->readAllStandardOutput());
+  mp_monitor->appendText(message);
+
+  if(message.toLower().contains("error"))
+    {
+      throw pappso::XtandemError(message);
+    }
+
+  if(mp_monitor->shouldIstop())
+    {
+      m_xtProcess->kill();
+      delete m_xtProcess;
+      m_xtProcess = nullptr;
+      throw pappso::ExceptionInterrupted(
+        QObject::tr("X!Tandem stopped by the user"));
+    }
 }
 
 void
 TandemWrapperRun::readyReadStandardError()
 {
-  *mp_errorStream << m_xtProcess->readAllStandardError();
-  mp_errorStream->flush();
+  mp_monitor->appendText(m_xtProcess->readAllStandardError());
+  if(mp_monitor->shouldIstop())
+    {
+      m_xtProcess->kill();
+      delete m_xtProcess;
+      m_xtProcess = nullptr;
+      throw pappso::ExceptionInterrupted(
+        QObject::tr("X!Tandem stopped by the user"));
+    }
 }
 
 void
@@ -228,20 +242,24 @@ TandemWrapperRun::writeFinalTandemOutput(
   const QString &final_tandem_output,
   const QString &original_msdata_file_name)
 {
+  mp_monitor->setStatus(QObject::tr("Rewriting X!Tandem XML result file"));
 
-  XtandemOutputSaxHandler wrap_output(final_tandem_output,
-                                      original_msdata_file_name);
+  WrapTandemResults wrap_output(final_tandem_output, original_msdata_file_name);
 
   wrap_output.setInputParameters("spectrum, timstof MS2 filters",
                                  getMs2FilterSuiteString());
+  wrap_output.setInputParameters("spectrum, mzFormat",
+                                 QString("%1").arg((int)m_mzFormat));
 
-  QFile qfile(tmp_tandem_output);
-  QXmlInputSource xmlInputSource(&qfile);
-  QXmlSimpleReader simplereader;
-  simplereader.setContentHandler(&wrap_output);
-  simplereader.setErrorHandler(&wrap_output);
+  if(m_convertMzDataUsingSpectrumIndex)
+    {
+      wrap_output.setInputParameters("output, spectrum index", "true");
+    }
+  else
+    {
+    }
 
-  if(simplereader.parse(xmlInputSource))
+  if(wrap_output.readFile(tmp_tandem_output))
     {
     }
   else
@@ -258,15 +276,10 @@ TandemWrapperRun::readTandemPresetFile(const QString &tandem_preset_file)
 {
   // get number of threads and centroid parameters from tandem preset
 
-  XtandemPresetSaxHandler preset_handler;
+  XtandemPresetReader preset_handler;
 
-  QFile qfile(tandem_preset_file);
-  QXmlInputSource xmlInputSource(&qfile);
-  QXmlSimpleReader simplereader;
-  simplereader.setContentHandler(&preset_handler);
-  simplereader.setErrorHandler(&preset_handler);
 
-  if(simplereader.parse(xmlInputSource))
+  if(preset_handler.readFile(tandem_preset_file))
     {
 
       int ideal_number_of_thread = QThread::idealThreadCount();
@@ -318,15 +331,35 @@ TandemWrapperRun::wrapTandemInputFile(const QString &tandem_input_file)
   // store original ms data file name
   // create new mzXML data file in temporary directory
   // create new tandem input file based on new mzXML file
+
+
   QString mzxml_data_file_name =
     mpa_temporaryDirectory->filePath("msdata.mzxml");
   QString wrapped_tandem_input =
     mpa_temporaryDirectory->filePath("input_tandem.xml");
   QString wrapped_tandem_output =
     mpa_temporaryDirectory->filePath("output_tandem.xml");
-  XtandemInputSaxHandler wrap_input(
+
+  WrapTandemInput wrap_tandem_input(
     mzxml_data_file_name, wrapped_tandem_input, wrapped_tandem_output);
 
+
+  if(wrap_tandem_input.readFile(tandem_input_file))
+    {
+    }
+  else
+    {
+      throw pappso::PappsoException(
+        QObject::tr("Error reading %1 X!Tandem input file :\n %2")
+          .arg(tandem_input_file)
+          .arg(wrap_tandem_input.errorString()));
+    }
+
+
+  /*
+   *
+  XtandemInputSaxHandler wrap_input(
+    mzxml_data_file_name, wrapped_tandem_input, wrapped_tandem_output);
   QFile qfile(tandem_input_file);
   if(!qfile.exists())
     {
@@ -349,98 +382,129 @@ TandemWrapperRun::wrapTandemInputFile(const QString &tandem_input_file)
           .arg(tandem_input_file)
           .arg(wrap_input.errorString()));
     }
-
+*/
   // get number of threads and centroid parameters from tandem preset
-  readTandemPresetFile(wrap_input.getOriginalTandemPresetFileName());
+  readTandemPresetFile(wrap_tandem_input.getOriginalTandemPresetFileName());
 
 
   // convert to mzXML
-  QString original_msdata_file_name = wrap_input.getOriginalMsDataFileName();
-  convertOrginalMsData2mzXmlData(original_msdata_file_name,
-                                 mzxml_data_file_name);
+  QString original_msdata_file_name =
+    wrap_tandem_input.getOriginalMsDataFileName();
+  if(convertOrginalMsData2mzXmlData(original_msdata_file_name,
+                                    mzxml_data_file_name))
+    {
 
 
-  // launch tandem
-  runTandem(wrapped_tandem_input);
+      // launch tandem
+      runTandem(wrapped_tandem_input);
 
-  // rewrite tandem result file
-  writeFinalTandemOutput(wrapped_tandem_output,
-                         wrap_input.getOriginalTandemOutputFileName(),
-                         original_msdata_file_name);
+      // rewrite tandem result file
+      writeFinalTandemOutput(
+        wrapped_tandem_output,
+        wrap_tandem_input.getOriginalTandemOutputFileName(),
+        original_msdata_file_name);
+    }
+  else
+    {
+      // launch tandem on original file
+      runTandem(tandem_input_file);
+    }
 }
 
-void
+bool
 TandemWrapperRun::convertOrginalMsData2mzXmlData(const QString &origin,
-                                                 const QString &target) const
+                                                 const QString &target)
 {
   qDebug();
   pappso::MsFileAccessor origin_access(origin, "runa1");
   origin_access.setPreferedFileReaderType(pappso::MzFormat::brukerTims,
                                           pappso::FileReaderType::tims_ms2);
   origin_access.getMsRunIds();
+  m_mzFormat = origin_access.getFileFormat();
 
-  pappso::MsRunReaderSPtr p_reader;
-  p_reader = origin_access.msRunReaderSp(origin_access.getMsRunIds().front());
-
-  pappso::TimsMsRunReaderMs2 *tims2_reader =
-    dynamic_cast<pappso::TimsMsRunReaderMs2 *>(p_reader.get());
-  if(tims2_reader != nullptr)
+  if(origin_access.getFileFormat() == pappso::MzFormat::brukerTims)
     {
-      qDebug();
-      tims2_reader->setMs2BuiltinCentroid(true);
-
-      if(msp_ms2FilterSuiteString != nullptr)
-        {
-          tims2_reader->setMs2FilterCstSPtr(msp_ms2FilterSuiteString);
-        }
-      qDebug();
+      m_convertMzDataUsingSpectrumIndex = true;
     }
 
-
-  pappso::MzxmlOutput *p_mzxml_output;
-  QFile output_file(target);
-  // qDebug() << " TsvDirectoryWriter::writeSheet " <<
-  // QFileInfo(*_p_ofile).absoluteFilePath();
-  if(output_file.open(QIODevice::WriteOnly))
+  if((origin_access.getFileFormat() == pappso::MzFormat::mzML) ||
+     (origin_access.getFileFormat() == pappso::MzFormat::brukerTims))
     {
-      p_mzxml_output =
-        new pappso::MzxmlOutput(QTextStream(&output_file).device());
+      mp_monitor->setStatus(
+        QObject::tr("Converting %1 to mzXML %2").arg(origin).arg(target));
+      pappso::MsRunReaderSPtr p_reader;
+      p_reader =
+        origin_access.msRunReaderSp(origin_access.getMsRunIds().front());
 
-      p_mzxml_output->maskMs1(true);
+      pappso::TimsMsRunReaderMs2 *tims2_reader =
+        dynamic_cast<pappso::TimsMsRunReaderMs2 *>(p_reader.get());
+      if(tims2_reader != nullptr)
+        {
+          qDebug();
+          tims2_reader->setMs2BuiltinCentroid(true);
 
-      p_mzxml_output->setReadAhead(true);
+          if(msp_ms2FilterSuiteString != nullptr)
+            {
+              tims2_reader->setMs2FilterCstSPtr(msp_ms2FilterSuiteString);
+            }
+          qDebug();
+        }
 
-      p_mzxml_output->write(p_reader.get());
 
-      p_mzxml_output->close();
+      pappso::MzxmlOutput *p_mzxml_output;
+      QFile output_file(target);
+      // qDebug() << " TsvDirectoryWriter::writeSheet " <<
+      // QFileInfo(*_p_ofile).absoluteFilePath();
+      if(output_file.open(QIODevice::WriteOnly))
+        {
+          p_mzxml_output = new pappso::MzxmlOutput(
+            *mp_monitor, QTextStream(&output_file).device());
 
-      delete p_mzxml_output;
+          p_mzxml_output->maskMs1(true);
+
+          p_mzxml_output->setReadAhead(true);
+
+          p_mzxml_output->write(p_reader.get());
+
+          p_mzxml_output->close();
+
+          delete p_mzxml_output;
+        }
+      else
+        {
+          throw pappso::PappsoException(
+            QObject::tr("unable to write into %1 mzXML output file")
+              .arg(target));
+        }
+
+      qDebug();
+      return true;
     }
   else
-    {
-      throw pappso::PappsoException(
-        tr("unable to write into %1 mzXML output file").arg(target));
+    { // other mz data formats
+      return false;
     }
-
-  qDebug();
+  return true;
 }
 
 void
-TandemWrapperRun::run(const QString &tandem_input_file,
-                      QTextStream &output_stream,
-                      QTextStream &error_stream)
+TandemWrapperRun::run(UiMonitorInterface &monitor,
+                      const QString &tandem_input_file)
 {
-  mp_outputStream = &output_stream;
-  mp_errorStream  = &error_stream;
+  mp_monitor = &monitor;
 
   wrapTandemInputFile(tandem_input_file);
-  mp_outputStream = nullptr;
-  mp_errorStream  = nullptr;
+  mp_monitor = nullptr;
 }
 void
 TandemWrapperRun::runTandem(const QString &tandem_input_file)
 {
-
+  if(mp_monitor->shouldIstop())
+    {
+      throw pappso::ExceptionInterrupted(
+        QObject::tr("X!Tandem stopped by the user processing on file %1")
+          .arg(tandem_input_file));
+    }
   m_xtProcess = new QProcess();
   QStringList arguments;
 
@@ -464,6 +528,8 @@ TandemWrapperRun::runTandem(const QString &tandem_input_file)
 
   qDebug() << m_tandemBinary << " " << m_xtProcess->arguments();
 
+  mp_monitor->setStatus(QObject::tr("Running X!Tandem"));
+
   if(!m_xtProcess->waitForStarted())
     {
       throw pappso::PappsoException(
@@ -471,16 +537,16 @@ TandemWrapperRun::runTandem(const QString &tandem_input_file)
     }
 
   qDebug() << m_tandemBinary << " " << m_xtProcess->arguments();
-
-  while(m_xtProcess->waitForFinished(m_maxTandemRunTimeMs))
+  while(m_xtProcess->waitForFinished(m_maxTandemRunTimeMs) == false)
     {
       //_p_monitor->appendText(xt_process->readAll().data());
       // data.append(xt_process->readAll());
-      if(shouldIstop())
+      if(mp_monitor->shouldIstop())
         {
           m_xtProcess->kill();
           delete m_xtProcess;
-          throw pappso::PappsoException(
+          m_xtProcess = nullptr;
+          throw pappso::ExceptionInterrupted(
             QObject::tr("X!Tandem stopped by the user processing on file %1")
               .arg(tandem_input_file));
         }
@@ -489,7 +555,7 @@ TandemWrapperRun::runTandem(const QString &tandem_input_file)
   QProcess::ExitStatus Status = m_xtProcess->exitStatus();
 
   delete m_xtProcess;
-  if(Status != 0)
+  if(Status != QProcess::ExitStatus::NormalExit)
     {
       // != QProcess::NormalExit
       throw pappso::PappsoException(
