@@ -31,15 +31,33 @@
 #include <QObject>
 #include <QProcess>
 #include <QTemporaryDir>
+#include <QMutex>
 
 #include "../../exportinmportconfig.h"
 #include "../../processing/filters/filtersuitestring.h"
+#include "../uimonitor/uimonitorinterface.h"
+#include "../../pappsoexception.h"
+#include "../../types.h"
 
 /**
  * @todo write docs
  */
 namespace pappso
 {
+class XtandemError : public PappsoException
+{
+  public:
+  XtandemError(const QString &message) throw() : PappsoException(message)
+  {
+  }
+
+  virtual QException *
+  clone() const override
+  {
+    return new XtandemError(*this);
+  }
+};
+
 class PMSPP_LIB_DECL TandemWrapperRun : public QObject
 {
   Q_OBJECT
@@ -60,13 +78,10 @@ class PMSPP_LIB_DECL TandemWrapperRun : public QObject
    * A default value of "chargeDeconvolution|0.02dalton" is recommended for this
    * additional tandem input parameter
    *
+   * @param monitor user interface monitor
    * @param tandem_input_file tandem xml input file
-   * @param output_stream standard output where to write tandem stdout
-   * @param error_stream standard error where to write tandem stderr
    */
-  void run(const QString &tandem_input_file,
-           QTextStream &output_stream,
-           QTextStream &error_stream);
+  void run(UiMonitorInterface &monitor, const QString &tandem_input_file);
 
   void readTandemPresetFile(const QString &tandem_preset_file);
 
@@ -81,14 +96,17 @@ class PMSPP_LIB_DECL TandemWrapperRun : public QObject
    */
   ~TandemWrapperRun();
 
+  signals:
+  void tandemProgressMessage(QString message);
+
+
   private:
   void setTandemBinaryPath(const QString &tandem_binary_path);
-  bool shouldIstop();
   const QString checkXtandemVersion(const QString &tandem_bin_path);
   void wrapTandemInputFile(const QString &tandem_input_file);
 
-  void convertOrginalMsData2mzXmlData(const QString &origin,
-                                      const QString &target) const;
+  bool convertOrginalMsData2mzXmlData(const QString &origin,
+                                      const QString &target);
 
 
   /** @brief run a tandem job
@@ -113,17 +131,20 @@ class PMSPP_LIB_DECL TandemWrapperRun : public QObject
   void readyReadStandardError();
 
   private:
+  UiMonitorInterface *mp_monitor;
   QString m_tandemBinary;
   QString m_tandemVersion;
   QString m_tmpDir;
-  int m_maxTandemRunTimeMs = (60000 * 60 * 24); // 1 day
-  QProcess *m_xtProcess    = nullptr;
+  int m_maxTandemRunTimeMs =
+    1000; // If msecs is -1, this function will not time out.
+  QProcess *m_xtProcess = nullptr;
 
   std::shared_ptr<FilterSuiteString> msp_ms2FilterSuiteString = nullptr;
 
-  QTextStream *mp_outputStream = nullptr;
-  QTextStream *mp_errorStream  = nullptr;
-
   QTemporaryDir *mpa_temporaryDirectory = nullptr;
+
+  bool m_convertMzDataUsingSpectrumIndex = false;
+
+  pappso::MzFormat m_mzFormat = pappso::MzFormat::unknown;
 };
 } // namespace pappso
