@@ -123,7 +123,7 @@ PeptideModificatorPipeline::privAddFixedModificationString(
                     "addLabeledModificationString function"));
     }
   QStringList mod_list_str =
-    mod_str.simplified().replace(" ", "").split(",", QString::SkipEmptyParts);
+    mod_str.simplified().replace(" ", "").split(",", Qt::SkipEmptyParts);
   for(auto i = 0; i < mod_list_str.size(); ++i)
     {
       parseFixedModification(mod_list_str[i], Nter, Cter, else_prot);
@@ -138,7 +138,7 @@ PeptideModificatorPipeline::parseFixedModification(const QString &mod_str,
                                                    bool else_prot)
 {
 
-  QStringList str_split = mod_str.split("@", QString::SkipEmptyParts);
+  QStringList str_split = mod_str.split("@", Qt::SkipEmptyParts);
 
   pappso::AaModificationP aa_mod = AaModification::getInstance(str_split[0]);
 
@@ -197,7 +197,7 @@ PeptideModificatorPipeline::privAddPotentialModificationString(
     }
 
   QStringList mod_list_str =
-    mod_str.simplified().replace(" ", "").split(",", QString::SkipEmptyParts);
+    mod_str.simplified().replace(" ", "").split(",", Qt::SkipEmptyParts);
   for(auto i = 0; i < mod_list_str.size(); ++i)
     {
       parsePotentialModification(mod_list_str[i], Nter, Cter, else_prot);
@@ -212,10 +212,10 @@ PeptideModificatorPipeline::parsePotentialModification(const QString &mod_str,
                                                        bool else_prot)
 {
 
-  QStringList str_split = mod_str.split("@", QString::SkipEmptyParts);
+  QStringList str_split = mod_str.split("@", Qt::SkipEmptyParts);
 
   QString mod_acc_str       = str_split[0];
-  QStringList str_acc_split = mod_acc_str.split("(", QString::SkipEmptyParts);
+  QStringList str_acc_split = mod_acc_str.split("(", Qt::SkipEmptyParts);
   pappso::AaModificationP aa_mod =
     AaModification::getInstance(str_acc_split[0]);
 
@@ -226,7 +226,7 @@ PeptideModificatorPipeline::parsePotentialModification(const QString &mod_str,
   if(str_acc_split.length() == 2)
     {
       QStringList max_num_str_list =
-        str_acc_split[1].replace(")", "").split("-", QString::SkipEmptyParts);
+        str_acc_split[1].replace(")", "").split("-", Qt::SkipEmptyParts);
       if(max_num_str_list.length() == 1)
         {
           mod->setModificationCounter(max_num_str_list[0].toUInt());
@@ -285,7 +285,7 @@ PeptideModificatorPipeline::addLabeledModificationString(const QString &mod_str)
 
 
   QStringList mod_list_str =
-    mod_str.simplified().replace(" ", "").split(",", QString::SkipEmptyParts);
+    mod_str.simplified().replace(" ", "").split(",", Qt::SkipEmptyParts);
   for(auto i = 0; i < mod_list_str.size(); ++i)
     {
       parseLabeledModification(mod_list_str[i], true, true, true);
@@ -311,7 +311,7 @@ PeptideModificatorPipeline::parseLabeledModification(const QString &mod_str,
                                                      bool else_prot)
 {
 
-  QStringList str_split          = mod_str.split("@", QString::SkipEmptyParts);
+  QStringList str_split          = mod_str.split("@", Qt::SkipEmptyParts);
   pappso::AaModificationP aa_mod = AaModification::getInstance(str_split[0]);
 
   PeptideFixedModificationBuilder *mod =
