@@ -54,6 +54,9 @@ class PMSPP_LIB_DECL MapTrace : public std::map<pappso_double, pappso_double>
   std::vector<pappso_double> xValues();
   std::vector<pappso_double> yValues();
 
+  void insertOrUpdate(const DataPoint &data_point);
+  void insertOrUpdate(const Trace &trace);
+
   Trace toTrace() const;
   QString toString() const;
 
