@@ -219,11 +219,38 @@ meanYTrace(std::vector<DataPoint>::const_iterator begin,
   return (sumYTrace(begin, end, 0) / nb_element);
 }
 
+
+double
+quantileYTrace(std::vector<DataPoint>::const_iterator begin,
+               std::vector<DataPoint>::const_iterator end,
+               double quantile)
+{
+  std::size_t nb_element = distance(begin, end);
+  if(nb_element == 0)
+    throw ExceptionOutOfRange(
+      QObject::tr("unable to compute quantile on a trace of size 0"));
+
+
+  std::size_t ieth_element = std::round((double)nb_element * quantile);
+  if(ieth_element > nb_element)
+    throw ExceptionOutOfRange(
+      QObject::tr("quantile value must be lower than 1"));
+
+
+  std::vector<DataPoint> data(begin, end);
+  std::nth_element(
+    data.begin(),
+    data.begin() + ieth_element,
+    data.end(),
+    [](const DataPoint &a, const DataPoint &b) { return a.y < b.y; });
+  return data[ieth_element].y;
+}
+
 double
 medianYTrace(std::vector<DataPoint>::const_iterator begin,
              std::vector<DataPoint>::const_iterator end)
 {
-  pappso_double nb_element = distance(begin, end);
+  std::size_t nb_element = distance(begin, end);
   if(nb_element == 0)
     throw ExceptionOutOfRange(
       QObject::tr("unable to compute median on a trace of size 0"));
@@ -681,12 +708,12 @@ Trace::containsX(pappso_double value, PrecisionPtr precision_p) const
                        // this code fails if the following cout statement is
                        // missing.
 
-                       //std::cout << std::setprecision(10)
-                                 //<< "Testing data_point.x: " << data_point.x
-                                 //<< std::endl;
+                       // std::cout << std::setprecision(10)
+                       //<< "Testing data_point.x: " << data_point.x
+                       //<< std::endl;
 
-                     // For this reason I had to deactivate the related tests
-                     // for i386 in tests/test_trace.cpp
+                       // For this reason I had to deactivate the related tests
+                       // for i386 in tests/test_trace.cpp
 
                        double diff_to_left_most  = data_point.x - left_most;
                        double diff_to_right_most = data_point.x - right_most;
