@@ -66,7 +66,8 @@ class PMSPP_LIB_DECL Utils
 
   static int zeroDecimalsInValue(pappso_double value);
   static pappso_double roundToDecimals(pappso_double value, int decimal_places);
-  static long long int roundToDecimal32bitsAsLongLongInt(pappso::pappso_double input);
+  static long long int
+  roundToDecimal32bitsAsLongLongInt(pappso::pappso_double input);
 
   static std::string toUtf8StandardString(const QString &text);
 
@@ -99,6 +100,12 @@ class PMSPP_LIB_DECL Utils
   static std::vector<std::size_t>
   splitSizetStringToSizetVectorWithSpaces(const QString &text,
                                           std::size_t &error_count);
+
+  /** @brief convenient function to transform a boolean to QString "TRUE" or
+   * "FALSE" QString returned is readable by R
+   * @return QString "TRUE" or "FALSE"
+   */
+  static QString booleanToString(bool value);
 };
 
 } // namespace pappso
