@@ -27,6 +27,8 @@
 
 #include "timsbindec.h"
 #include "../../../pappsomspp/pappsoexception.h"
+#include "../../../pappsomspp/exception/exceptionnotimplemented.h"
+#include "timsframetype1.h"
 #include <QDataStream>
 #include <zstd.h>
 
@@ -35,10 +37,10 @@ using namespace pappso;
 TimsBinDec::TimsBinDec(const QFileInfo &timsBinFile, int timsCompressionType)
   : m_timsBinFile(timsBinFile.absoluteFilePath())
 {
-
-  if(timsCompressionType != 2)
+  m_timsCompressionType = timsCompressionType;
+  if((timsCompressionType != 1) && (timsCompressionType != 2))
     {
-      throw pappso::PappsoException(
+      throw pappso::ExceptionNotImplemented(
         QObject::tr("compression type %1 not handled by this library")
           .arg(timsCompressionType));
     }
@@ -64,6 +66,17 @@ TimsBinDec::TimsBinDec(const TimsBinDec &other)
 
 TimsBinDec::~TimsBinDec()
 {
+  if(mpa_memoryBuffer != nullptr)
+    {
+      delete[] mpa_memoryBuffer;
+      mpa_memoryBuffer = nullptr;
+    }
+
+
+  if(mpa_decompressMemoryBuffer != nullptr)
+    {
+      delete[] mpa_decompressMemoryBuffer;
+    }
 }
 
 
@@ -139,8 +152,7 @@ TimsBinDec::indexingFile()
 }
 
 TimsFrameSPtr
-TimsBinDec::getTimsFrameSPtrByOffset(std::size_t timsId,
-                                     std::size_t timsOffset) const
+TimsBinDec::getTimsFrameSPtrByOffset(std::size_t timsId, std::size_t timsOffset)
 {
   qDebug() << "timsId:" << timsId << "timsOffset:" << timsOffset;
 
@@ -152,7 +164,7 @@ TimsBinDec::getTimsFrameSPtrByOffset(std::size_t timsId,
         QObject::tr("ERROR opening TIMS binary file %1 for read")
           .arg(m_timsBinFile));
     }
-
+  qDebug();
   bool seekpos_ok = file.seek(timsOffset);
   if(!seekpos_ok)
     {
@@ -164,6 +176,7 @@ TimsBinDec::getTimsFrameSPtrByOffset(std::size_t timsId,
           .arg(timsOffset));
     }
 
+  qDebug();
   quint32 frame_length;
   file.read((char *)&frame_length, 4);
   // frame_length = qToBigEndian(frame_length);
@@ -171,6 +184,7 @@ TimsBinDec::getTimsFrameSPtrByOffset(std::size_t timsId,
   // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__
   //       << " frame_length=" << frame_length;
 
+  qDebug();
   quint32 scan_number;
   file.read((char *)&scan_number, 4);
   // scan_number = qToBigEndian(scan_number);
@@ -186,8 +200,29 @@ TimsBinDec::getTimsFrameSPtrByOffset(std::size_t timsId,
 
   qDebug();
 
-  QByteArray frame_byte_array = file.read((qint64)frame_length + 2);
+  // if (m_memoryBufferSize
+  if(mpa_memoryBuffer == nullptr)
+    {
+      qDebug() << "mpa_memoryBuffer == nullptr";
+      m_memoryBufferSize = (qint64)frame_length + 10;
+      mpa_memoryBuffer   = new char[m_memoryBufferSize];
+    }
+  if((m_memoryBufferSize - 10) < frame_length)
+    {
+      if(mpa_memoryBuffer != nullptr)
+        {
+          delete[] mpa_memoryBuffer;
+        }
+      m_memoryBufferSize = (qint64)frame_length + 10;
+      mpa_memoryBuffer   = new char[m_memoryBufferSize];
+    }
 
+
+  // QByteArray frame_byte_array(mpa_memoryBuffer, m_memoryBufferSize);
+
+  qDebug();
+  qint64 read_length = file.read(mpa_memoryBuffer, (qint64)frame_length + 2);
+  qDebug();
   file.close();
 
   // qDebug() << __FILE__ << " " << __FUNCTION__ << " " << __LINE__
@@ -198,70 +233,93 @@ TimsBinDec::getTimsFrameSPtrByOffset(std::size_t timsId,
   //     << (quint8) * (frame_byte_array.constData() + frame_length);
   // m_timsBinFile.seek(m_indexArray.at(timsId) + 8);
 
-  if(frame_byte_array.size() - 2 != (qint64)frame_length)
+  if(read_length - 2 != (qint64)frame_length)
     {
       throw PappsoException(
         QObject::tr("ERROR reading TIMS frame %1 TIMS binary file %2: "
-                    "frame_byte_array.size()%3 != %4frame_length")
+                    "read_length=%3 != %4frame_length")
           .arg(timsId)
           .arg(m_timsBinFile)
-          .arg(frame_byte_array.size())
+          .arg(read_length)
           .arg(frame_length));
     }
+  qDebug();
   TimsFrameSPtr frame_sptr;
   if(frame_length > 0)
     {
-      auto decompressed_size2 =
-        ZSTD_getFrameContentSize(frame_byte_array.constData(), frame_length);
-
-      if(decompressed_size2 == ZSTD_CONTENTSIZE_UNKNOWN)
-        {
-          throw PappsoException(
-            QObject::tr("ERROR reading TIMS frame %1 TIMS binary file %2: "
-                        " decompressed_size2 == ZSTD_CONTENTSIZE_UNKNOWN, "
-                        "frame_length=%3")
-              .arg(timsId)
-              .arg(m_timsBinFile)
-              .arg(frame_length));
-        }
-
-      if(decompressed_size2 == ZSTD_CONTENTSIZE_ERROR)
-        {
-          throw PappsoException(
-            QObject::tr(
-              "ERROR reading TIMS frame %1 TIMS binary file %2: "
-              " decompressed_size2 == ZSTD_CONTENTSIZE_ERROR, frame_length=%3")
-              .arg(timsId)
-              .arg(m_timsBinFile)
-              .arg(frame_length));
-        }
-      qDebug() << " decompressed_size2=" << decompressed_size2;
-
-      char *uncompress = new char[decompressed_size2 + 10];
-      std::size_t decompressed_size =
-        ZSTD_decompress(uncompress,
-                        decompressed_size2 + 10,
-                        frame_byte_array.constData(),
-                        frame_length);
       qDebug();
-
-      if(decompressed_size != decompressed_size2)
+      if(m_timsCompressionType == 2)
         {
-          throw PappsoException(
-            QObject::tr("ERROR reading TIMS frame %1 TIMS binary file %2: "
-                        "decompressed_size != decompressed_size2")
-              .arg(timsId)
-              .arg(m_timsBinFile)
-              .arg(decompressed_size)
-              .arg(decompressed_size2));
+          auto decompressed_size2 =
+            ZSTD_getFrameContentSize(mpa_memoryBuffer, frame_length);
+          qDebug();
+          if(decompressed_size2 == ZSTD_CONTENTSIZE_UNKNOWN)
+            {
+              throw PappsoException(
+                QObject::tr("ERROR reading TIMS frame %1 TIMS binary file %2: "
+                            " decompressed_size2 == ZSTD_CONTENTSIZE_UNKNOWN, "
+                            "frame_length=%3")
+                  .arg(timsId)
+                  .arg(m_timsBinFile)
+                  .arg(frame_length));
+            }
+          qDebug();
+          if(decompressed_size2 == ZSTD_CONTENTSIZE_ERROR)
+            {
+              qDebug();
+              throw PappsoException(
+                QObject::tr("ERROR reading TIMS frame %1 TIMS binary file %2: "
+                            " decompressed_size2 == ZSTD_CONTENTSIZE_ERROR, "
+                            "frame_length=%3")
+                  .arg(timsId)
+                  .arg(m_timsBinFile)
+                  .arg(frame_length));
+            }
+          qDebug() << " decompressed_size2=" << decompressed_size2;
+
+          if(m_decompressMemoryBufferSize < (decompressed_size2 + 10))
+            {
+              if(mpa_decompressMemoryBuffer != nullptr)
+                {
+                  delete[] mpa_decompressMemoryBuffer;
+                }
+              m_decompressMemoryBufferSize = decompressed_size2 + 10;
+              mpa_decompressMemoryBuffer =
+                new char[m_decompressMemoryBufferSize];
+            }
+          std::size_t decompressed_size =
+            ZSTD_decompress(mpa_decompressMemoryBuffer,
+                            m_decompressMemoryBufferSize,
+                            mpa_memoryBuffer,
+                            frame_length);
+          qDebug();
+
+          if(decompressed_size != decompressed_size2)
+            {
+              throw PappsoException(
+                QObject::tr("ERROR reading TIMS frame %1 TIMS binary file %2: "
+                            "decompressed_size != decompressed_size2")
+                  .arg(timsId)
+                  .arg(m_timsBinFile)
+                  .arg(decompressed_size)
+                  .arg(decompressed_size2));
+            }
+
+          qDebug();
+
+          frame_sptr = std::make_shared<TimsFrame>(
+            timsId, scan_number, mpa_decompressMemoryBuffer, decompressed_size);
         }
+      else
+        {
 
-      qDebug();
-
-      frame_sptr = std::make_shared<TimsFrame>(
-        timsId, scan_number, uncompress, decompressed_size);
-
-      delete[] uncompress;
+          if(m_timsCompressionType == 1)
+            {
+              frame_sptr = std::make_shared<TimsFrameType1>(
+                timsId, scan_number, mpa_memoryBuffer, frame_length);
+            }
+        }
+      // delete[] mpa_decompressMemoryBuffer;
     }
   else
     {
