@@ -6,7 +6,7 @@
  */
 
 /*******************************************************************************
- * Copyright (c) 2019 Olivier Langella <Olivier.Langella@u-psud.fr>.
+œ* Copyright (c) 2019 Olivier Langella <Olivier.Langella@u-psud.fr>.
  *
  * This file is part of the PAPPSOms++ library.
  *
@@ -33,6 +33,8 @@
 #include "timsframe.h"
 #include "../../massspectrum/qualifiedmassspectrum.h"
 #include "../../processing/filters/filterinterface.h"
+#include "../../msrun/xiccoord/xiccoordtims.h"
+#include "../../msrun/msrunreader.h"
 #include <deque>
 #include <QMutex>
 #include <QSqlQuery>
@@ -41,43 +43,6 @@
 namespace pappso
 {
 
-
-/** @brief structure needed to extract XIC from Tims data
- */
-
-struct TimsXicStructure
-{
-  TimsXicStructure()
-    : mzRange(pappso_double(1), PrecisionFactory::getPpmInstance(10.0)){};
-  /** @brief the corresponding precursor id
-   */
-  std::size_t precursorId;
-
-  /** @brief mass range to extract
-   */
-  MzRange mzRange;
-  /** @brief mobility index begin
-   */
-  std::size_t scanNumBegin;
-
-  /** @brief mobility index end
-   */
-  std::size_t scanNumEnd;
-
-  /** @brief targeted retention time for this precursor
-   */
-  pappso::pappso_double rtTarget;
-
-  /** @brief extracted xic
-   */
-  XicSPtr xicSptr = nullptr;
-
-  /** @brief targeted charge for this precursor
-   */
-
-  unsigned int charge;
-};
-
 class TimsData;
 
 /** \brief shared pointer on a TimsData object
@@ -104,7 +69,7 @@ class PMSPP_LIB_DECL TimsData
   /**
    * Destructor
    */
-  ~TimsData();
+  virtual ~TimsData();
 
 
   /** @brief get a mass spectrum given its spectrum index
@@ -139,18 +104,39 @@ class PMSPP_LIB_DECL TimsData
 
   unsigned int getMsLevelBySpectrumIndex(std::size_t spectrum_index);
 
-  QualifiedMassSpectrum
-  getQualifiedMassSpectrumByRawIndex(std::size_t spectrum_index,
-                                     bool want_binary_data);
+  void getQualifiedMassSpectrumByRawIndex(const MsRunIdCstSPtr &msrun_id,
+                                          QualifiedMassSpectrum &mass_spectrum,
+                                          std::size_t spectrum_index,
+                                          bool want_binary_data);
+
+  Trace getTicChromatogram();
+
+  struct SpectrumDescr
+  {
+    std::size_t parent_frame        = 0;
+    std::size_t precursor_id        = 0;
+    std::size_t scan_mobility_start = 0;
+    std::size_t scan_mobility_end   = 0;
+    std::size_t ms1_index           = 0;
+    std::size_t ms2_index           = 0;
+    double isolationMz              = 0;
+    double isolationWidth           = 0;
+    float collisionEnergy           = 0;
+    std::vector<std::size_t> tims_frame_list;
+    PrecursorIonData precursor_ion_data;
+  };
 
   void
-  getQualifiedMs2MassSpectrumByPrecursorId(QualifiedMassSpectrum &mass_spectrum,
-                                           std::size_t ms2_index,
-                                           std::size_t precursor_index,
+  getQualifiedMs2MassSpectrumByPrecursorId(const MsRunIdCstSPtr &msrun_id,
+                                           QualifiedMassSpectrum &mass_spectrum,
+                                           SpectrumDescr &spectrum_descr,
                                            bool want_binary_data);
 
-  QualifiedMassSpectrum getQualifiedMs1MassSpectrumByPrecursorId(
-    std::size_t ms2_index, std::size_t precursor_index, bool want_binary_data);
+  void
+  getQualifiedMs1MassSpectrumByPrecursorId(const MsRunIdCstSPtr &msrun_id,
+                                           QualifiedMassSpectrum &mass_spectrum,
+                                           SpectrumDescr &spectrum_descr,
+                                           bool want_binary_data);
 
   /** @brief filter interface to apply just after raw MS2 specturm extraction
    * the filter can be a list of filters inside a FilterSuite object
@@ -179,26 +165,34 @@ class PMSPP_LIB_DECL TimsData
 
   /** @brief get a Tims frame with his database ID
    */
-  TimsFrameCstSPtr getTimsFrameCstSPtr(std::size_t timsId) const;
+  TimsFrameCstSPtr getTimsFrameCstSPtr(std::size_t timsId);
 
-  TimsXicStructure
-  getTimsXicStructureFromPrecursorId(std::size_t precursor_id,
-                                     PrecisionPtr precision_ptr) const;
+  XicCoordTims getXicCoordTimsFromPrecursorId(std::size_t precursor_id,
+                                              PrecisionPtr precision_ptr);
 
 
-  /** @brief extract a list of XICs from Tims data
+  /** @brief function to visit an MsRunReader and get each Spectrum in a
+   * spectrum collection handler by Ms Levels
    *
-   * @param tims_xic_structure_list the list of tims XIC structure  to extract
-   * @param xicExtractMethod XIC extraction method (sum or max) to use
-   * @param rtRange retention time range in seconds to extract XIC from rtTarget
-   * - rtRange to rtTarget + rtRange
+   * this function will retrieve processed qualified spectrum depending on each
+   * Bruker precursors
    */
-  void extractXicListByTimsXicStructureList(
-    std::vector<TimsXicStructure> &tims_xic_structure_list,
-    XicExtractMethod xicExtractMethod,
-    double rtRange) const;
+  void ms2ReaderSpectrumCollectionByMsLevel(
+    const MsRunIdCstSPtr &msrun_id,
+    SpectrumCollectionHandlerInterface &handler,
+    unsigned int ms_level);
 
 
+  /** @brief function to visit an MsRunReader and get each raw Spectrum in a
+   * spectrum collection handler by Ms Levels
+   *
+   * this function will retrieve every scans as a qualified mass spectrum
+   */
+  void rawReaderSpectrumCollectionByMsLevel(
+    const MsRunIdCstSPtr &msrun_id,
+    SpectrumCollectionHandlerInterface &handler,
+    unsigned int ms_level);
+
   /** @brief get cumulated raw signal for a given precursor
    * only to use to see the raw signal
    *
@@ -208,22 +202,30 @@ class PMSPP_LIB_DECL TimsData
   std::map<quint32, quint32>
   getRawMs2ByPrecursorId(std::size_t precursor_index);
 
-  private:
-  /** @brief extract a list of XICs from Tims data
+  /** @brief get raw signal for a spectrum index
+   * only to use to see the raw signal
    *
-   * @param precursor_id_list the list of precursors to extract
-   * @param precision_ptr precision to compute the mz range to extract for each
-   * precursor mass
-   * @param xicExtractMethod XIC extraction method (sum or max) to use
-   * @param rtRange retention time range in seconds to extract XIC from rtTarget
-   * - rtRange to rtTarget + rtRange
-   * @result the corresponding XIC list as a specific structure
+   * @param spectrum_index spcetrum index
+   * @result a map of integers, x=time of flights, y= intensities
    */
-  std::vector<TimsXicStructure> extractXicListByPrecursorIds(
-    const std::vector<std::size_t> &precursor_id_list,
-    PrecisionPtr precision_ptr,
-    XicExtractMethod xicExtractMethod,
-    double rtRange) const;
+  std::map<quint32, quint32>
+  getRawMsBySpectrumIndex(std::size_t spectrum_index);
+
+
+  /** @brief retention timeline
+   * get retention times along the MSrun in seconds
+   * @return vector of retention times (seconds)
+   */
+  virtual std::vector<double> getRetentionTimeLine() const;
+
+  /** @brief get an intermediate structure describing a spectrum
+   */
+  SpectrumDescr getSpectrumDescrWithPrecursorId(std::size_t precursor_id);
+
+
+  private:
+  SpectrumDescr getSpectrumDescrWithScanCoordinate(
+    const std::pair<std::size_t, std::size_t> &scan_coordinate);
 
 
   std::pair<std::size_t, std::size_t>
@@ -238,7 +240,7 @@ class PMSPP_LIB_DECL TimsData
   /** @brief get a Tims frame base (no binary data file access) with his
    * database ID
    */
-  TimsFrameBaseCstSPtr getTimsFrameBaseCstSPtr(std::size_t timsId) const;
+  TimsFrameBaseCstSPtr getTimsFrameBaseCstSPtr(std::size_t timsId);
 
 
   /** @brief get a Tims frame with his database ID
@@ -265,6 +267,16 @@ class PMSPP_LIB_DECL TimsData
   void fillFrameIdDescrList();
 
 
+  private:
+  void
+  ms2ReaderGenerateMS1MS2Spectrum(const MsRunIdCstSPtr &msrun_id,
+                                  SpectrumCollectionHandlerInterface &handler,
+                                  SpectrumDescr &spectrum_descr,
+                                  unsigned int ms_level);
+
+  void fillSpectrumDescriptionWithSqlRecord(SpectrumDescr &spectrum_descr,
+                                            QSqlQuery &qprecursor_list);
+
   private:
   QDir m_timsDataDirectory;
   TimsBinDec *mpa_timsBinDec = nullptr;
@@ -286,6 +298,7 @@ class PMSPP_LIB_DECL TimsData
   std::map<int, QSqlRecord> m_mapMzCalibrationRecord;
   std::map<int, QSqlRecord> m_mapTimsCalibrationRecord;
   std::map<std::size_t, QSqlRecord> m_mapFramesRecord;
+  std::map<std::size_t, QSqlRecord> m_mapXicCoordRecord;
 
   MzCalibrationStore *mpa_mzCalibrationStore;
 
@@ -297,6 +310,7 @@ class PMSPP_LIB_DECL TimsData
     std::size_t m_cumulSize; // cumulative size
   };
 
+
   /** @brief store every frame id and corresponding sizes
    */
   std::vector<FrameIdDescr> m_frameIdDescrList;
