@@ -33,6 +33,7 @@
 #include "../../massspectrum/qualifiedmassspectrum.h"
 #include "timsframebase.h"
 #include "../../xic/xic.h"
+#include "../../msrun/xiccoord/xiccoordtims.h"
 
 namespace pappso
 {
@@ -43,7 +44,6 @@ typedef std::shared_ptr<const TimsFrame> TimsFrameCstSPtr;
 
 class TimsBinDec;
 
-struct TimsXicStructure;
 class TimsDirectXicExtractor;
 
 /**
@@ -55,7 +55,10 @@ class TimsFrame : public TimsFrameBase
 
   public:
   /**
-   * Default constructor
+   * @param timsId tims frame id
+   * @param scanNum total number of scans in this frame
+   * @param p_bytes pointer on the decompressed binary buffer
+   * @param len size of the decompressed binary buffer
    */
   TimsFrame(std::size_t timsId,
             quint32 scanNum,
@@ -93,57 +96,77 @@ class TimsFrame : public TimsFrameBase
                                      std::size_t scanNumBegin,
                                      std::size_t scanNumEnd) const override;
 
-  /** @brief cumulate a scan list into a map of integers
-   * @param scanNumBegin first scan to cumulate
-   * @param scanNumEnd last scan to cumulate
-   * @param accumulate_into map of x and y integer values
-   */
-  void cumulateScans(std::size_t scanNumBegin,
-                     std::size_t scanNumEnd,
-                     std::map<quint32, quint32> &accumulate_into) const;
 
   /** @brief get raw index list for one given scan
    * index are not TOF nor m/z, just index on digitizer
    */
-  std::vector<quint32> getScanIndexList(std::size_t scanNum) const;
+  virtual std::vector<quint32> getScanIndexList(std::size_t scanNum) const;
 
   /** @brief get raw intensities without transformation from one scan
    * it needs intensity normalization
    */
-  std::vector<quint32> getScanIntensities(std::size_t scanNum) const;
+  virtual std::vector<quint32> getScanIntensities(std::size_t scanNum) const;
 
   /** @brief get the mass spectrum corresponding to a scan number
    * @param scanNum the scan number to retrieve
    * */
-  pappso::MassSpectrumCstSPtr getMassSpectrumCstSPtr(std::size_t scanNum) const;
+  virtual pappso::MassSpectrumCstSPtr
+  getMassSpectrumCstSPtr(std::size_t scanNum) const;
+
   virtual pappso::MassSpectrumSPtr
   getMassSpectrumSPtr(std::size_t scanNum) const override;
 
 
   protected:
+  /** @brief constructor for binary independant tims frame
+   * @param timsId tims frame identifier in the database
+   * @param scanNum the total number of scans contained in this frame
+   */
+  TimsFrame(std::size_t timsId, quint32 scanNum);
+
   void extractTimsXicListInRtRange(
-    std::vector<TimsXicStructure>::iterator &itXicListbegin,
-    std::vector<TimsXicStructure>::iterator &itXicListend,
+    std::vector<XicCoordTims *>::iterator &itXicListbegin,
+    std::vector<XicCoordTims *>::iterator &itXicListend,
     XicExtractMethod method) const;
 
-  private:
-  void unshufflePacket(const char *src);
-
-  std::size_t getScanOffset(std::size_t scanNum) const;
-
 
   /** @brief cumulate a scan into a map
+   *
+   * @param scanNum scan number 0 to (m_scanNumber-1)
    */
-  void cumulateScan(std::size_t scanNum,
-                    std::map<quint32, quint32> &accumulate_into) const;
+  virtual void cumulateScan(std::size_t scanNum,
+                            std::map<quint32, quint32> &accumulate_into) const;
 
-  pappso::TraceSPtr getRawTraceSPtr(std::size_t scanNum) const;
+
+  /** @brief get the raw index tof_index and intensities (normalized)
+   *
+   * @param scanNum the scan number to extract
+   * @return trace vector
+   *
+   */
+  virtual pappso::TraceSPtr getRawTraceSPtr(std::size_t scanNum) const;
+
+
+  private:
+  /** @brief unshuffle data packet of tims compression type 2
+   * @param src is a zstd decompressed buffer pointer
+   */
+  void unshufflePacket(const char *src);
+
+
+  /** @brief get offset for this spectrum in the binary file
+   *
+   * @param scanNum scan number in the frame in the order it lies in binary
+   * file, from 0 to N-1
+   */
+
+  std::size_t getScanOffset(std::size_t scanNum) const;
 
   private:
   struct XicComputeStructure
   {
     XicComputeStructure(const TimsFrame *fram_p,
-                        const TimsXicStructure &xic_struct);
+                        const XicCoordTims &xic_struct);
 
 
     Xic *xic_ptr = nullptr;
@@ -154,7 +177,7 @@ class TimsFrame : public TimsFrameBase
     double tmpIntensity = 0;
   };
 
-  private:
+  protected:
   QByteArray m_timsDataFrame;
 };
 } // namespace pappso
