@@ -40,16 +40,17 @@ class TimsDirectXicExtractor : public TimsXicExtractorInterface
   /**
    * Default constructor
    */
-  TimsDirectXicExtractor(const TimsData *mp_tims_data);
+  TimsDirectXicExtractor(MsRunReaderSPtr &msrun_reader);
 
   /**
    * Destructor
    */
   virtual ~TimsDirectXicExtractor();
 
-
   protected:
-  virtual void extractTimsXicList(std::vector<TimsXicStructure> &timsXicList,
-                                  double rtRange) const override;
+  void protectedExtractXicCoordSPtrList(
+    UiMonitorInterface &monitor,
+    std::vector<XicCoordSPtr>::iterator it_xic_coord_list_begin,
+    std::vector<XicCoordSPtr>::iterator it_xic_coord_list_end) override;
 };
 } // namespace pappso
