@@ -333,8 +333,6 @@ MassSpectrumWidget::plot()
           // peak_ion_match.getPeak().y);
           if(i < _tag_nmost_intense)
             {
-              QString plusstr = "+";
-              plusstr         = plusstr.repeated(peak_ion_match.getCharge());
               QCPItemText *text_label = new QCPItemText(_custom_plot);
               text_label->setVisible(true);
               //_custom_plot->addItem(text_label);
@@ -347,12 +345,9 @@ MassSpectrumWidget::plot()
                   .y); // place position at center/top of axis rect
               text_label->setFont(QFont(font().family(), 8));
               text_label->setText(
-                QString("%1%2%3")
-                  .arg(peak_ion_match.getPeptideFragmentIonSp()
-                         .get()
-                         ->getPeptideIonName())
-                  .arg(peak_ion_match.getPeptideFragmentIonSp().get()->size())
-                  .arg(plusstr));
+                peak_ion_match.getPeptideFragmentIonSp()
+                  .get()
+                  ->getCompletePeptideIonName(peak_ion_match.getCharge()));
               // text_label->setPen(QPen(PeptideFragmentIon::getPeptideIonColor(peak_ion_match.getPeptideIonType()),
               // 1)); // show black border around text
               text_label->setColor(
