@@ -60,6 +60,9 @@ class QCPSpectrum : public QCustomPlot
                          &isotope_mass_list,
                        pappso_double intensity);
   void addPeakIonIsotopeMatch(const PeakIonIsotopeMatch &peak_ion_match);
+  void highlightPrecursorPeaks(double precursor_mz,
+                               int charge,
+                               PrecisionPtr ms2_precision);
   virtual void mouseMoveEvent(QMouseEvent *event) override;
   virtual void mousePressEvent(QMouseEvent *event) override;
   virtual void mouseReleaseEvent(QMouseEvent *event) override;
@@ -83,6 +86,7 @@ class QCPSpectrum : public QCustomPlot
   QCPRange _mass_delta_range;
   QCPBars *_p_peak_bars;
   QCPBars *_p_peak_bars_isotope;
+  QCPBars *mp_peak_bars_precursor;
   std::map<PeptideIon, QCPBars *> _map_ion_type_bars;
   QCPAxisRect *_p_delta_axis_rect;
   QCPGraph *_p_delta_graph;
