@@ -77,10 +77,11 @@ BaseColorMapPlotWidget::BaseColorMapPlotWidget(QWidget *parent,
 */
 BaseColorMapPlotWidget::~BaseColorMapPlotWidget()
 {
-  if(mpa_backupColorMapData != nullptr)
-    delete mpa_backupColorMapData;
-  if(mpa_backupColorMapData != nullptr)
-    delete mpa_backupColorMapPlotConfig;
+  if(mpa_origColorMapData != nullptr)
+    delete mpa_origColorMapData;
+
+  if(mpa_origColorMapPlotConfig != nullptr)
+    delete mpa_origColorMapPlotConfig;
 }
 
 
@@ -92,6 +93,13 @@ BaseColorMapPlotWidget::setColorMapPlotConfig(
 }
 
 
+const ColorMapPlotConfig *
+BaseColorMapPlotWidget::getOrigColorMapPlotConfig()
+{
+  return mpa_origColorMapPlotConfig;
+}
+
+
 const ColorMapPlotConfig &
 BaseColorMapPlotWidget::getColorMapPlotConfig()
 {
@@ -119,22 +127,22 @@ BaseColorMapPlotWidget::addColorMap(
   // Do not forget to copy the config!
   m_colorMapPlotConfig = color_map_plot_config;
 
-  // Immediately create a copy for backup.
-  mpa_backupColorMapPlotConfig = new ColorMapPlotConfig(color_map_plot_config);
+  // Immediately create a copy of the original data for backup.
+  mpa_origColorMapPlotConfig = new ColorMapPlotConfig(color_map_plot_config);
 
 #if 0 
-			// This is the code on the QCustomPlot documentation and it works fine.
-			QCPColorMap *color_map_p = new QCPColorMap(xAxis, yAxis);
+      // This is the code on the QCustomPlot documentation and it works fine.
+      QCPColorMap *color_map_p = new QCPColorMap(xAxis, yAxis);
 
-			color_map_p->data()->setSize(50, 50);
-			color_map_p->data()->setRange(QCPRange(0, 2), QCPRange(0, 2));
-			for(int x = 0; x < 50; ++x)
-				for(int y = 0; y < 50; ++y)
-					color_map_p->data()->setCell(x, y, qCos(x / 10.0) + qSin(y / 10.0));
-			color_map_p->setGradient(QCPColorGradient::gpPolar);
-			color_map_p->rescaleDataRange(true);
-			rescaleAxes();
-			replot();
+      color_map_p->data()->setSize(50, 50);
+      color_map_p->data()->setRange(QCPRange(0, 2), QCPRange(0, 2));
+      for(int x = 0; x < 50; ++x)
+        for(int y = 0; y < 50; ++y)
+          color_map_p->data()->setCell(x, y, qCos(x / 10.0) + qSin(y / 10.0));
+      color_map_p->setGradient(QCPColorGradient::gpPolar);
+      color_map_p->rescaleDataRange(true);
+      rescaleAxes();
+      replot();
 #endif
 
   // Only now can afford to call createAllAncillaryItems() in this derived class
@@ -192,10 +200,15 @@ BaseColorMapPlotWidget::addColorMap(
           double prev_intensity = color_map_p->data()->data(dt_or_rt_key, mz);
           double new_intensity  = prev_intensity + intensity;
 
-          // Record the max cell intensity value (maxZValue). We will need that
-          // later.
-          m_colorMapPlotConfig.maxZValue =
-            std::max(m_colorMapPlotConfig.maxZValue, new_intensity);
+          // Record the min/max cell intensity value (origM(in/ax)ZValue). We
+          // will need that later. Also update the lastM(in/ax)ZValue because
+          // when doing this kind of data conversion it is assume that the user
+          // actually changes the data.
+          m_colorMapPlotConfig.setOrigAndLastMinZValue(
+            std::min(m_colorMapPlotConfig.origMinZValue, new_intensity));
+
+          m_colorMapPlotConfig.setOrigAndLastMaxZValue(
+            std::max(m_colorMapPlotConfig.origMaxZValue, new_intensity));
 
           // qDebug() << "Setting tri-point:" << dt_or_rt_key << "," << mz <<
           // ","
@@ -236,9 +249,9 @@ BaseColorMapPlotWidget::addColorMap(
 
   color_map_p->setPen(pen);
 
-  // Copy the color map's data into a backup copy.
+  // Copy the original color map's data into a backup copy.
 
-  mpa_backupColorMapData = new QCPColorMapData(*(color_map_p->data()));
+  mpa_origColorMapData = new QCPColorMapData(*(color_map_p->data()));
 
   replot();
 
@@ -321,6 +334,9 @@ BaseColorMapPlotWidget::transposeAxes()
 void
 BaseColorMapPlotWidget::zAxisScaleToLog10()
 {
+  // The user wants to rescale the intensity values of the color map according
+  // to: new_int = log10(orig_int).
+
   // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()" ;
 
   if(m_colorMapPlotConfig.zAxisScale == AxisScale::log10)
@@ -349,8 +365,11 @@ BaseColorMapPlotWidget::zAxisScaleToLog10()
 
   // But we need to reset these two values to be able to update them using
   // std::min() and std::max() below.
-  new_color_map_plot_config.minZValue = std::numeric_limits<double>::max();
-  new_color_map_plot_config.maxZValue = std::numeric_limits<double>::min();
+  new_color_map_plot_config.setOrigAndLastMinZValue(
+    std::numeric_limits<double>::max());
+
+  new_color_map_plot_config.setOrigAndLastMaxZValue(
+    std::numeric_limits<double>::min());
 
   // qDebug() << "new_color_map_plot_config"
   //<< new_color_map_plot_config.toString();
@@ -377,18 +396,19 @@ BaseColorMapPlotWidget::zAxisScaleToLog10()
           else
             new_cell_data = std::log10(cell_data);
 
-          // Store the new values here.
-          new_color_map_plot_config.minZValue =
+          // Store the new values here. Should we change the last or orig or
+          // both ?
+          new_color_map_plot_config.lastMinZValue =
             //(new_cell_data < new_color_map_plot_config.minZValue
             //? new_cell_data
             //: new_color_map_plot_config.minZValue);
-            std::min(new_color_map_plot_config.minZValue, new_cell_data);
+            std::min(new_color_map_plot_config.lastMinZValue, new_cell_data);
 
-          new_color_map_plot_config.maxZValue =
+          new_color_map_plot_config.lastMaxZValue =
             //(new_cell_data > new_color_map_plot_config.maxZValue
             //? new_cell_data
             //: new_color_map_plot_config.maxZValue);
-            std::max(new_color_map_plot_config.maxZValue, new_cell_data);
+            std::max(new_color_map_plot_config.lastMaxZValue, new_cell_data);
 
           // qDebug() << "cell_data:" << cell_data
           //<< "new_cell_data:" << new_cell_data
@@ -431,13 +451,15 @@ BaseColorMapPlotWidget::zAxisScaleToLog10()
   replot();
 }
 
-
 void
 BaseColorMapPlotWidget::zAxisFilterLowPassPercentage(
   double threshold_percentage)
 {
-  // We want to zAxisFilter the cell data by eliminating the contents of all the
-  // cells that have an intensity value less than threshold.
+  // This filter allows all the values smaller than a threshold to remain
+  // unchanged. Instead, all the values above the threshold will be reset to
+  // that threshold. 
+  //
+  // The effect of this filter is to enhance the high-intensity signal.
 
   QCPColorMap *color_map_p = static_cast<QCPColorMap *>(plottable(0));
 
@@ -449,11 +471,19 @@ BaseColorMapPlotWidget::zAxisFilterLowPassPercentage(
   QCPRange keyRange   = map_data->keyRange();
   QCPRange valueRange = map_data->valueRange();
 
-  double threshold =
-    m_colorMapPlotConfig.maxZValue * (threshold_percentage / 100);
+  double minZValue = m_colorMapPlotConfig.lastMinZValue;
+  double maxZValue = m_colorMapPlotConfig.lastMaxZValue;
 
-  qDebug() << "maxZValue:" << m_colorMapPlotConfig.maxZValue
-           << "threshold:" << threshold;
+  double amplitude = maxZValue - minZValue;
+
+  double amplitude_fraction = amplitude * threshold_percentage / 100;
+
+  double threshold = minZValue + amplitude_fraction;
+
+  //qDebug() << "Before filtering minZValue:" << minZValue
+           //<< "maxZValue:" << maxZValue << "fraction:" << fraction
+           //<< "threshold:" << threshold
+           //<< "new threshold percentage:" << new_threshold_percentage;
 
   // Make a copy of the current config so that we can modify
   // the xxxZvalue values.
@@ -461,105 +491,8 @@ BaseColorMapPlotWidget::zAxisFilterLowPassPercentage(
 
   // But we need to reset these two values to be able to update them using
   // std::min() and std::max() below.
-  new_color_map_plot_config.minZValue = std::numeric_limits<double>::max();
-  new_color_map_plot_config.maxZValue = std::numeric_limits<double>::min();
-
-  // Filtered
-  QCPColorMapData *new_map_data =
-    new QCPColorMapData(keySize, valueSize, keyRange, valueRange);
-
-  for(int iter = 0; iter < keySize; ++iter)
-    {
-      for(int jter = 0; jter < valueSize; ++jter)
-        {
-          double cell_data = map_data->cell(iter, jter);
-
-          double new_cell_data = 0;
-
-          if(cell_data > threshold)
-            new_cell_data = threshold;
-          else
-            new_cell_data = cell_data;
-
-          // Store the new values here.
-          new_color_map_plot_config.minZValue =
-            //(new_cell_data < new_color_map_plot_config.minZValue
-            //? new_cell_data
-            //: new_color_map_plot_config.minZValue);
-            std::min(new_color_map_plot_config.minZValue, new_cell_data);
-
-          new_color_map_plot_config.maxZValue =
-            //(new_cell_data > new_color_map_plot_config.maxZValue
-            //? new_cell_data
-            //: new_color_map_plot_config.maxZValue);
-            std::max(new_color_map_plot_config.maxZValue, new_cell_data);
-
-          // qDebug() << "cell_data:" << cell_data
-          //<< "new_cell_data:" << new_cell_data
-          //<< "new_color_map_plot_config.minZValue:"
-          //<< new_color_map_plot_config.minZValue
-          //<< "new_color_map_plot_config.maxZValue:"
-          //<< new_color_map_plot_config.maxZValue;
-
-          new_map_data->setCell(iter, jter, new_cell_data);
-        }
-    }
-
-  color_map_p->data()->clear();
-
-  // Will take ownership of the new_map_data.
-  color_map_p->setData(new_map_data);
-
-  color_map_p->data()->recalculateDataBounds();
-  color_map_p->rescaleDataRange(true);
-
-  // At this point the new color map data have taken their place, we can update
-  // the config. This, way any new filtering can take advantage of the new
-  // values and compute the threshold correctly.
-  m_colorMapPlotConfig = new_color_map_plot_config;
-
-  // We should not do this, as the user might have zoomed to a region of
-  // interest.
-  // color_map_p->rescaleAxes();
-
-  replot();
-}
-
-
-void
-BaseColorMapPlotWidget::zAxisFilterHighPassPercentage(
-  double threshold_percentage)
-{
-  // We want to zAxisFilter the cell data by eliminating the contents of all the
-  // cells that have an intensity value higher than threshold.
-
-  QCPColorMap *color_map_p = static_cast<QCPColorMap *>(plottable(0));
-
-  QCPColorMapData *map_data = color_map_p->data();
-
-  int keySize   = map_data->keySize();
-  int valueSize = map_data->valueSize();
-
-  QCPRange keyRange   = map_data->keyRange();
-  QCPRange valueRange = map_data->valueRange();
-
-  double threshold =
-    m_colorMapPlotConfig.maxZValue * (threshold_percentage / 100);
-
-  qDebug() << "maxZValue:" << m_colorMapPlotConfig.maxZValue
-           << "threshold:" << threshold;
-
-  // Make a copy of the current config so that we can modify
-  // the xxxZvalue values.
-  ColorMapPlotConfig new_color_map_plot_config(m_colorMapPlotConfig);
-
-  // But we need to reset these two values to be able to update them using
-  // std::min() and std::max() below.
-  new_color_map_plot_config.minZValue = std::numeric_limits<double>::max();
-  new_color_map_plot_config.maxZValue = std::numeric_limits<double>::min();
-
-  qDebug() << "new_color_map_plot_config"
-           << new_color_map_plot_config.toString();
+  new_color_map_plot_config.lastMinZValue = std::numeric_limits<double>::max();
+  new_color_map_plot_config.lastMaxZValue = std::numeric_limits<double>::min();
 
   // Filtered
   QCPColorMapData *new_map_data =
@@ -574,22 +507,23 @@ BaseColorMapPlotWidget::zAxisFilterHighPassPercentage(
           double new_cell_data = 0;
 
           if(cell_data < threshold)
-            new_cell_data = threshold;
-          else
+            // Keep the value, we are in low-pass
             new_cell_data = cell_data;
+          else
+            new_cell_data = threshold;
 
           // Store the new values here.
-          new_color_map_plot_config.minZValue =
+          new_color_map_plot_config.lastMinZValue =
             //(new_cell_data < new_color_map_plot_config.minZValue
             //? new_cell_data
             //: new_color_map_plot_config.minZValue);
-            std::min(new_color_map_plot_config.minZValue, new_cell_data);
+            std::min(new_color_map_plot_config.lastMinZValue, new_cell_data);
 
-          new_color_map_plot_config.maxZValue =
+          new_color_map_plot_config.lastMaxZValue =
             //(new_cell_data > new_color_map_plot_config.maxZValue
             //? new_cell_data
             //: new_color_map_plot_config.maxZValue);
-            std::max(new_color_map_plot_config.maxZValue, new_cell_data);
+            std::max(new_color_map_plot_config.lastMaxZValue, new_cell_data);
 
           // qDebug() << "cell_data:" << cell_data
           //<< "new_cell_data:" << new_cell_data
@@ -610,8 +544,116 @@ BaseColorMapPlotWidget::zAxisFilterHighPassPercentage(
   color_map_p->data()->recalculateDataBounds();
   color_map_p->rescaleDataRange(true);
 
-  qDebug() << "new_color_map_plot_config"
-           << new_color_map_plot_config.toString();
+
+  // At this point the new color map data have taken their place, we can update
+  // the config. This, way any new filtering can take advantage of the new
+  // values and compute the threshold correctly.
+  m_colorMapPlotConfig = new_color_map_plot_config;
+
+  // qDebug() << "Member colormap plot config is now, after filter was applied:"
+  //<< m_colorMapPlotConfig.toString();
+
+  // We should not do this, as the user might have zoomed to a region of
+  // interest.
+  // color_map_p->rescaleAxes();
+
+  replot();
+}
+
+
+void
+BaseColorMapPlotWidget::zAxisFilterHighPassPercentage(
+  double threshold_percentage)
+{
+  // This filter allows all the value greater than a threshold to remain
+  // unchanged. Instead, all the values below the threshold will be reset to
+  // that threshold value.
+  //
+  // The effect of this filter is to reduce the low-intensity signal: reduce
+  // noise.
+
+  QCPColorMap *color_map_p = static_cast<QCPColorMap *>(plottable(0));
+
+  QCPColorMapData *map_data = color_map_p->data();
+
+  int keySize   = map_data->keySize();
+  int valueSize = map_data->valueSize();
+
+  QCPRange keyRange   = map_data->keyRange();
+  QCPRange valueRange = map_data->valueRange();
+
+  double minZValue = m_colorMapPlotConfig.lastMinZValue;
+  double maxZValue = m_colorMapPlotConfig.lastMaxZValue;
+
+  double amplitude = maxZValue - minZValue;
+
+  double amplitude_fraction = amplitude * threshold_percentage / 100;
+
+  double threshold = minZValue + amplitude_fraction;
+
+    //qDebug() << "Before filtering minZValue:" << minZValue
+             //<< "maxZValue:" << maxZValue << "fraction:" << fraction
+             //<< "threshold:" << threshold
+             //<< "new threshold percentage:" << new_threshold_percentage;
+
+  // Make a copy of the current config so that we can modify
+  // the xxxZvalue values.
+  ColorMapPlotConfig new_color_map_plot_config(m_colorMapPlotConfig);
+
+  // But we need to reset these two values to be able to update them using
+  // std::min() and std::max() below.
+  new_color_map_plot_config.lastMinZValue = std::numeric_limits<double>::max();
+  new_color_map_plot_config.lastMaxZValue = std::numeric_limits<double>::min();
+
+  // Filtered
+  QCPColorMapData *new_map_data =
+    new QCPColorMapData(keySize, valueSize, keyRange, valueRange);
+
+  for(int iter = 0; iter < keySize; ++iter)
+    {
+      for(int jter = 0; jter < valueSize; ++jter)
+        {
+          double cell_data = map_data->cell(iter, jter);
+
+          double new_cell_data = 0;
+
+          if(cell_data > threshold)
+            // Keep the value, we are in high-pass
+            new_cell_data = cell_data;
+          else
+            new_cell_data = threshold;
+
+          // Store the new values here.
+          new_color_map_plot_config.lastMinZValue =
+            //(new_cell_data < new_color_map_plot_config.minZValue
+            //? new_cell_data
+            //: new_color_map_plot_config.minZValue);
+            std::min(new_color_map_plot_config.lastMinZValue, new_cell_data);
+
+          new_color_map_plot_config.lastMaxZValue =
+            //(new_cell_data > new_color_map_plot_config.maxZValue
+            //? new_cell_data
+            //: new_color_map_plot_config.maxZValue);
+            std::max(new_color_map_plot_config.lastMaxZValue, new_cell_data);
+
+          // qDebug() << "cell_data:" << cell_data
+          //<< "new_cell_data:" << new_cell_data
+          //<< "new_color_map_plot_config.minZValue:"
+          //<< new_color_map_plot_config.minZValue
+          //<< "new_color_map_plot_config.maxZValue:"
+          //<< new_color_map_plot_config.maxZValue;
+
+          new_map_data->setCell(iter, jter, new_cell_data);
+        }
+    }
+
+  color_map_p->data()->clear();
+
+  // Will take ownership of the new_map_data.
+  color_map_p->setData(new_map_data);
+
+  color_map_p->data()->recalculateDataBounds();
+  color_map_p->rescaleDataRange(true);
 
 
   // At this point the new color map data have taken their place, we can update
@@ -619,7 +661,8 @@ BaseColorMapPlotWidget::zAxisFilterHighPassPercentage(
   // values and compute the threshold correctly.
   m_colorMapPlotConfig = new_color_map_plot_config;
 
-  qDebug() << "m_colorMapPlotConfig:" << m_colorMapPlotConfig.toString();
+  // qDebug() << "Member colormap plot config is now, after filter was applied:"
+  //<< m_colorMapPlotConfig.toString();
 
   // We should not do this, as the user might have zoomed to a region of
   // interest.
@@ -632,17 +675,24 @@ BaseColorMapPlotWidget::zAxisFilterHighPassPercentage(
 void
 BaseColorMapPlotWidget::zAxisDataResetToOriginal()
 {
+  // The user might have changed to the axis scale to log10, for example.
+  // While doing this, the original data were still available in
+  // mpa_origColorMapData,with mpa_origColorMapPlotConfig. We need to reset the
+  // current data to the original data. 
+  //
+  // Same thing for filters that might have been applied to the data.
+
   QCPColorMap *color_map_p = static_cast<QCPColorMap *>(plottable(0));
   color_map_p->data()->clear();
 
-  if(mpa_backupColorMapData == nullptr)
+  if(mpa_origColorMapData == nullptr)
     throw(PappsoException(
-      "Not possible that the mpa_backupColorMapData pointer is null."));
+      "Not possible that the mpa_origColorMapData pointer be null."));
 
   // We do no want that the color_map_p takes ownership of the data, because
   // these must remain there always, so pass true, to say that we want to copy
   // the data not transfer the pointer.
-  color_map_p->setData(mpa_backupColorMapData, true);
+  color_map_p->setData(mpa_origColorMapData, true);
 
   color_map_p->data()->recalculateDataBounds();
   color_map_p->rescaleDataRange(true);
@@ -651,8 +701,9 @@ BaseColorMapPlotWidget::zAxisDataResetToOriginal()
   // interest.
   // color_map_p->rescaleAxes();
 
-  // Reset the current plot config to what it was originally.
-  m_colorMapPlotConfig = *mpa_backupColorMapPlotConfig;
+  // Reset the current plot config to what it was originally. The member
+  // m_colorMapPlotConfig.zAxisScale  is now AxisScale::orig.
+  m_colorMapPlotConfig = *mpa_origColorMapPlotConfig;
 
   replot();
 }
