@@ -72,6 +72,7 @@ class PMSPP_LIB_DECL BaseColorMapPlotWidget : public BasePlotWidget
   virtual void
   setColorMapPlotConfig(const ColorMapPlotConfig &color_map_config);
   virtual const ColorMapPlotConfig &getColorMapPlotConfig();
+  const ColorMapPlotConfig *getOrigColorMapPlotConfig();
 
   virtual QCPColorMap *addColorMap(
     std::shared_ptr<std::map<double, MapTrace>> double_map_trace_map_sp,
@@ -104,9 +105,10 @@ class PMSPP_LIB_DECL BaseColorMapPlotWidget : public BasePlotWidget
   signals:
 
   protected:
-  QCPColorMapData *mpa_backupColorMapData = nullptr;
+  QCPColorMapData *mpa_origColorMapData = nullptr;
+
   ColorMapPlotConfig m_colorMapPlotConfig;
-  ColorMapPlotConfig *mpa_backupColorMapPlotConfig = nullptr;
+  ColorMapPlotConfig *mpa_origColorMapPlotConfig = nullptr;
 };
 
 
