@@ -44,6 +44,24 @@ namespace pappso
 BaseTracePlotWidget::BaseTracePlotWidget(QWidget *parent)
   : BasePlotWidget(parent)
 {
+  // We can afford to call createAllAncillaryItems() in this derived class
+  // because all the items will have been created *before* the addition of plots
+  // and then the rendering order will hide them to the viewer, since the
+  // rendering order is according to the order in which the items have been
+  // created.
+  //
+  // The fact that the ancillary items are created before trace plots is not a
+  // problem because the trace plots are sparse and do not effectively hide the
+  // data.
+  //
+  // But, in the color map plot widgets, we cannot afford to create the
+  // ancillary items *before* the plot itself because then, the rendering of the
+  // plot (created after) would screen off the ancillary items (created before).
+  //
+  // So, the createAllAncillaryItems() function needs to be called in the
+  // derived classes at the most appropriate moment in the setting up of the
+  // widget.
+  createAllAncillaryItems();
 }
 
 
@@ -52,6 +70,24 @@ BaseTracePlotWidget::BaseTracePlotWidget(QWidget *parent,
                                          const QString &y_axis_label)
   : BasePlotWidget(parent, x_axis_label, y_axis_label)
 {
+  // We can afford to call createAllAncillaryItems() in this derived class
+  // because all the items will have been created *before* the addition of plots
+  // and then the rendering order will hide them to the viewer, since the
+  // rendering order is according to the order in which the items have been
+  // created.
+  //
+  // The fact that the ancillary items are created before trace plots is not a
+  // problem because the trace plots are sparse and do not effectively hide the
+  // data.
+  //
+  // But, in the color map plot widgets, we cannot afford to create the
+  // ancillary items *before* the plot itself because then, the rendering of the
+  // plot (created after) would screen off the ancillary items (created before).
+  //
+  // So, the createAllAncillaryItems() function needs to be called in the
+  // derived classes at the most appropriate moment in the setting up of the
+  // widget.
+  createAllAncillaryItems();
 }
 
 
@@ -159,9 +195,11 @@ BaseTracePlotWidget::addTrace(const pappso::Trace &trace, const QColor &color)
 
   QCPGraph *graph_p = addGraph();
 
+  graph_p->setLayer("plotsLayer");
+
   // Now depracated as of 20200924
-  //graph_p->setData(QVector<double>::fromStdVector(trace.xValues()),
-                   //QVector<double>::fromStdVector(trace.yValues()));
+  // graph_p->setData(QVector<double>::fromStdVector(trace.xValues()),
+  // QVector<double>::fromStdVector(trace.yValues()));
 
   QVector<double> key_qvector;
   QVector<double> value_qvector;
@@ -470,9 +508,9 @@ BaseTracePlotWidget::axisDoubleClickHandler(
   QMouseEvent *event)
 {
 
-  m_context.keyboardModifiers = QGuiApplication::queryKeyboardModifiers();
+  m_context.m_keyboardModifiers = QGuiApplication::queryKeyboardModifiers();
 
-  if(m_context.keyboardModifiers & Qt::ControlModifier)
+  if(m_context.m_keyboardModifiers & Qt::ControlModifier)
     {
 
       // If the Ctrl modifiers is active, then both axes are to be reset. Also
@@ -490,7 +528,7 @@ BaseTracePlotWidget::axisDoubleClickHandler(
 
       if(axis->orientation() == Qt::Vertical)
         {
-          if(m_context.keyboardModifiers & Qt::ShiftModifier)
+          if(m_context.m_keyboardModifiers & Qt::ShiftModifier)
             {
 
               // In this case, we want to make a rescale of the Y axis such
@@ -519,9 +557,9 @@ BaseTracePlotWidget::axisDoubleClickHandler(
   // "pressed". We need to remove manually the button from the pressed buttons
   // context member.
 
-  m_context.pressedMouseButtons ^= event->button();
+  m_context.m_pressedMouseButtons ^= event->button();
 
-  updateContextRanges();
+  updateContextXandYAxisRanges();
 
   emit plotRangesChangedSignal(m_context);
 
@@ -541,17 +579,17 @@ BaseTracePlotWidget::axisRescale()
 
   // This function is called only when the user has clicked on the x/y axis or
   // when the user has dragged the left mouse button with the Ctrl key
-  // modifier. The m_context.wasClickOnXAxis is then simulated in the mouse
+  // modifier. The m_context.m_wasClickOnXAxis is then simulated in the mouse
   // move handler. So we need to test which axis was clicked-on.
 
-  if(m_context.wasClickOnXAxis)
+  if(m_context.m_wasClickOnXAxis)
     {
 
       // We are changing the range of the X axis.
 
       // What is the x delta ?
       double xDelta =
-        m_context.currentDragPoint.x() - m_context.startDragPoint.x();
+        m_context.m_currentDragPoint.x() - m_context.m_startDragPoint.x();
 
       // If xDelta is < 0, the  we were dragging from right to left, we are
       // compressing the view on the x axis, by adding new data to the right
@@ -590,7 +628,7 @@ BaseTracePlotWidget::axisRescale()
       // data displayed in the new X axis range are full scale on the Y
       // axis. For this, the Shift modifier key should be pressed.
 
-      if(m_context.keyboardModifiers & Qt::ShiftModifier)
+      if(m_context.m_keyboardModifiers & Qt::ShiftModifier)
         {
 
           // In this case, we want to make a rescale of the Y axis such that
@@ -605,14 +643,14 @@ BaseTracePlotWidget::axisRescale()
       // else, do leave the Y axis range unchanged.
     }
   // End of
-  // if(m_context.wasClickOnXAxis)
-  else // that is, if(m_context.wasClickOnYAxis)
+  // if(m_context.m_wasClickOnXAxis)
+  else // that is, if(m_context.m_wasClickOnYAxis)
     {
       // We are changing the range of the Y axis.
 
       // What is the y delta ?
       double yDelta =
-        m_context.currentDragPoint.y() - m_context.startDragPoint.y();
+        m_context.m_currentDragPoint.y() - m_context.m_startDragPoint.y();
 
       // See above for an explanation of the computation.
 
@@ -637,11 +675,11 @@ BaseTracePlotWidget::axisRescale()
       //}
     }
   // End of
-  // else // that is, if(m_context.wasClickOnYAxis)
+  // else // that is, if(m_context.m_wasClickOnYAxis)
 
   // Update the context with the current axes ranges
 
-  updateContextRanges();
+  updateContextXandYAxisRanges();
 
   emit plotRangesChangedSignal(m_context);
 
@@ -654,21 +692,21 @@ BaseTracePlotWidget::axisReframe()
 {
 
   // double sorted_start_drag_point_x =
-  // std::min(m_context.startDragPoint.x(), m_context.currentDragPoint.x());
+  // std::min(m_context.m_startDragPoint.x(), m_context.m_currentDragPoint.x());
 
   // xAxis->setRange(sorted_start_drag_point_x,
-  // sorted_start_drag_point_x + fabs(m_context.xDelta));
+  // sorted_start_drag_point_x + fabs(m_context.m_xDelta));
 
   xAxis->setRange(
-    QCPRange(m_context.xRegionRangeStart, m_context.xRegionRangeEnd));
+    QCPRange(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd));
 
   // Note that the y axis should be rescaled from current lower value to new
   // upper value matching the y-axis position of the cursor when the mouse
   // button was released.
 
-  yAxis->setRange(
-    xAxis->range().lower,
-    std::max<double>(m_context.yRegionRangeStart, m_context.yRegionRangeEnd));
+  yAxis->setRange(xAxis->range().lower,
+                  std::max<double>(m_context.m_yRegionRangeStart,
+                                   m_context.m_yRegionRangeEnd));
 
   // qDebug() << "xaxis:" << xAxis->range().lower << "-" <<
   // xAxis->range().upper
@@ -676,7 +714,7 @@ BaseTracePlotWidget::axisReframe()
 
   // If the shift modifier key is pressed, then the user want the y axis
   // to be full scale.
-  if(m_context.keyboardModifiers & Qt::ShiftModifier)
+  if(m_context.m_keyboardModifiers & Qt::ShiftModifier)
     {
 
       bool ok = false;
@@ -687,7 +725,7 @@ BaseTracePlotWidget::axisReframe()
     }
   // else do nothing, let the y axis range as is.
 
-  updateContextRanges();
+  updateContextXandYAxisRanges();
 
   updateAxesRangeHistory();
   emit plotRangesChangedSignal(m_context);
@@ -700,17 +738,17 @@ void
 BaseTracePlotWidget::axisZoom()
 {
 
-  // Use the m_context.xRegionRangeStart/End values, but we need to sort the
+  // Use the m_context.m_xRegionRangeStart/End values, but we need to sort the
   // values before using them, because now we want to really have the lower x
   // value. Simply craft a QCPRange that will swap the values if lower is not
   // < than upper QCustomPlot calls this normalization).
 
   xAxis->setRange(
-    QCPRange(m_context.xRegionRangeStart, m_context.xRegionRangeEnd));
+    QCPRange(m_context.m_xRegionRangeStart, m_context.m_xRegionRangeEnd));
 
   // If the shift modifier key is pressed, then the user want the y axis
   // to be full scale.
-  if(m_context.keyboardModifiers & Qt::ShiftModifier)
+  if(m_context.m_keyboardModifiers & Qt::ShiftModifier)
     {
 
       bool ok = false;
@@ -721,9 +759,9 @@ BaseTracePlotWidget::axisZoom()
     }
   else
     yAxis->setRange(
-      QCPRange(m_context.yRegionRangeStart, m_context.yRegionRangeEnd));
+      QCPRange(m_context.m_yRegionRangeStart, m_context.m_yRegionRangeEnd));
 
-  updateContextRanges();
+  updateContextXandYAxisRanges();
 
   updateAxesRangeHistory();
   emit plotRangesChangedSignal(m_context);
@@ -734,14 +772,14 @@ BaseTracePlotWidget::axisZoom()
 void
 BaseTracePlotWidget::axisPan()
 {
-  if(m_context.wasClickOnXAxis)
+  if(m_context.m_wasClickOnXAxis)
     {
-      xAxis->setRange(m_context.xRange.lower - m_context.xDelta,
-                      m_context.xRange.upper - m_context.xDelta);
+      xAxis->setRange(m_context.m_xRange.lower - m_context.m_xDelta,
+                      m_context.m_xRange.upper - m_context.m_xDelta);
 
       // If the shift modifier key is pressed, then the user want the y axis
       // to be full scale.
-      if(m_context.keyboardModifiers & Qt::ShiftModifier)
+      if(m_context.m_keyboardModifiers & Qt::ShiftModifier)
         {
 
           bool ok = false;
@@ -753,13 +791,13 @@ BaseTracePlotWidget::axisPan()
       // else nothing to do we do not change the y axis scale.
     }
 
-  if(m_context.wasClickOnYAxis)
+  if(m_context.m_wasClickOnYAxis)
     {
-      yAxis->setRange(m_context.yRange.lower - m_context.yDelta,
-                      m_context.yRange.upper - m_context.yDelta);
+      yAxis->setRange(m_context.m_yRange.lower - m_context.m_yDelta,
+                      m_context.m_yRange.upper - m_context.m_yDelta);
     }
 
-  updateContextRanges();
+  updateContextXandYAxisRanges();
 
   // We cannot store the new ranges in the history, because the pan operation
   // involved a huge quantity of micro-movements elicited upon each mouse move
