@@ -38,6 +38,7 @@
 
 #include "massspectraceplotwidget.h"
 #include "../../pappsoexception.h"
+#include "massspectraceplotcontext.h"
 
 
 int massSpecTracePlotContextMetaTypeId =
@@ -52,40 +53,18 @@ int massSpecTracePlotContextPtrMetaTypeId =
 namespace pappso
 {
 
-
-QString
-MassSpecTracePlotContext::toString() const
-{
-  QString text("Base context:\n");
-
-  text += baseContext.toString();
-
-  text += "\n";
-
-  text += QString("last z: %1").arg(lastZ);
-  text += QString("last m/z: %1").arg(lastMz, 0, 'f', 6);
-  text += QString("last TIC intensity: %1").arg(lastTicIntensity, 0, 'g', 0);
-  text += QString("last Mr: %1").arg(lastMr, 0, 'f', 6);
-  text +=
-    QString("last resolving power: %1").arg(lastResolvingPower, 0, 'g', 0);
-
-  text += "\n";
-
-  return text;
-}
-
 MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent)
   : BaseTracePlotWidget(parent)
 {
   // Set the base context to be of kind DataKind::mz;
 
-  BasePlotWidget::m_context.dataKind = DataKind::mz;
+  BasePlotWidget::m_context.m_dataKind = DataKind::mz;
 
   // And then initialize ours with the base class' one.
-  m_context.baseContext = BasePlotWidget::m_context;
+  m_context.m_baseContext = BasePlotWidget::m_context;
 
   // qDebug() << "Data kind:" <<
-  // static_cast<int>(m_context.baseContext.dataKind);
+  // static_cast<int>(m_context.m_baseContext.m_dataKind);
 }
 
 MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent,
@@ -95,13 +74,13 @@ MassSpecTracePlotWidget::MassSpecTracePlotWidget(QWidget *parent,
 {
   // Set the base context to be of kind DataKind::mz;
 
-  BasePlotWidget::m_context.dataKind = DataKind::mz;
+  BasePlotWidget::m_context.m_dataKind = DataKind::mz;
 
   // And then initialize ours with the base class' one.
-  m_context.baseContext = BasePlotWidget::m_context;
+  m_context.m_baseContext = BasePlotWidget::m_context;
 
   // qDebug() << "Data kind:" <<
-  // static_cast<int>(m_context.baseContext.dataKind);
+  // static_cast<int>(m_context.m_baseContext.m_dataKind);
 }
 
 
@@ -126,8 +105,8 @@ MassSpecTracePlotWidget::keyPressEvent(QKeyEvent *event)
   emit keyPressEventSignal(m_context);
   emit testKeyPressEventSignal(m_context);
   emit newKeyPressEventSignal(
-    pappso::DataPoint(m_context.baseContext.currentDragPoint.x(),
-                      m_context.baseContext.currentDragPoint.y()));
+    pappso::DataPoint(m_context.m_baseContext.m_currentDragPoint.x(),
+                      m_context.m_baseContext.m_currentDragPoint.y()));
 }
 
 
@@ -187,13 +166,13 @@ MassSpecTracePlotWidget::mouseMoveHandlerDraggingCursor()
   // to get it from the base class and refresh our local context with it.
   refreshBaseContext();
 
-  if(m_context.baseContext.mouseButtonsAtMousePress & Qt::LeftButton)
+  if(m_context.m_baseContext.m_mouseButtonsAtMousePress & Qt::LeftButton)
     {
-      if(!m_context.baseContext.isMeasuringDistance)
+      if(!m_context.m_baseContext.m_isMeasuringDistance)
         return;
 
       // qDebug() << "lastMovingMouseButtons:"
-      //<< m_context.baseContext.lastMovingMouseButtons;
+      //<< m_context.m_baseContext.m_lastMovingMouseButtons;
 
       deconvolute();
       computeResolvingPower();
@@ -228,7 +207,7 @@ MassSpecTracePlotWidget::mouseReleaseHandler(QMouseEvent *event)
 const MassSpecTracePlotContext &
 MassSpecTracePlotWidget::refreshBaseContext() const
 {
-  m_context.baseContext = BasePlotWidget::m_context;
+  m_context.m_baseContext = BasePlotWidget::m_context;
 
   return m_context;
 }
@@ -281,11 +260,11 @@ MassSpecTracePlotWidget::deconvolute()
   // on the fractional part of the deconvoluted charge value. This value is set
   // in the parent window's double spin box.
 
-  if(fabs(m_context.baseContext.xDelta) >= 0 &&
-     fabs(m_context.baseContext.xDelta) <= 1.1)
+  if(fabs(m_context.m_baseContext.m_xDelta) >= 0 &&
+     fabs(m_context.m_baseContext.m_xDelta) <= 1.1)
     {
       // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-      //<< "m_xDelta:" << m_context.baseContext.xDelta
+      //<< "m_xDelta:" << m_context.m_baseContext.m_xDelta
       //<< "trying isotope-based deconvolution.";
 
       return deconvoluteIsotopicCluster();
@@ -325,26 +304,26 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
   // That parameter defaults to 1, that is the two peaks are immediately
   // consecutive, that is, there is only one interval.
 
-  // We use the m_contex.baseContext.xRegionRange structure that is unsorted.
+  // We use the m_contex.basecontext.m_xRegionRange structure that is unsorted.
   // That is, lower is the start drag point.x and upper is the current drag
   // point.x. If dragging occurs from left to right, start.x < cur.x.
   // We use the unsorted values, because we need to know in which direction
   // the user has drug the mouse, because we want to provide the Mr value
   // for the peak currently under the mouse cursor, that is under
   // currentDragPoint, that is the value in
-  // m_context.baseContext.xRegionRange.upper.
+  // m_context.m_baseContext.m_xRegionRange.upper.
 
-  double startMz = m_context.baseContext.xRegionRangeStart;
-  double curMz   = m_context.baseContext.xRegionRangeEnd;
+  double startMz = m_context.m_baseContext.m_xRegionRangeStart;
+  double curMz   = m_context.m_baseContext.m_xRegionRangeEnd;
 
   // qDebug() << "startMz:" << startMz << "curMz:" << curMz;
 
   if(startMz == curMz)
     {
-      m_context.lastZ            = -1;
-      m_context.lastMz           = std::numeric_limits<double>::min();
-      m_context.lastTicIntensity = std::numeric_limits<double>::min();
-      m_context.lastMr           = std::numeric_limits<double>::min();
+      m_context.m_lastZ            = -1;
+      m_context.m_lastMz           = std::numeric_limits<double>::min();
+      m_context.m_lastTicIntensity = std::numeric_limits<double>::min();
+      m_context.m_lastMr           = std::numeric_limits<double>::min();
 
       return false;
     }
@@ -407,10 +386,10 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
        (1 - m_chargeMinimalFractionalPart /* that is >= 0.01 */) &&
      chargeFracPart <= m_chargeMinimalFractionalPart /* that is <= 0.99 */)
     {
-      m_context.lastZ            = -1;
-      m_context.lastMz           = std::numeric_limits<double>::min();
-      m_context.lastTicIntensity = std::numeric_limits<double>::min();
-      m_context.lastMr           = std::numeric_limits<double>::min();
+      m_context.m_lastZ            = -1;
+      m_context.m_lastMz           = std::numeric_limits<double>::min();
+      m_context.m_lastTicIntensity = std::numeric_limits<double>::min();
+      m_context.m_lastMr           = std::numeric_limits<double>::min();
 
       // qDebug() << __FILE__ << __LINE__
       //<< "Not a charge state family peak,"
@@ -420,9 +399,9 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
     }
 
   if(chargeFracPart > m_chargeMinimalFractionalPart)
-    m_context.lastZ = chargeIntPart + 1;
+    m_context.m_lastZ = chargeIntPart + 1;
   else
-    m_context.lastZ = chargeIntPart;
+    m_context.m_lastZ = chargeIntPart;
 
   // Now, to actually compute the molecular mass based on the charge and on
   // the currently displayed m/z value, we need to have some thinking:
@@ -437,19 +416,19 @@ MassSpecTracePlotWidget::deconvoluteChargedState(int span)
     {
       // The drag was from right to left, that is curMz is less than startMz.
       // So we want to show the charge of the curMz, that is, z + span.
-      m_context.lastZ = m_context.lastZ + span;
+      m_context.m_lastZ = m_context.m_lastZ + span;
     }
 
-  m_context.lastMz = curMz;
-  m_context.lastMr =
-    (m_context.lastMz * m_context.lastZ) - (m_context.lastZ * MPROTON);
+  m_context.m_lastMz = curMz;
+  m_context.m_lastMr =
+    (m_context.m_lastMz * m_context.m_lastZ) - (m_context.m_lastZ * MPROTON);
 
   // qDebug() << __FILE__ << __LINE__
   //<< "startMz:" << QString("%1").arg(startMz, 0, 'f', 6)
   //<< "m_lastMz (curMz):"
-  //<< QString("%1").arg(m_context.lastMz, 0, 'f', 6)
-  //<< "m_lastMass:" << QString("%1").arg(m_context.lastMr, 0, 'f', 6)
-  //<< "m_lastZ:" << QString("%1").arg(m_context.lastZ);
+  //<< QString("%1").arg(m_context.m_lastMz, 0, 'f', 6)
+  //<< "m_lastMass:" << QString("%1").arg(m_context.m_lastMr, 0, 'f', 6)
+  //<< "m_lastZ:" << QString("%1").arg(m_context.m_lastZ);
 
   // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
   //<< "returning true";
@@ -480,8 +459,8 @@ bool
 MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
 {
 
-  if(m_context.baseContext.xRegionRangeStart ==
-     m_context.baseContext.xRegionRangeEnd)
+  if(m_context.m_baseContext.m_xRegionRangeStart ==
+     m_context.m_baseContext.m_xRegionRangeEnd)
     {
       // qDebug() << __FILE__ << __LINE__
       //<< "Same xRegionRange.upper and xRegionRange.lower:"
@@ -490,13 +469,13 @@ MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
       return false;
     }
 
-  double chargeTemp = 1 / fabs(m_context.baseContext.xDelta);
+  double chargeTemp = 1 / fabs(m_context.m_baseContext.m_xDelta);
 
   // Make a judicious roundup.
   double chargeIntPart;
   double chargeFracPart = modf(chargeTemp, &chargeIntPart);
 
-  // qDebug() << "m_xDelta:" << m_context.baseContext.xDelta
+  // qDebug() << "m_xDelta:" << m_context.m_baseContext.m_xDelta
   //<< "chargeTemp:" << QString("%1").arg(chargeTemp, 0, 'f', 6)
   //<< "chargeIntPart:" << chargeIntPart
   //<< "chargeFracPart:" << QString("%1").arg(chargeFracPart, 0, 'f', 6)
@@ -505,10 +484,10 @@ MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
   if(chargeFracPart >= (1 - m_chargeMinimalFractionalPart) &&
      chargeFracPart <= m_chargeMinimalFractionalPart)
     {
-      m_context.lastZ            = -1;
-      m_context.lastMz           = std::numeric_limits<double>::min();
-      m_context.lastTicIntensity = std::numeric_limits<double>::min();
-      m_context.lastMr           = std::numeric_limits<double>::min();
+      m_context.m_lastZ            = -1;
+      m_context.m_lastMz           = std::numeric_limits<double>::min();
+      m_context.m_lastTicIntensity = std::numeric_limits<double>::min();
+      m_context.m_lastMr           = std::numeric_limits<double>::min();
 
       // qDebug() << "Not in a isotopic cluster peak:"
       //<< "returning from deconvoluteIsotopicCluster";
@@ -518,19 +497,19 @@ MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
 
   if(chargeFracPart > m_chargeMinimalFractionalPart)
     {
-      m_context.lastZ = chargeIntPart + 1;
+      m_context.m_lastZ = chargeIntPart + 1;
 
       // qDebug() << "chargeFracPart > m_chargeMinimalFractionalPart -> m_lastZ
       // = "
-      //<< m_context.lastZ;
+      //<< m_context.m_lastZ;
     }
   else
     {
-      m_context.lastZ = chargeIntPart;
+      m_context.m_lastZ = chargeIntPart;
 
       // qDebug()
       //<< "chargeFracPart <=  m_chargeMinimalFractionalPart -> m_lastZ = "
-      //<< m_context.lastZ;
+      //<< m_context.m_lastZ;
     }
 
   // Now that we have the charge in the form of an int, we can compute the
@@ -540,11 +519,11 @@ MassSpecTracePlotWidget::deconvoluteIsotopicCluster()
   // We need to sort the xRegionRange before being certain that lower is indeed
   // the left value of the drag span.
 
-  m_context.lastMz = std::min<double>(m_context.baseContext.xRegionRangeStart,
-                                      m_context.baseContext.xRegionRangeEnd);
+  m_context.m_lastMz = std::min<double>(m_context.m_baseContext.m_xRegionRangeStart,
+                                      m_context.m_baseContext.m_xRegionRangeEnd);
 
-  m_context.lastMr =
-    (m_context.lastMz * m_context.lastZ) - (m_context.lastZ * MPROTON);
+  m_context.m_lastMr =
+    (m_context.m_lastMz * m_context.m_lastZ) - (m_context.m_lastZ * MPROTON);
 
   // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
   //<< "returning true";
@@ -565,20 +544,20 @@ MassSpecTracePlotWidget::computeResolvingPower()
   // during mouve movement handling. Note that the range values *are
   // sorted*.
 
-  if(!m_context.baseContext.xDelta || m_context.baseContext.xDelta > 1)
+  if(!m_context.m_baseContext.m_xDelta || m_context.m_baseContext.m_xDelta > 1)
     {
-      m_context.lastResolvingPower = std::numeric_limits<double>::min();
+      m_context.m_lastResolvingPower = std::numeric_limits<double>::min();
 
       return false;
     }
 
   // Resolving power is m/z / Delta(m/z), for singly-charged species.
 
-  m_context.lastResolvingPower =
-    (std::min<double>(m_context.baseContext.xRegionRangeStart,
-                      m_context.baseContext.xRegionRangeEnd) +
-     (m_context.baseContext.xDelta / 2)) /
-    m_context.baseContext.xDelta;
+  m_context.m_lastResolvingPower =
+    (std::min<double>(m_context.m_baseContext.m_xRegionRangeStart,
+                      m_context.m_baseContext.m_xRegionRangeEnd) +
+     (m_context.m_baseContext.m_xDelta / 2)) /
+    m_context.m_baseContext.m_xDelta;
 
   // The m_context was refreshed with the base class context in the calling
   // chain.
