@@ -90,15 +90,38 @@ MsRunXicExtractorDisk::prepareExtractor()
     }
 }
 
-XicCstSPtr
-MsRunXicExtractorDisk::getXicCstSPtr(const MzRange &mz_range,
-                                     pappso::pappso_double rt_begin,
-                                     pappso::pappso_double rt_end)
+
+void
+MsRunXicExtractorDisk::protectedExtractXicCoordSPtrList(
+  UiMonitorInterface &monitor,
+  std::vector<XicCoordSPtr>::iterator it_xic_coord_list_begin,
+  std::vector<XicCoordSPtr>::iterator it_xic_coord_list_end)
 {
-  std::shared_ptr<Xic> msrunxic_sp = std::make_shared<Xic>(Xic());
+  // sort xic by mz:
+  std::sort(it_xic_coord_list_begin,
+            it_xic_coord_list_end,
+            [](XicCoordSPtr &a, XicCoordSPtr &b) {
+              return a.get()->mzRange.getMz() < b.get()->mzRange.getMz();
+            });
+
+  for(auto it = it_xic_coord_list_begin; it != it_xic_coord_list_end; it++)
+    {
+      extractOneXicCoord(*(it->get()));
+      monitor.count();
+    }
+}
+
+void
+MsRunXicExtractorDisk::extractOneXicCoord(XicCoord &xic_coord)
+{
+  std::shared_ptr<Xic> msrunxic_sp = xic_coord.xicSptr;
+
+  double rt_begin = xic_coord.rtTarget - m_retentionTimeAroundTarget;
+  double rt_end   = xic_coord.rtTarget + m_retentionTimeAroundTarget;
+
 
   std::vector<MsRunSliceSPtr> slice_list;
-  slice_list = acquireSlices(mz_range);
+  slice_list = acquireSlices(xic_coord.mzRange);
 
   if(slice_list.size() == 0)
     {
@@ -120,7 +143,7 @@ MsRunXicExtractorDisk::getXicCstSPtr(const MzRange &mz_range,
           const MassSpectrum &spectrum = msrun_slice.get()->getSpectrum(i);
           for(auto &&peak : spectrum)
             {
-              if(mz_range.contains(peak.x))
+              if(xic_coord.mzRange.contains(peak.x))
                 {
                   if(m_xicExtractMethod == XicExtractMethod::sum)
                     {
@@ -138,21 +161,6 @@ MsRunXicExtractorDisk::getXicCstSPtr(const MzRange &mz_range,
         }
       msrunxic_sp.get()->push_back(xic_element);
     }
-
-  return (msrunxic_sp);
-}
-
-std::vector<XicCstSPtr>
-MsRunXicExtractorDisk::getXicCstSPtrList(
-  const std::vector<MzRange> &mz_range_list)
-{
-
-  std::vector<XicCstSPtr> xic_list_return;
-  for(auto &range : mz_range_list)
-    {
-      xic_list_return.push_back(getXicCstSPtr(range, 0, 40000000));
-    }
-  return xic_list_return;
 }
 
 void
