@@ -26,9 +26,12 @@
  *implementation
  ******************************************************************************/
 
-// make test ARGS="-V -I 6,6"
 
-#define CATCH_CONFIG_MAIN
+// make test ARGS="-V -I 1,1"
+
+// ./tests/catch2-only-tests [Aa] -s
+
+
 #include <catch2/catch.hpp>
 #include <QDebug>
 #include <QString>
@@ -52,15 +55,16 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
 
   SECTION("..:: AA init ::..", "[Aa]")
   {
-    // cout << endl << "..:: AA init ::.." << endl;
+    // cout << std::endl << "..:: AA init ::.." << std::endl;
     //   OboPsiMod test;
     Aa leucine('L');
     MzRange mz_range(leucine.getMass(), PrecisionFactory::getPpmInstance(1));
     cout << "leucine: "
-         << QString::number(leucine.getMass(), 'g', 10).toStdString() << endl;
+         << QString::number(leucine.getMass(), 'g', 10).toStdString()
+         << std::endl;
     cout << "leucine number of N15 : "
-         << leucine.getNumberOfIsotope(Isotope::N15) << endl;
-    cout << mz_range.toString().toStdString() << endl;
+         << leucine.getNumberOfIsotope(Isotope::N15) << std::endl;
+    cout << mz_range.toString().toStdString() << std::endl;
     /*
     if(!mz_range.contains(pappso_double(131.094635) - MASSH2O))
       {
@@ -99,20 +103,20 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
 
     OboPsiMod psimod(filter_label);
 
-    cout << "term_list.size= " << term_list.size() << endl;
+    cout << "term_list.size= " << term_list.size() << std::endl;
     REQUIRE(term_list.size() == 12);
 
 
     MzRange range(pappso_double(57.02),
                   PrecisionFactory::getDaltonInstance(pappso_double(0.02)));
-    cout << range.getMz() << endl;
+    cout << range.getMz() << std::endl;
 
     cout << "choses "
          << MzRange(pappso_double(57.02),
                     PrecisionFactory::getDaltonInstance(pappso_double(0.02)))
               .toString()
               .toStdString()
-         << endl;
+         << std::endl;
     FilterOboPsiModSink term_listb;
     FilterOboPsiModTermDiffMono filter_labelb(
       term_listb,
@@ -124,9 +128,9 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
     for(auto term : term_listb.getOboPsiModTermList())
       {
         // cout << term._accession.toStdString() << " " << mz(term._diff_mono)
-        // << endl;
+        // << std::endl;
       }
-    cout << "term_listb.size= " << term_listb.size() << endl;
+    cout << "term_listb.size= " << term_listb.size() << std::endl;
     REQUIRE(term_listb.size() == 8);
 
     Aa alaninebis('A');
@@ -155,33 +159,33 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
   {
     AaModificationP mod = AaModification::getInstance("MOD:00397");
     cout << " MOD:00397 mass="
-         << QString::number(mod->getMass(), 'g', 15).toStdString() << endl;
+         << QString::number(mod->getMass(), 'g', 15).toStdString() << std::endl;
     // 57.021464
 
     // MOD:00429
     mod = AaModification::getInstance("MOD:00429");
     cout << " MOD:00429 mass="
-         << QString::number(mod->getMass(), 'g', 15).toStdString() << endl;
+         << QString::number(mod->getMass(), 'g', 15).toStdString() << std::endl;
     // 28.0313
 
 
     // MOD:00382
     mod = AaModification::getInstance("MOD:00382");
     cout << " MOD:00382 mass="
-         << QString::number(mod->getMass(), 'g', 15).toStdString() << endl;
+         << QString::number(mod->getMass(), 'g', 15).toStdString() << std::endl;
     //-20.026215
     REQUIRE(mod->getMass() == Approx(-20.026215));
 
     // MOD:00234
     mod = AaModification::getInstance("MOD:00234");
     cout << " MOD:00234 mass="
-         << QString::number(mod->getMass(), 'g', 15).toStdString() << endl;
+         << QString::number(mod->getMass(), 'g', 15).toStdString() << std::endl;
     // 305.068156
 
     // MOD:00838
     mod = AaModification::getInstance("MOD:00838");
     cout << " MOD:00838 mass="
-         << QString::number(mod->getMass(), 'g', 15).toStdString() << endl;
+         << QString::number(mod->getMass(), 'g', 15).toStdString() << std::endl;
 
 
     for(auto amino_acid : pappso::Aa::getAminoAcidCharList())
@@ -189,7 +193,7 @@ TEST_CASE("Amino Acid test suite.", "[Aa]")
         pappso::Aa aa_enumi(amino_acid);
         cout << " " << (char)amino_acid << " "
              << QString::number(aa_enumi.getMass(), 'g', 15).toStdString()
-             << endl;
+             << std::endl;
       }
     /*
      * A 71.037113785565
