@@ -43,15 +43,16 @@ int
 main()
 {
 
-  cout << endl << "..:: peptide init ::.." << endl;
+  cout << std::endl << "..:: peptide init ::.." << std::endl;
   Peptide peptide("LA");
-  cout << endl << "..:: peptide LI ::.." << endl;
+  cout << std::endl << "..:: peptide LI ::.." << std::endl;
   cout << peptide.getSequence().toStdString() << " "
-       << peptide.getSequenceLi().toStdString() << endl;
+       << peptide.getSequenceLi().toStdString() << std::endl;
   MzRange mz_range(peptide.getMass(), PrecisionFactory::getPpmInstance(10));
   if(!mz_range.contains(Aa('L').getMass() + Aa('A').getMass() + MASSH2O))
     {
-      cerr << "!mz_range.contains(Aa('L').getMass()+Aa('A').getMass()" << endl;
+      cerr << "!mz_range.contains(Aa('L').getMass()+Aa('A').getMass()"
+           << std::endl;
       return 1;
     }
   // 202.13179
@@ -61,7 +62,7 @@ main()
   if(!mz_range_very_precise.contains(202.13179))
     {
       cerr << QString::number(peptide.getMass(), 'g', 10).toStdString()
-           << " LA mass != 202.13179" << endl;
+           << " LA mass != 202.13179" << std::endl;
       return 1;
     }
 
@@ -72,7 +73,7 @@ main()
   if(!mz_range_very_preciseb.contains(1756.73395))
     {
       cerr << QString::number(peptide2.getMz(1), 'g', 10).toStdString()
-           << " CCAADDKEACFAVEGPK mass != 1756.73395" << endl;
+           << " CCAADDKEACFAVEGPK mass != 1756.73395" << std::endl;
       return 1;
     }
   /*
@@ -83,21 +84,22 @@ main()
     */
 
   pappso::AaModificationP aaModcarba = AaModification::getInstance("MOD:00397");
+  /*
   pappso::AaModificationP aaModcarbab =
     AaModification::getInstance("MOD:00397");
-  AaModificationP met_oxy = AaModification::getInstance("MOD:00719");
+  AaModificationP met_oxy = AaModification::getInstance("MOD:00719");*/
   peptide2.addAaModification(aaModcarba, 0);
   peptide2.addAaModification(aaModcarba, 1);
   peptide2.addAaModification(aaModcarba, 9);
   peptide2.addAaModification(AaModification::getInstance("MOD:01160"), 0);
 
-  cerr << peptide2.getFormula(1).toStdString().c_str() << endl;
+  cerr << peptide2.getFormula(1).toStdString().c_str() << std::endl;
 
   MzRange mz_range2(peptide2.getMz(1), PrecisionFactory::getPpmInstance(10));
   if(!mz_range2.contains(1910.7722))
     {
       cerr << peptide2.getMz(1) << "!="
-           << "1910.7722" << endl;
+           << "1910.7722" << std::endl;
       return 1;
     }
 
@@ -108,7 +110,7 @@ main()
     {
       cerr << "peptide_from_str.get()->getMass() != peptide2.getMass()"
            << peptide_from_str.get()->getMass() << "!=" << peptide2.getMass()
-           << endl;
+           << std::endl;
       return 1;
     }
   PeptideSp peptide_from_str2 = PeptideStrParser::parseString(
@@ -121,18 +123,18 @@ main()
       cerr << "peptide_from_str2.get()->getMass() != "
               "peptide_from_str3.get()->getMass()"
            << peptide_from_str2.get()->getMass()
-           << "!=" << peptide_from_str3.get()->getMass() << endl;
+           << "!=" << peptide_from_str3.get()->getMass() << std::endl;
       return 1;
     }
   // SUCCESS
   Peptide copy_str2(*peptide_from_str2.get());
   copy_str2.rotate();
-  cerr << copy_str2.toAbsoluteString().toStdString() << endl;
+  cerr << copy_str2.toAbsoluteString().toStdString() << std::endl;
   if(peptide_from_str2.get()->getMass() != copy_str2.getMass())
     {
       cerr << "peptide_from_str2.get()->getMass() != copy_str2.getMass()"
            << peptide_from_str2.get()->getMass() << "!=" << copy_str2.getMass()
-           << endl;
+           << std::endl;
       return 1;
     }
 
@@ -141,7 +143,7 @@ main()
   //[Term]
   // id: MOD:00582
   // name: 6x(13)C,2x(15)N labeled L-lysine
-  cout << endl << "..:: Test peptide isotope labels::.." << endl;
+  cout << std::endl << "..:: Test peptide isotope labels::.." << std::endl;
   PeptideSp peptide_normal =
     PeptideStrParser::parseString("CCAALDDKEACFAVEGPK");
   PeptideSp peptide_lys_label =
@@ -154,19 +156,19 @@ main()
            << "!= "
            << peptide_lys_label.get()->getNumberOfAtom(AtomIsotopeSurvey::C)
            << " peptide_lys_label.get()->getNumberOfAtom(AtomIsotopeSurvey::C)"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(peptide_normal.get()->getNumberOfIsotope(Isotope::C13) != 0)
     {
       cerr << "peptide_normal.get()->getNumberOfIsotope(Isotope::C13) != 0 "
-           << endl;
+           << std::endl;
       return 1;
     }
   if(peptide_lys_label.get()->getNumberOfIsotope(Isotope::C13) != 6)
     {
       cerr << "peptide_lys_label.get()->getNumberOfIsotope(Isotope::C13) != 6 "
-           << endl;
+           << std::endl;
       return 1;
     }
   // xref: DiffMono: "8.014199"
@@ -174,20 +176,20 @@ main()
   if(!mz_range_lys.contains(peptide_lys_label.get()->getMz(1) -
                             peptide_normal.get()->getMz(1)))
     {
-      cerr << "mz_range_lys -  peptide_normal != 8.014199" << endl;
+      cerr << "mz_range_lys -  peptide_normal != 8.014199" << std::endl;
       return 1;
     }
 
   if(*peptide_normal.get() == *peptide_lys_label.get())
     {
       cerr << "(*peptide_normal.get() == *peptide_lys_label.get()) ERROR"
-           << endl;
+           << std::endl;
       return 1;
     }
   if(!(*peptide_normal.get() < *peptide_lys_label.get()))
     {
       cerr << "!(*peptide_normal.get() < *peptide_lys_label.get()) ERROR"
-           << endl;
+           << std::endl;
       return 1;
     }
 
@@ -198,17 +200,17 @@ main()
     {
       cerr
         << "!(*peptide_lys_label_bis.get() == *peptide_lys_label.get()) ERROR"
-        << endl;
+        << std::endl;
       return 1;
     }
 
 
-  cout << endl << "..:: peptide palindrome ::.." << endl;
+  cout << std::endl << "..:: peptide palindrome ::.." << std::endl;
   Peptide peptide_pal_a("ALA");
 
   if(!peptide_pal_a.isPalindrome())
     {
-      cerr << "!peptide_pal_a.isPalindrome() ERROR" << endl;
+      cerr << "!peptide_pal_a.isPalindrome() ERROR" << std::endl;
       return 1;
     }
 
@@ -216,12 +218,12 @@ main()
     {
       cerr << "peptide_normal.isPalindrome() ERROR "
            << peptide_normal.get()->getSequence().toStdString() << " "
-           << peptide_normal.get()->isPalindrome() << endl;
+           << peptide_normal.get()->isPalindrome() << std::endl;
       return 1;
     }
 
 
-  cout << endl << "..:: peptide dimethyl ::.." << endl;
+  cout << std::endl << "..:: peptide dimethyl ::.." << std::endl;
   //"Q(internal:Nter_hydrolytic_cleavage_H,MOD:00429)SLPSLSS(MOD:00696)FLNR(internal:Cter_hydrolytic_cleavage_HO)"
   Peptide peptide_dimethyl("QSLPSLSSFLNR");
   pappso::AaModificationP aaModDimethyl =
@@ -231,7 +233,7 @@ main()
   peptide_dimethyl.addAaModification(aaModDimethyl, 0);
   peptide_dimethyl.addAaModification(aaModDimethyl2, 7);
   cout << "Before " << peptide_dimethyl.toAbsoluteString().toStdString();
-  cout << endl << "remove AaModif" << endl;
+  cout << std::endl << "remove AaModif" << std::endl;
   peptide_dimethyl.removeAaModification(aaModDimethyl);
   if(peptide_dimethyl.toAbsoluteString() !=
      "Q(internal:Nter_hydrolytic_cleavage_H)SLPSLSS(MOD:00696)FLNR(internal:"
