@@ -142,7 +142,7 @@ TEST_CASE("Test Protein", "[Protein]")
   {
 
     qDebug() << "init test protein";
-    cout << endl << "..:: Test Protein ::.." << endl;
+    cout << std::endl << "..:: Test Protein ::.." << std::endl;
 
     Protein cry1Ac(
       "cry1Ac",
@@ -178,7 +178,7 @@ TEST_CASE("Test Protein", "[Protein]")
       "SV"
       "YEEKSYTDGRRENPCEFNRGYRDYTPLPVGYVTKELEYFPETDKVWIEIGETEGTFIVDSVELLLMEE");
 
-    cout << endl << "cry1Ac Mass = " << cry1Ac.getMass() << endl;
+    cout << std::endl << "cry1Ac Mass = " << cry1Ac.getMass() << std::endl;
     MzRange cry1Ac_mass(133248.068195739,
                         PrecisionFactory::getPpmInstance(0.5));
     REQUIRE(cry1Ac_mass.contains(cry1Ac.getMass()));
@@ -266,7 +266,7 @@ TEST_CASE("Test Protein", "[Protein]")
     var_mod_builder.setSink(&modification_sink);
 
     //  QString accMo = "MOD:00719";
-    cout << endl << "..:: chose ::.." << endl;
+    cout << std::endl << "..:: chose ::.." << std::endl;
 
     PeptideBuilder fixed_mod_builder2;
     fixed_mod_builder2.setSink(&var_mod_builder);
@@ -286,7 +286,7 @@ TEST_CASE("Test Protein", "[Protein]")
     kinase.eat(0, fake, false, peptide_size2varmod);
 
     digestion.clear();
-    cout << endl << "..:: Test trypsin peptides on fake prot ::.." << endl;
+    cout << std::endl << "..:: Test trypsin peptides on fake prot ::.." << std::endl;
     kinase.eat(0, fake, false, digestion);
 
     REQUIRE(digestion.contain("K"));
@@ -297,7 +297,7 @@ TEST_CASE("Test Protein", "[Protein]")
     REQUIRE(digestion.contain("VVVMAMEEK"));
 
     // BSA
-    cout << endl << "..:: Test semi tryptic peptides on BSA ::.." << endl;
+    cout << std::endl << "..:: Test semi tryptic peptides on BSA ::.." << std::endl;
     kinase.setMiscleavage(0);
     PeptideSemiEnzyme semi_tryptic;
     semi_tryptic.setSink(&digestion);
@@ -305,7 +305,7 @@ TEST_CASE("Test Protein", "[Protein]")
     kinase.eat(0, protein_sp, false, semi_tryptic);
 
 
-    qDebug() << endl << "..:: Test enzyme motif ::.." << endl;
+    qDebug() << Qt::endl << "..:: Test enzyme motif ::.." << Qt::endl;
     Enzyme motif_digest("(MAMEE[KR])([^P])");
     motif_digest.eat(0, fake, false, digestion);
 
@@ -339,7 +339,7 @@ TEST_CASE("Test Protein", "[Protein]")
     kinase.eat(0, fake, false, peptide_size2varmod);
 
     // reverse protein :
-    cout << endl
+    cout << std::endl
          << "reverse :"
          << Protein(*fake.get()).reverse().getSequence().toStdString();
 
@@ -347,29 +347,29 @@ TEST_CASE("Test Protein", "[Protein]")
       "E(MOD:00429)C(MOD:00419)C(MOD:00397)VVSTQT(MOD:00696,MOD:00696)ALA");
     REQUIRE(modification_sink.contain(peptide_test));
     cout << peptide_test.get()->toString().toStdString() << " is present"
-         << endl;
+         << std::endl;
 
 
     peptide_test =
       PeptideStrParser::parseString("V(MOD:00552)VVMAMEEK(MOD:00429)");
     REQUIRE_FALSE(modification_sink.contain(peptide_test));
     cout << peptide_test.get()->toString().toStdString() << " is absent"
-         << endl;
+         << std::endl;
 
     peptide_test =
       PeptideStrParser::parseString("V(MOD:00552)VVMAMEEK(MOD:00552)");
     REQUIRE(modification_sink.contain(peptide_test));
     cout << peptide_test.get()->toString().toStdString() << " is present"
-         << endl;
+         << std::endl;
 
 
     peptide_test = PeptideStrParser::parseString(
       "E(MOD:00429)C(MOD:00397)C(MOD:00397)VVSTQT(MOD:00696,MOD:00696)ALA");
     REQUIRE(modification_sink.contain(peptide_test));
     cout << peptide_test.get()->toString().toStdString() << " is present"
-         << endl;
+         << std::endl;
 
-    cout << endl << "..:: test modification motifs ::.." << endl;
+    cout << std::endl << "..:: test modification motifs ::.." << std::endl;
 
     ProteinSp prot_test_motif =
       Protein("prot_test_motif", "MVVVVVMAMEEWVTFISLLLLFTVHECCVVSTQTALA")
@@ -390,11 +390,11 @@ TEST_CASE("Test Protein", "[Protein]")
     REQUIRE(modification_sink.contain(peptide_test));
     REQUIRE(modification_sink.size() == 1);
     cout << peptide_test.get()->toString().toStdString() << " is present"
-         << endl;
+         << std::endl;
 
 
     qDebug() << "init test protein";
-    cout << endl << "..:: Test Protein with B and Z wildcard ::.." << endl;
+    cout << std::endl << "..:: Test Protein with B and Z wildcard ::.." << std::endl;
 
     // BSA
     qDebug() << "init bsa with B and Z wildcard";
@@ -426,9 +426,9 @@ TEST_CASE("Test Protein", "[Protein]")
     REQUIRE_FALSE(digestion_bz.contain("MAXXK"));
     REQUIRE(digestion_bz.contain("MAAAK"));
     REQUIRE(digestion_bz.contain("SNEIAHR"));
-    cout << endl << " SNEIAHRFK FOUND " << endl;
+    cout << std::endl << " SNEIAHRFK FOUND " << std::endl;
     REQUIRE(digestion_bz.contain("SDEIAHR"));
-    cout << endl << " SDEIAHRFK FOUND " << endl;
+    cout << std::endl << " SDEIAHRFK FOUND " << std::endl;
   }
 
 
