@@ -52,7 +52,7 @@ TEST_CASE("psm test suite.", "[psm]")
 
   SECTION("..:: readMgf ::..", "[psm]")
   {
-    cout << endl << "..:: readMgf ::.." << endl;
+    cout << std::endl << "..:: readMgf ::.." << std::endl;
     // bool refine_spectrum_synthesis = false;
 
     MassSpectrum spectrum_simple =
@@ -70,7 +70,7 @@ TEST_CASE("psm test suite.", "[psm]")
     std::list<PeptideIon> ion_list;
     ion_list.push_back(PeptideIon::y);
     ion_list.push_back(PeptideIon::b);
-    cout << "spectrum_simple size  " << spectrum_simple.size() << endl;
+    cout << "spectrum_simple size  " << spectrum_simple.size() << std::endl;
 
     PeptideSpectrumMatch psm(
       spectrum_simple, peptide_sp, 2, precision, ion_list);
