@@ -59,7 +59,7 @@ TEST_CASE("scan 15968 test suite.", "[scan15968]")
 
   SECTION("..:: Test scan 15968 ::..", "[scan15968]")
   {
-    cout << endl << "..:: Test scan 15968 ::.." << endl;
+    cout << std::endl << "..:: Test scan 15968 ::.." << std::endl;
     PrecisionPtr precision = PrecisionFactory::getDaltonInstance(0.02);
     std::list<PeptideIon> ion_list;
     ion_list.push_back(PeptideIon::y);
@@ -686,9 +686,9 @@ TEST_CASE("scan 15968 test suite.", "[scan15968]")
 
     MassSpectrum spectrum_clean_isotopes(spectrum_neutral.massSpectrumFilter(
       pappso::FilterTandemDeisotope(1.5, 200)));
-    cout << spectrum_neutral.size() << endl;
-    cout << sclean_isotopes.size() << endl;
-    cout << spectrum_clean_isotopes.size() << endl;
+    cout << spectrum_neutral.size() << std::endl;
+    cout << sclean_isotopes.size() << std::endl;
+    cout << spectrum_clean_isotopes.size() << std::endl;
     REQUIRE(spectrum_clean_isotopes.equals(sclean_isotopes, precision));
 
     MassSpectrum spectrum_most_intense(spectrum_clean_isotopes);
@@ -706,10 +706,10 @@ TEST_CASE("scan 15968 test suite.", "[scan15968]")
                                       ion_list,
                                       refine_spectrum_synthesis);
     cout << "peptide " << pep15968.getSequence().toStdString()
-         << " hyperscore15968=" << hyperscore15968.getHyperscore() << endl;
+         << " hyperscore15968=" << hyperscore15968.getHyperscore() << std::endl;
     cout << "peptide " << pep15968.getSequence().toStdString()
          << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
-         << endl;
+         << std::endl;
 
     // Spectrum::getHyperscore  "b"  itmap->second  1   1
     //  Spectrum::getHyperscore  "y"  itmap->second  9   362880
