@@ -23,10 +23,12 @@
  *
  ******************************************************************************/
 
-// make test ARGS="-V -I 23,23"
+// make test ARGS="-V -I 1,1"
 
+// ./tests/catch2-only-tests [timsframe] -s
+
+// ./tests/catch2-only-tests [timsframe] -s -a
 
-#define CATCH_CONFIG_MAIN
 #include <catch2/catch.hpp>
 #include <QDebug>
 #include <QString>
@@ -37,6 +39,7 @@
 #include <pappsomspp/msrun/private/timsmsrunreaderms2.h>
 #include <pappsomspp/msrun/private/timsmsrunreader.h>
 #include <pappsomspp/pappsoexception.h>
+#include <pappsomspp/exception/exceptionnotfound.h>
 #include <pappsomspp/processing/filters/filtersuitestring.h>
 #include "config.h"
 
@@ -44,20 +47,20 @@ using namespace pappso;
 using namespace std;
 
 
-TEST_CASE("test tims frames", "[timsframe]")
+TEST_CASE("Test tims frames", "[timsframe]")
 {
 
   // Set the debugging message formatting pattern.
   qSetMessagePattern(QString("%{file}@%{line}, %{function}(): %{message}"));
 
-  INFO("..:: test TIMS frame init begin ::..");
+  INFO("..:: Test TIMS frame init begin ::..");
   //   OboPsiMod test;
 
   TimsFrameBase frame(1, 671);
 
   MzRange mz_range(1200.0001, PrecisionFactory::getPpmInstance(10));
 
-  SECTION("test 1")
+  SECTION("Test 1")
   {
     double temperature_correction =
       77.0 * (25.4933665127396 - 25.59978165276) +
@@ -121,12 +124,13 @@ TEST_CASE("test tims frames", "[timsframe]")
     std::size_t scan_num = frame.getScanNumFromOneOverK0(one_over_k0);
 
     REQUIRE(scan_num == 400);
-    cout << endl << "..:: test 1 OK ::.." << endl;
+    cout << std::endl << "..:: Test 1 OK ::.." << std::endl;
   }
 
-  SECTION("test 2")
+  SECTION("Test 2")
   {
-    cout << endl << "..:: second test, new calibration parameters ::.." << endl;
+    cout << std::endl
+         << "..:: second test, new calibration parameters ::.." << std::endl;
 
 
     frame.setMzCalibration(25.3072302808429,
@@ -201,21 +205,82 @@ TEST_CASE("test tims frames", "[timsframe]")
 
 
     REQUIRE_FALSE(mz < 50.0);
-    cout << endl << "..:: test 2 OK ::.." << endl;
+    cout << std::endl << "..:: Test 2 OK ::.." << std::endl;
   }
 
+
 #if USEPAPPSOTREE == 1
+  SECTION("Test TIMS TDF parsing issue #61")
+  {
+    INFO("Test case ERROR reading TIMS frame 58581");
+
+    pappso::MsFileAccessor accessor(
+      "/gorgone/pappso/fichiers_fabricants/Bruker/tims_doc/tdf-sdk/"
+      "example_data/200ngHeLaPASEF_2min_compressed.d/"
+      "analysis.tdf",
+      "a1");
 
 
-  SECTION("test TIMS TDF parsing")
+    accessor.setPreferedFileReaderType(pappso::MzFormat::brukerTims,
+                                       pappso::FileReaderType::tims_ms2);
+
+
+    pappso::MsRunReaderSPtr p_msreader =
+      accessor.msRunReaderSp(accessor.getMsRunIds().front());
+
+    REQUIRE(p_msreader != nullptr);
+
+    REQUIRE(accessor.getFileReaderType() == pappso::FileReaderType::tims_ms2);
+
+    pappso::TimsMsRunReaderMs2 *tims2_reader =
+      dynamic_cast<pappso::TimsMsRunReaderMs2 *>(p_msreader.get());
+    REQUIRE(tims2_reader != nullptr);
+    if(tims2_reader != nullptr)
+      {
+        tims2_reader->setMs2BuiltinCentroid(true);
+        tims2_reader->setMs2FilterCstSPtr(std::make_shared<FilterSuiteString>(
+          FilterSuiteString("chargeDeconvolution|0.02dalton")));
+      }
+    pappso::QualifiedMassSpectrum mass_spectrum;
+    REQUIRE_NOTHROW(mass_spectrum = tims2_reader->qualifiedMassSpectrum(5001));
+
+
+    /*
+     * 23:   ..:: Test TIMS frame init begin ::..
+23:   Test case ERROR reading TIMS frame 58581
+23:   ERROR reading TIMS frame 60575 TIMS binary file
+/home/langella/data1/bruker/ 23:
+5-18-2021_1_robert_28_mic02-std_1354.d/analysis.tdf_bin:  decompressed_size2 23:
+== ZSTD_CONTENTSIZE_ERROR, frame_length=265254592
+
+*/
+    REQUIRE_NOTHROW(mass_spectrum = tims2_reader->qualifiedMassSpectrum(6001));
+    REQUIRE_NOTHROW(mass_spectrum = tims2_reader->qualifiedMassSpectrum(6003));
+    REQUIRE_NOTHROW(mass_spectrum = tims2_reader->qualifiedMassSpectrum(6005));
+    REQUIRE_NOTHROW(mass_spectrum = tims2_reader->qualifiedMassSpectrum(6007));
+    REQUIRE_THROWS_AS(mass_spectrum =
+                        tims2_reader->qualifiedMassSpectrum(35460),
+                      pappso::ExceptionNotFound);
+  }
+
+
+  SECTION("Test TIMS TDF parsing")
   {
     INFO("Test case pappso::FileReaderType::tims_ms2 start");
+
+    pappso::MsFileAccessor accessor(
+      "/gorgone/pappso/versions_logiciels_pappso/masschroq/donnees/"
+      "PXD014777_maxquant_timstof/"
+      "20180809_120min_200ms_WEHI25_brute20k_timsON_100ng_HYE124B_Slot1-8_1_"
+      "894.d/analysis.tdf",
+      "a1");
     /*
-        pappso::MsFileAccessor accessor(
-          "/gorgone/pappso/jouy/raw/2020_Tims_TOF/20201102_HeLa/"
-          "11-2-2020_1_QC_HeLa10ng_219.d/analysis.tdf",
-          "a1");
-    */
+    pappso::MsFileAccessor accessor(
+      "/gorgone/pappso/fichiers_fabricants/Bruker/tims_doc/tdf-sdk/"
+      "example_data/200ngHeLaPASEF_2min_compressed.d/"
+      "analysis.tdf",
+      "a1");
+*/
     /*
         pappso::MsFileAccessor accessor(
           "/gorgone/pappso/fichiers_fabricants/Bruker/tims_doc/tdf-sdk/"
@@ -223,10 +288,50 @@ TEST_CASE("test tims frames", "[timsframe]")
           "200ngHeLaPASEF_2min_compressed.d/analysis.tdf",
           "a1");
     */
+    /*
+        pappso::MsFileAccessor accessor(
+          "/data/test_tdf_quality/2-3-2021_1_HeLa10ng_871.d/analysis.tdf",
+       "a1");
+    */
 
-    pappso::MsFileAccessor accessor(
-      "/data/test_tdf_quality/2-3-2021_1_HeLa10ng_871.d/analysis.tdf",
-      "a1");
+    accessor.setPreferedFileReaderType(pappso::MzFormat::brukerTims,
+                                       pappso::FileReaderType::tims);
+
+
+    pappso::MsRunReaderSPtr p_msreader_tims_ms1 =
+      accessor.msRunReaderSp(accessor.getMsRunIds().front());
+
+    pappso::TimsMsRunReader *tims1_reader =
+      dynamic_cast<pappso::TimsMsRunReader *>(p_msreader_tims_ms1.get());
+
+    REQUIRE_FALSE(p_msreader_tims_ms1.get() == nullptr);
+    REQUIRE_FALSE(tims1_reader == nullptr);
+
+    pappso::TimsDataSp timsdata_sp = tims1_reader->getTimsDataSPtr();
+
+    REQUIRE_NOTHROW(timsdata_sp.get()->getRawMsBySpectrumIndex(0));
+    REQUIRE_NOTHROW(timsdata_sp.get()->getRawMsBySpectrumIndex(1));
+    REQUIRE_NOTHROW(p_msreader_tims_ms1.get()->massSpectrumCstSPtr(0));
+    // REQUIRE_NOTHROW(p_msreader_tims_ms1.get()->massSpectrumCstSPtr(1000));
+
+    for(std::size_t i = 0; i < 1000; i++)
+      {
+        qDebug()
+          << " size(" << (i) << ")="
+          << p_msreader_tims_ms1.get()->massSpectrumCstSPtr(i).get()->size();
+      }
+    p_msreader_tims_ms1.get()->massSpectrumCstSPtr(53);
+    p_msreader_tims_ms1.get()->massSpectrumCstSPtr(5000);
+    // timsdata_sp.get()->getRawMsBySpectrumIndex(8207);
+
+    REQUIRE_NOTHROW(p_msreader_tims_ms1.get()->massSpectrumCstSPtr(8207));
+
+    // 8206, frameId=9 scanNum=910 ERROR in
+    // MzCalibrationModel1::getMzFromTofIndex m[0].y!= 0
+    REQUIRE_NOTHROW(p_msreader_tims_ms1.get()->massSpectrumCstSPtr(8206));
+
+    // scan_num=899 spectrum_index=899
+    REQUIRE_NOTHROW(p_msreader_tims_ms1.get()->massSpectrumCstSPtr(899));
 
 
     accessor.setPreferedFileReaderType(pappso::MzFormat::brukerTims,
@@ -251,7 +356,7 @@ TEST_CASE("test tims frames", "[timsframe]")
       }
 
     pappso::QualifiedMassSpectrum mass_spectrum =
-      tims2_reader->qualifiedMassSpectrum(33373);
+      tims2_reader->qualifiedMassSpectrum(7001);
 
     INFO("mass_spectrum.getMsLevel()=" << mass_spectrum.getMsLevel());
     INFO("mass_spectrum.getPrecursorMz()=" << mass_spectrum.getPrecursorMz());
@@ -269,15 +374,6 @@ TEST_CASE("test tims frames", "[timsframe]")
                                        pappso::FileReaderType::tims);
 
 
-    pappso::MsRunReaderSPtr p_msreader_tims_ms1 =
-      accessor.msRunReaderSp(accessor.getMsRunIds().front());
-
-    pappso::TimsMsRunReader *tims1_reader =
-      dynamic_cast<pappso::TimsMsRunReader *>(p_msreader_tims_ms1.get());
-
-    REQUIRE(tims1_reader != nullptr);
-
-
     class SpectrumCollectionHandler : public SpectrumCollectionHandlerInterface
     {
       public:
@@ -292,6 +388,15 @@ TEST_CASE("test tims frames", "[timsframe]")
                  << m_count << " "
                  << spectrum.getMassSpectrumId().getNativeId().toStdString()
                  << " MSlevel=" << spectrum.getMsLevel());
+
+            if(spectrum.getMsLevel() == 1)
+              {
+                REQUIRE_FALSE(spectrum.getMassSpectrumCstSPtr() == nullptr);
+              }
+            if(spectrum.getMassSpectrumCstSPtr() != nullptr)
+              {
+                WARN(" size=" << spectrum.size());
+              }
             //<< " size=" << spectrum.toString().toStdString());
           }
       };
@@ -313,12 +418,13 @@ TEST_CASE("test tims frames", "[timsframe]")
          << accessor.getFileName().toStdString());
     dummy_handler.setNeedMsLevelPeakList(1, false);
     dummy_handler.setNeedMsLevelPeakList(2, false);
-    tims1_reader->readSpectrumCollectionByMsLevel(dummy_handler, 1);
+    // tims1_reader->readSpectrumCollectionByMsLevel(dummy_handler, 1);
 
     auto s = t.getElapsedSeconds();
 
     WARN("reading time in second : " << s);
 
+
     // git hash 597d6a68062a45d5e3ccaaa8398598a62dc69043 reading time in second
     // : 1447.15
 
@@ -336,13 +442,13 @@ TEST_CASE("test tims frames", "[timsframe]")
     // => avoiding sql query is not really efficient
   }
   /*
-cout << endl
+cout << std::endl
   << mass_spectrum.getMassSpectrumCstSPtr()
        .get()
        ->toString()
        .toStdString()
        .c_str()
-  << endl;
+  << std::endl;
 */
   /*
    *
@@ -386,9 +492,11 @@ polynome :
 
 */
 
+
 #elif USEPAPPSOTREE == 1
 
-  cout << endl << "..:: NO test TIMS TDF parsing ::.." << endl;
+  cout << std::endl
+       << "..:: NO test TIMS TIC chromatogram extraction ::.." << std::endl;
 
 #endif
 }
