@@ -23,10 +23,12 @@
  *
  ******************************************************************************/
 
-// make test ARGS="-V -I 20,20"
 
+// make test ARGS="-V -I 1,1"
 
-#define CATCH_CONFIG_MAIN
+// ./tests/catch2-only-tests [filters] -s
+
+//#define CATCH_CONFIG_MAIN
 #include <catch2/catch.hpp>
 #include <QDebug>
 #include <QString>
@@ -64,7 +66,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
       readMgf(QString(CMAKE_SOURCE_DIR)
                 .append("/tests/data/peaklist_15046_simple_xt.mgf"));
     //.applyCutOff(150).takeNmostIntense(100).applyDynamicRange(100);
-    cout << endl << "..:: FilterGreatestY ::.." << endl;
+    cout << std::endl << "..:: FilterGreatestY ::.." << std::endl;
 
     qDebug();
     MassSpectrum most_intense(spectrum_simple);
@@ -72,7 +74,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
 
     REQUIRE(most_intense.size() == 10);
 
-    qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
+    qDebug();
     most_intense = spectrum_simple;
     most_intense.massSpectrumFilter(
       pappso::MassSpectrumFilterGreatestItensities(10));
@@ -90,7 +92,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
     REQUIRE(most_intense.size() == 100);
     qDebug();
     // 3.018830
-    cout << endl << "..:: resample filters ::.." << endl;
+    cout << std::endl << "..:: resample filters ::.." << std::endl;
     Trace deca_suite({DataPoint(0, 1),
                       DataPoint(1, 2),
                       DataPoint(2, 3),
@@ -147,7 +149,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
     deca = deca_suite;
     deca.filter(FilterResampleKeepGreater(9));
     REQUIRE(deca == deca_greater);
-    cout << endl << "..:: morpho filters ::.." << endl;
+    cout << std::endl << "..:: morpho filters ::.." << std::endl;
 
     deca = deca_suite;
     deca.filter(FilterMorphoMedian(1));
@@ -165,10 +167,10 @@ TEST_CASE("trace filters test suite.", "[filters]")
                        DataPoint(11, 5),
                        DataPoint(12, 6)});
     REQUIRE(deca.size() == deca_median.size());
-    cout << "deca.size() == deca_median.size() " << deca.size() << endl;
+    cout << "deca.size() == deca_median.size() " << deca.size() << std::endl;
     REQUIRE(deca == deca_median);
 
-    cout << endl << "..:: FilterTandemDeisotope ::.." << endl;
+    cout << std::endl << "..:: FilterTandemDeisotope ::.." << std::endl;
     qDebug();
     MassSpectrum remove_tandem_deisotope =
       MassSpectrum(spectrum_simple)
@@ -205,7 +207,7 @@ TEST_CASE("trace filters test suite.", "[filters]")
     ion_list.push_back(PeptideIon::b);
     qDebug();
 
-    cout << endl << "..:: FilterRemoveC13 ::.." << endl;
+    cout << std::endl << "..:: FilterRemoveC13 ::.." << std::endl;
     qDebug();
     MassSpectrum remove_c13 =
       MassSpectrum(spectrum_simple)
@@ -238,10 +240,10 @@ TEST_CASE("trace filters test suite.", "[filters]")
       ion_list,
       true);
     cout << "peptide " << pep15968.getSequence().toStdString()
-         << " hyperscore15968=" << hyperscore15968.getHyperscore() << endl;
+         << " hyperscore15968=" << hyperscore15968.getHyperscore() << std::endl;
     cout << "peptide " << pep15968.getSequence().toStdString()
          << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
-         << endl;
+         << std::endl;
 
     XtandemHyperscore hyperscore15968_remove_c13(
       *spectrum_removed_c13.getMassSpectrumSPtr().get(),
@@ -252,13 +254,14 @@ TEST_CASE("trace filters test suite.", "[filters]")
       true);
     cout << "peptide " << pep15968.getSequence().toStdString()
          << " hyperscore15968_remove_c13="
-         << hyperscore15968_remove_c13.getHyperscore() << endl;
+         << hyperscore15968_remove_c13.getHyperscore() << std::endl;
     cout << "peptide " << pep15968.getSequence().toStdString()
          << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
-         << endl;
+         << std::endl;
 
 
-    cout << endl << "..:: FilterMassSpectrumComplementIonEnhancer ::.." << endl;
+    cout << std::endl
+         << "..:: FilterMassSpectrumComplementIonEnhancer ::.." << std::endl;
     qDebug();
 
     QualifiedMassSpectrum spectrum_complement_ion =
@@ -286,13 +289,14 @@ TEST_CASE("trace filters test suite.", "[filters]")
       true);
     cout << "peptide " << pep15968.getSequence().toStdString()
          << " hyperscore15968_complement_ion_enhancer="
-         << hyperscore15968_complement_ion_enhancer.getHyperscore() << endl;
+         << hyperscore15968_complement_ion_enhancer.getHyperscore()
+         << std::endl;
     cout << "peptide " << pep15968.getSequence().toStdString()
          << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2)
-         << endl;
+         << std::endl;
 
 
-    cout << endl << "..:: FilterGreatestYperWindow ::.." << endl;
+    cout << std::endl << "..:: FilterGreatestYperWindow ::.." << std::endl;
     FilterGreatestYperWindow filter_per_window(40, 2);
     qDebug();
     QualifiedMassSpectrum spectrum_greatest_y_per_window =
@@ -312,8 +316,9 @@ TEST_CASE("trace filters test suite.", "[filters]")
     qDebug();
 
 
-    cout << endl
-         << "..:: FilterGreatestYperWindow  on scan_PXD001468.mgf ::.." << endl;
+    cout << std::endl
+         << "..:: FilterGreatestYperWindow  on scan_PXD001468.mgf ::.."
+         << std::endl;
     QualifiedMassSpectrum spectrum_scan_PXD001468 =
       readQualifiedMassSpectrumMgf(
         QString(CMAKE_SOURCE_DIR).append("/tests/data/scan_PXD001468.mgf"));
@@ -352,27 +357,27 @@ TEST_CASE("trace filters test suite.", "[filters]")
         true);
       cout << "peptide " << pep15968.getSequence().toStdString()
            << " hyperscore15968_greatest_y_per_window="
-           << hyperscore15968_greatest_y_per_window.getHyperscore() << endl;
-      cout << "peptide " << pep15968.getSequence().toStdString()
+           << hyperscore15968_greatest_y_per_window.getHyperscore() <<
+      std::endl; cout << "peptide " << pep15968.getSequence().toStdString()
            << " mz1=" << pep15968.getMz(1) << " mz2=" << pep15968.getMz(2) <<
       endl;
 
     */
 
-    cout << endl << "..:: FilterSuiteString ::.." << endl;
+    cout << std::endl << "..:: FilterSuiteString ::.." << std::endl;
 
     std::shared_ptr<pappso::FilterSuiteString> filter_suite_str =
       std::make_shared<pappso::FilterSuiteString>(
         "chargeDeconvolution|0.02dalton");
 
 
-    cout << endl
+    cout << std::endl
          << "filter_suite_str = "
-         << filter_suite_str.get()->toString().toStdString() << endl;
+         << filter_suite_str.get()->toString().toStdString() << std::endl;
 
-    cout << endl
+    cout << std::endl
          << "..:: FilterChargeDeconvolution from FilterSuiteString ::.."
-         << endl;
+         << std::endl;
 
     std::shared_ptr<pappso::FilterChargeDeconvolution>
       filter_charge_deconvolution =
@@ -401,14 +406,14 @@ TEST_CASE("trace filters test suite.", "[filters]")
                            DataPoint(24, 220),
                            // Third
                            DataPoint(62 - MHPLUS, 35)});
-    cout << "Transform Trace data" << endl;
+    cout << "Transform Trace data" << std::endl;
     filter_charge_deconvolution->filter(loaded_trace);
 
 
     if(loaded_trace != theorical_trace)
       {
         cerr << "transformed Trace are different from theorical trace :"
-             << endl;
+             << std::endl;
 
         if(loaded_trace.xValues().size() == theorical_trace.xValues().size())
           {
@@ -418,14 +423,14 @@ TEST_CASE("trace filters test suite.", "[filters]")
                 cerr << "(" << loaded_trace.xValues()[i] << ", "
                      << loaded_trace.yValues()[i] << ") ";
               }
-            cerr << endl;
+            cerr << std::endl;
             cerr << "theorical trace : \t";
             for(std::size_t i = 0; i < theorical_trace.xValues().size(); i++)
               {
                 cerr << "(" << theorical_trace.xValues()[i] << ", "
                      << theorical_trace.yValues()[i] << ") ";
               }
-            cerr << endl;
+            cerr << std::endl;
           }
         else
           {
@@ -436,8 +441,10 @@ TEST_CASE("trace filters test suite.", "[filters]")
       }
 
     REQUIRE(loaded_trace == theorical_trace);
-
-    cout << endl << "..:: FilterMorphoAntiSpike filters ::.." << endl;
+  }
+  SECTION("..:: test FilterMorphoAntiSpike ::..", "[filters]")
+  {
+    // MESSAGE("..:: FilterMorphoAntiSpike filters ::..");
     Trace anti_spike_trace({DataPoint(0, 0),
                             DataPoint(1, 1),
                             DataPoint(2, 3),
@@ -456,6 +463,63 @@ TEST_CASE("trace filters test suite.", "[filters]")
 
     REQUIRE(anti_spike_trace[9].y == 0);
     REQUIRE(anti_spike_trace[2].y == 3);
-    cout << endl << anti_spike_trace.toString().toStdString() << endl;
+    // cout << std::endl << anti_spike_trace.toString().toStdString() <<
+    // std::endl;
+
+    INFO("filter_anti_spike_too_big");
+    FilterMorphoAntiSpike filter_anti_spike_too_big(7);
+    filter_anti_spike_too_big.filter(anti_spike_trace);
+  }
+
+  SECTION("..:: check empty trace ::..", "[filters]")
+  {
+    // MESSAGE("..:: FilterMorphoAntiSpike filters ::..");
+    Trace empty_trace;
+    FilterMorphoMean m_smooth(3);
+
+    REQUIRE_NOTHROW(m_smooth.filter(empty_trace));
+
+
+    FilterMorphoMinMax m_minMax(5);
+    REQUIRE_NOTHROW(m_minMax.filter(empty_trace));
+
+    FilterMorphoMaxMin m_maxMin(5);
+    REQUIRE_NOTHROW(m_maxMin.filter(empty_trace));
+
+    Trace xic;
+    xic.push_back(DataPoint(1434.7806210000, 85.9931205504));
+    xic.push_back(DataPoint(1586.4034760000, 162.9869610431));
+    xic.push_back(DataPoint(1643.5517360000, 84.9932005440));
+    xic.push_back(DataPoint(1645.8830080000, 98.9920806335));
+
+    FilterMorphoMaxMin m_maxMin2(2);
+    REQUIRE_NOTHROW(m_maxMin2.filter(xic));
+  }
+
+  SECTION("..:: check FilterQuantileBasedRemoveY ::..", "[filters]")
+  {
+
+    Trace xic_PXD0014777 =
+      *(readQualifiedMassSpectrumMgf(
+          QString(CMAKE_SOURCE_DIR).append("/tests/data/xic/PXD014777_xic.tsv"))
+          .getMassSpectrumSPtr()
+          .get());
+
+    REQUIRE(Approx(62.43).epsilon(0.01) ==
+            quantileYTrace(xic_PXD0014777.begin(), xic_PXD0014777.end(), 0.1));
+    REQUIRE(Approx(250.75).epsilon(0.01) ==
+            quantileYTrace(xic_PXD0014777.begin(), xic_PXD0014777.end(), 0.5));
+    REQUIRE(Approx(136.96).epsilon(0.01) ==
+            quantileYTrace(xic_PXD0014777.begin(), xic_PXD0014777.end(), 0.3));
+
+
+    FilterQuantileBasedRemoveY quantile(0.1);
+    xic_PXD0014777 = quantile.filter(xic_PXD0014777);
+
+
+    QFile fnew("quantile_trace.tsv");
+    fnew.open(QFile::WriteOnly | QFile::Text);
+    QTextStream out(&fnew);
+    out << xic_PXD0014777.toString();
   }
 }
